@@ -33,6 +33,11 @@
 #include "components/gwp_asan/common/crash_key_name.h"
 #include "partition_alloc/buildflags.h"
 
+#if PA_BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC) && PA_BUILDFLAG(IS_ANDROID)
+#include "base/system/sys_info.h"
+#endif  // PA_BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC) &&
+        // PA_BUILDFLAG(IS_ANDROID)
+
 #if PA_BUILDFLAG(USE_ALLOCATOR_SHIM)
 #include "components/gwp_asan/client/lightweight_detector/malloc_shims.h"
 #include "components/gwp_asan/client/sampling_malloc_shims.h"
@@ -568,6 +573,22 @@ void MaybeEnableLightweightDetector(bool boost_sampling,
 void MaybeEnableExtremeLightweightDetector(bool boost_sampling,
                                            std::string_view process_type) {
 #if PA_BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC)
+#if PA_BUILDFLAG(IS_ANDROID)
+  // The negative performance impacts of ELUD are not negligible, thus we'd like
+  // to apply ELUD only to high memory devices (approximately high-end devices)
+  // in case of Android. On other platforms, the performance impacts are
+  // acceptable.
+  //
+  // It is very important to filter this condition before
+  // `base::FeatureList::IsEnabled` gets called so that the finch system applies
+  // the experiments to the right devices equally and collects the accurate
+  // statistics from the devices.
+  if (base::SysInfo::AmountOfPhysicalMemory() <
+      8ULL * 1024 * 1024 * 1024 /* 8 Gbytes */) {
+    return;
+  }
+#endif  // PA_BUILDFLAG(IS_ANDROID)
+
   if (!base::FeatureList::IsEnabled(internal::kExtremeLightweightUAFDetector)) {
     return;
   }
