@@ -17,6 +17,7 @@
 #include "base/command_line.h"
 #include "base/containers/contains.h"
 #include "base/containers/map_util.h"
+#include "base/feature_list.h"
 #include "base/files/file_path.h"
 #include "base/i18n/rtl.h"
 #include "base/json/json_writer.h"
@@ -33,6 +34,7 @@
 #include "extensions/common/error_utils.h"
 #include "extensions/common/extension_features.h"
 #include "extensions/common/extension_id.h"
+#include "extensions/common/file_util.h"
 #include "extensions/common/manifest.h"
 #include "extensions/common/manifest_constants.h"
 #include "extensions/common/manifest_handler.h"
@@ -56,6 +58,10 @@ namespace errors = manifest_errors;
 
 namespace {
 
+BASE_FEATURE(kValidateGetResourceURLPath,
+             "ValidateGetResourceURLPath",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
 constexpr int kMinimumSupportedManifestVersion = 2;
 constexpr int kMaximumSupportedManifestVersion = 3;
 constexpr int kPEMOutputColumns = 64;
@@ -94,13 +100,6 @@ bool IsManifestSupported(int manifest_version,
                          ManifestLocation location,
                          int creation_flags,
                          std::string* warning) {
-#if BUILDFLAG(ENABLE_DESKTOP_ANDROID_EXTENSIONS)
-  if (base::FeatureList::IsEnabled(
-          extensions_features::kBlockInstallingExtensionsOnDesktopAndroid)) {
-    return false;
-  }
-#endif  // BUILDFLAG(ENABLE_DESKTOP_ANDROID_EXTENSIONS)
-
   // Supported versions are always safe.
   if (manifest_version >= kMinimumSupportedManifestVersion &&
       manifest_version <= kMaximumSupportedManifestVersion) {
@@ -318,6 +317,29 @@ GURL Extension::ResolveExtensionURL(const GURL& extension_url,
   return resolved;
 }
 
+// static
+GURL Extension::GetResourceURL(const GURL& extension_url,
+                               std::string_view relative_url) {
+  GURL resolved = Extension::ResolveExtensionURL(extension_url, relative_url);
+
+  // TODO(crbug.com/407932132): Remove this if-check and always validate the
+  // path in M142.
+  if (!base::FeatureList::IsEnabled(kValidateGetResourceURLPath)) {
+    return resolved;
+  }
+
+  // Make sure that the relative path is valid. The validation is aligned with
+  // GetResource, i.e. we don't allow retrieving resource URLs for paths that
+  // GetResource would reject.
+  base::FilePath relative_path =
+      file_util::ExtensionURLToRelativeFilePath(resolved);
+  if (ContainsReservedCharacters(relative_path)) {
+    return GURL();
+  }
+
+  return resolved;
+}
+
 bool Extension::ResourceMatches(const URLPatternSet& pattern_set,
                                 std::string_view resource) const {
   return pattern_set.MatchesURL(extension_url_.Resolve(resource));
