@@ -27,7 +27,7 @@
 #include "components/history_clusters/core/config.h"  // nogncheck
 #endif
 
-#if BUILDFLAG(ENABLE_EXTENSIONS)
+#if BUILDFLAG(ENABLE_EXTENSIONS_CORE)
 #include "extensions/common/extension_features.h"  // nogncheck
 #endif
 
@@ -62,10 +62,7 @@ int AutocompleteClassifier::DefaultOmniboxProviders(bool is_low_memory_device) {
                .show_recently_closed_tabs
            ? AutocompleteProvider::TYPE_RECENTLY_CLOSED_TABS
            : 0) |
-      (omnibox_feature_configs::ContextualSearch::Get().show_open_lens_action ||
-               omnibox_feature_configs::Toolbelt::Get().enabled
-           ? AutocompleteProvider::TYPE_CONTEXTUAL_SEARCH
-           : 0) |
+      AutocompleteProvider::TYPE_CONTEXTUAL_SEARCH |
 #else
       AutocompleteProvider::TYPE_CLIPBOARD |
       AutocompleteProvider::TYPE_MOST_VISITED_SITES |
@@ -79,6 +76,10 @@ int AutocompleteClassifier::DefaultOmniboxProviders(bool is_low_memory_device) {
       (base::FeatureList::IsEnabled(omnibox::kAndroidHubSearchTabGroups)
            ? AutocompleteProvider::TYPE_TAB_GROUP
            : 0) |
+      // Keyword search for Android.
+      (base::FeatureList::IsEnabled(omnibox::kOmniboxSiteSearch)
+           ? AutocompleteProvider::TYPE_KEYWORD
+           : 0) |
 #endif
 #if !BUILDFLAG(IS_IOS)
       (history_clusters::GetConfig().is_journeys_enabled_no_locale_check &&
@@ -107,7 +108,10 @@ int AutocompleteClassifier::DefaultOmniboxProviders(bool is_low_memory_device) {
            ? AutocompleteProvider::TYPE_HISTORY_EMBEDDINGS
            : 0) |
 #endif
-#if BUILDFLAG(ENABLE_EXTENSIONS)
+#if BUILDFLAG(ENABLE_EXTENSIONS_CORE)
+      // The `chrome.omnibox` extension API uses `TYPE_KEYWORD`, including on
+      // desktop Android.
+      AutocompleteProvider::TYPE_KEYWORD |
       // `UnscopedExtensionProvider` should only be included when extensions are
       // enabled and the `ExperimentalOmniboxLabs` feature is enabled.
       (base::FeatureList::IsEnabled(
