@@ -6,6 +6,7 @@
 
 #include <algorithm>
 #include <memory>
+#include <optional>
 #include <string>
 #include <utility>
 
@@ -31,7 +32,6 @@
 #include "base/time/time.h"
 #include "build/build_config.h"
 #include "chrome/browser/browser_process.h"
-#include "chrome/browser/download/bubble/download_bubble_prefs.h"
 #include "chrome/browser/download/download_core_service.h"
 #include "chrome/browser/download/download_core_service_factory.h"
 #include "chrome/browser/download/download_crx_util.h"
@@ -87,6 +87,7 @@
 #include "content/public/browser/download_manager.h"
 #include "content/public/browser/page_navigator.h"
 #include "content/public/browser/service_process_host.h"
+#include "content/public/common/buildflags.h"
 #include "content/public/common/origin_util.h"
 #include "extensions/buildflags/buildflags.h"
 #include "mojo/public/cpp/bindings/pending_receiver.h"
@@ -94,7 +95,6 @@
 #include "net/base/filename_util.h"
 #include "net/base/mime_util.h"
 #include "net/base/network_change_notifier.h"
-#include "ppapi/buildflags/buildflags.h"
 #include "ui/base/l10n/l10n_util.h"
 
 #if BUILDFLAG(IS_ANDROID)
@@ -164,7 +164,13 @@
 #if BUILDFLAG(ENABLE_EXTENSIONS)
 #include "chrome/browser/extensions/api/safe_browsing_private/safe_browsing_private_event_router.h"
 #include "chrome/browser/extensions/api/safe_browsing_private/safe_browsing_private_event_router_factory.h"
-#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
+#endif
+
+#if BUILDFLAG(ENTERPRISE_CLOUD_CONTENT_ANALYSIS)
+#include "chrome/browser/enterprise/connectors/reporting/reporting_event_router_factory.h"
+#include "components/enterprise/connectors/core/reporting_constants.h"
+#include "components/enterprise/connectors/core/reporting_event_router.h"
+#endif  // BUILDFLAG(ENTERPRISE_CLOUD_CONTENT_ANALYSIS)
 #endif  // BUILDFLAG(SAFE_BROWSING_DOWNLOAD_PROTECTION)
 
 using content::BrowserThread;
@@ -194,8 +200,10 @@ constexpr base::TimeDelta kEphemeralWarningLifetimeBeforeCancel =
 bool IsEphemeralWarningCancellationEnabled() {
 #if BUILDFLAG(IS_ANDROID)
   return ShouldShowSafeBrowsingAndroidDownloadWarnings();
+#elif BUILDFLAG(IS_CHROMEOS)
+  return false;
 #else
-  return download::IsDownloadBubbleEnabled();
+  return true;
 #endif
 }
 
@@ -345,6 +353,8 @@ void OnDownloadDialogClosed(
       std::move(callback).Run(DownloadConfirmationResult::CANCELED,
                               ui::SelectedFileInfo());
       break;
+    case DownloadLocationDialogResult::CONFIRMED_WITHOUT_USER_INPUT:
+      [[fallthrough]];
     case DownloadLocationDialogResult::DUPLICATE_DIALOG:
       // TODO(xingliu): Figure out the dialog behavior on multiple downloads.
       // Currently we just let other downloads continue, which doesn't make
@@ -455,9 +465,10 @@ void MaybeReportDangerousDownloadBlocked(
     }
   }
 
-#if BUILDFLAG(ENABLE_EXTENSIONS)
+#if BUILDFLAG(ENTERPRISE_CLOUD_CONTENT_ANALYSIS)
   auto* router =
-      extensions::SafeBrowsingPrivateEventRouterFactory::GetForProfile(profile);
+      enterprise_connectors::ReportingEventRouterFactory::GetForBrowserContext(
+          browser_context);
   if (router) {
     std::string raw_digest_sha256;
     if (download->GetState() == DownloadItem::DownloadState::COMPLETE) {
@@ -471,12 +482,15 @@ void MaybeReportDangerousDownloadBlocked(
     }
 
     router->OnDangerousDownloadEvent(
-        download->GetURL(), download->GetTabUrl(), download_path,
-        base::HexEncode(raw_digest_sha256), danger_type,
-        download->GetMimeType(), /*scan_id*/ "", download->GetTotalBytes(),
-        referrer_chain, enterprise_connectors::EventResult::BLOCKED);
+        download->GetURL(), download->GetTabUrl(), /*source*/ "",
+        /*destination=*/"", download_path, base::HexEncode(raw_digest_sha256),
+        danger_type, download->GetMimeType(),
+        enterprise_connectors::kFileDownloadDataTransferEventTrigger,
+        /*scan_id=*/"", /*content_transfer_method=*/"",
+        download->GetTotalBytes(), referrer_chain,
+        enterprise_connectors::EventResult::BLOCKED);
   }
-#endif  // BUILDFLAG(ENABLE_EXTENSIONS)
+#endif  // BUILDFLAG(ENTERPRISE_CLOUD_CONTENT_ANALYSIS)
 #endif  // BUILDFLAG(SAFE_BROWSING_DOWNLOAD_PROTECTION)
 }
 
@@ -692,7 +706,9 @@ bool ChromeDownloadManagerDelegate::DetermineDownloadTarget(
 #if BUILDFLAG(IS_ANDROID)
   if (base::android::BuildInfo::GetInstance()->is_desktop()) {
     action = DownloadPathReservationTracker::UNIQUIFY;
-  } else if (download->IsTransient()) {
+  }
+
+  if (download->IsTransient()) {
     if (download_path.empty() && download->GetMimeType() == pdf::kPDFMimeType &&
         !download->IsMustDownload()) {
       if (profile_->IsOffTheRecord() && download->GetDownloadFile() &&
@@ -1030,6 +1046,7 @@ bool ChromeDownloadManagerDelegate::InterceptDownloadIfApplicable(
     const std::string& request_origin,
     int64_t content_length,
     bool is_transient,
+    bool is_content_initiated,
     content::WebContents* web_contents) {
   PolicyBlocklistService* service =
       PolicyBlocklistFactory::GetForBrowserContext(profile_);
@@ -1048,7 +1065,9 @@ bool ChromeDownloadManagerDelegate::InterceptDownloadIfApplicable(
   // the download corresponds to background service. Additionally we don't want
   // offline pages backend to intercept html files explicitly marked as
   // attachments.
-  if (!is_transient &&
+  // Also, we only want to respond to browser actions, like saving pages from
+  // a context menu, not content initiated actions. See crbug.com/425492793.
+  if (!is_transient && !is_content_initiated &&
       !net::HttpContentDisposition(content_disposition, std::string())
            .is_attachment() &&
       offline_pages::OfflinePageUtils::CanDownloadAsOfflinePage(url,
