@@ -4,9 +4,12 @@
 
 #include "chrome/browser/enterprise/data_controls/reporting_service.h"
 
-#include "chrome/browser/extensions/api/safe_browsing_private/safe_browsing_private_event_router.h"
-#include "chrome/browser/extensions/api/safe_browsing_private/safe_browsing_private_event_router_factory.h"
+#include "chrome/browser/enterprise/connectors/analysis/content_analysis_info.h"
+#include "chrome/browser/enterprise/connectors/reporting/reporting_event_router_factory.h"
+#include "chrome/browser/enterprise/data_protection/content_area_user_provider.h"
 #include "chrome/browser/profiles/profile.h"
+#include "components/enterprise/connectors/core/reporting_constants.h"
+#include "components/enterprise/connectors/core/reporting_event_router.h"
 #include "components/enterprise/data_controls/core/browser/prefs.h"
 #include "components/enterprise/data_controls/core/browser/verdict.h"
 #include "components/policy/core/common/policy_types.h"
@@ -184,7 +187,7 @@ void ReportingService::ReportPaste(
     const Verdict& verdict) {
   ReportCopyOrPaste(
       source, destination, metadata, verdict,
-      extensions::SafeBrowsingPrivateEventRouter::kTriggerWebContentUpload,
+      enterprise_connectors::kWebContentUploadDataTransferEventTrigger,
       GetEventResult(verdict.level()));
 }
 
@@ -195,7 +198,7 @@ void ReportingService::ReportPasteWarningBypassed(
     const Verdict& verdict) {
   ReportCopyOrPaste(
       source, destination, metadata, verdict,
-      extensions::SafeBrowsingPrivateEventRouter::kTriggerWebContentUpload,
+      enterprise_connectors::kWebContentUploadDataTransferEventTrigger,
       enterprise_connectors::EventResult::BYPASSED);
 }
 
@@ -204,7 +207,7 @@ void ReportingService::ReportCopy(const content::ClipboardEndpoint& source,
                                   const Verdict& verdict) {
   ReportCopyOrPaste(
       source, /*destination=*/std::nullopt, metadata, verdict,
-      extensions::SafeBrowsingPrivateEventRouter::kTriggerClipboardCopy,
+      enterprise_connectors::kClipboardCopyDataTransferEventTrigger,
       GetEventResult(verdict.level()));
 }
 
@@ -214,7 +217,7 @@ void ReportingService::ReportCopyWarningBypassed(
     const Verdict& verdict) {
   ReportCopyOrPaste(
       source, /*destination=*/std::nullopt, metadata, verdict,
-      extensions::SafeBrowsingPrivateEventRouter::kTriggerClipboardCopy,
+      enterprise_connectors::kClipboardCopyDataTransferEventTrigger,
       enterprise_connectors::EventResult::BYPASSED);
 }
 
@@ -226,7 +229,7 @@ void ReportingService::ReportCopyOrPaste(
     const std::string& trigger,
     enterprise_connectors::EventResult event_result) {
   auto* router =
-      extensions::SafeBrowsingPrivateEventRouterFactory::GetForProfile(
+      enterprise_connectors::ReportingEventRouterFactory::GetForBrowserContext(
           &profile_.get());
 
   if (!router || verdict.triggered_rules().empty()) {
@@ -236,22 +239,24 @@ void ReportingService::ReportCopyOrPaste(
   GURL url;
   std::string destination_string;
   std::string source_string;
+  content::WebContents* web_contents = nullptr;
   if (trigger ==
-      extensions::SafeBrowsingPrivateEventRouter::kTriggerWebContentUpload) {
+      enterprise_connectors::kWebContentUploadDataTransferEventTrigger) {
     DCHECK(destination.has_value());
 
     url = GetURL(*destination);
     destination_string = url.spec();
     source_string = GetClipboardSourceString(source, *destination,
                                              kDataControlsRulesScopePref);
+    web_contents = destination->web_contents();
   } else {
-    DCHECK_EQ(
-        trigger,
-        extensions::SafeBrowsingPrivateEventRouter::kTriggerClipboardCopy);
+    DCHECK_EQ(trigger,
+              enterprise_connectors::kClipboardCopyDataTransferEventTrigger);
     DCHECK(!destination.has_value());
 
     url = GetURL(source);
     source_string = GetURL(source).spec();
+    web_contents = source.web_contents();
   }
 
   router->OnDataControlsSensitiveDataEvent(
@@ -261,6 +266,11 @@ void ReportingService::ReportCopyOrPaste(
       /*destination=*/destination_string,
       /*mime_type=*/GetMimeType(metadata.format_type),
       /*trigger=*/trigger,
+      /*source_active_user_email=*/
+      enterprise_data_protection::GetActiveContentAreaUser(source),
+      /*content_area_account_email=*/
+      enterprise_connectors::ContentAreaUserProvider::GetUser(
+          &profile_.get(), web_contents, url),
       /*triggered_rules=*/verdict.triggered_rules(),
       /*event_result=*/event_result,
       /*content_size=*/metadata.size.value_or(-1));
@@ -293,7 +303,7 @@ ReportingServiceFactory::ReportingServiceFactory()
               .WithSystem(ProfileSelection::kNone)
               .WithAshInternals(ProfileSelection::kNone)
               .Build()) {
-  DependsOn(extensions::SafeBrowsingPrivateEventRouterFactory::GetInstance());
+  DependsOn(enterprise_connectors::ReportingEventRouterFactory::GetInstance());
 }
 
 ReportingServiceFactory::~ReportingServiceFactory() = default;
