@@ -224,6 +224,8 @@ class ExtensionService : public ExtensionServiceInterface,
 
   void UninstallMigratedExtensionsForTest();
 
+  bool HasShutDownExecutedForTest() const { return is_shut_down_executed_; }
+
 #if defined(UNIT_TEST)
   void FinishInstallationForTest(const Extension* extension) {
     extension_registrar_->FinishInstallation(extension);
@@ -307,6 +309,10 @@ class ExtensionService : public ExtensionServiceInterface,
   // other disable reasons associated with them.
   void OnDeveloperModePrefChanged();
 
+  // Logs a warning if --extensions-on-chrome-urls switch is used in Google
+  // Chrome.
+  void LogExtensionsOnChromeUrlsSwitchWarningIfNeeded();
+
   raw_ptr<const base::CommandLine> command_line_ = nullptr;
 
   // The normal profile associated with this ExtensionService.
@@ -350,6 +356,10 @@ class ExtensionService : public ExtensionServiceInterface,
   // first time.
   bool is_first_run_ = false;
 
+  // Set to true if the ExtensionService::Shutdown() has been executed.
+  // Used in test to ensure the service's shutdown method has been called.
+  bool is_shut_down_executed_ = false;
+
   // The controller for the UI that alerts the user about any blocklisted
   // extensions. Not owned.
   raw_ptr<ExtensionErrorController> error_controller_ = nullptr;
