@@ -5,51 +5,44 @@
 #include "chrome/browser/ui/safety_hub/revoked_permissions_service.h"
 
 #include <memory>
-#include <string>
 
 #include "base/check.h"
 #include "base/feature_list.h"
 #include "base/functional/bind.h"
-#include "base/functional/callback_helpers.h"
-#include "base/json/values_util.h"
 #include "base/memory/scoped_refptr.h"
 #include "base/memory/weak_ptr.h"
-#include "base/metrics/field_trial_params.h"
 #include "base/metrics/histogram_functions.h"
-#include "base/run_loop.h"
 #include "base/strings/string_number_conversions.h"
-#include "base/task/task_traits.h"
-#include "base/task/thread_pool.h"
 #include "base/time/clock.h"
 #include "base/time/default_clock.h"
 #include "base/time/time.h"
 #include "base/values.h"
 #include "build/build_config.h"
-#include "chrome/app/chrome_command_ids.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/engagement/site_engagement_service_factory.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/ui/safety_hub/safety_hub_prefs.h"
+#include "chrome/browser/ui/safety_hub/safety_hub_result.h"
 #include "chrome/browser/ui/safety_hub/safety_hub_service.h"
 #include "chrome/browser/ui/safety_hub/safety_hub_util.h"
+#include "chrome/browser/ui/safety_hub/unused_site_permissions_manager.h"
 #include "chrome/common/chrome_features.h"
-#include "chrome/grit/generated_resources.h"
 #include "components/content_settings/core/browser/content_settings_info.h"
 #include "components/content_settings/core/browser/content_settings_registry.h"
 #include "components/content_settings/core/browser/content_settings_uma_util.h"
 #include "components/content_settings/core/browser/content_settings_utils.h"
 #include "components/content_settings/core/browser/host_content_settings_map.h"
+#include "components/content_settings/core/browser/permission_settings_registry.h"
 #include "components/content_settings/core/browser/website_settings_info.h"
 #include "components/content_settings/core/browser/website_settings_registry.h"
 #include "components/content_settings/core/common/content_settings.h"
-#include "components/content_settings/core/common/content_settings_constraints.h"
 #include "components/content_settings/core/common/content_settings_pattern.h"
 #include "components/content_settings/core/common/content_settings_types.h"
 #include "components/content_settings/core/common/content_settings_utils.h"
 #include "components/content_settings/core/common/features.h"
 #include "components/permissions/constants.h"
 #include "components/permissions/permission_uma_util.h"
-#include "components/permissions/pref_names.h"
+#include "components/permissions/permission_util.h"
 #include "components/prefs/pref_change_registrar.h"
 #include "components/prefs/pref_service.h"
 #include "components/safe_browsing/core/common/features.h"
@@ -57,8 +50,6 @@
 #include "content/public/browser/browser_context.h"
 #include "content/public/browser/browser_thread.h"
 #include "revoked_permissions_service.h"
-#include "ui/base/l10n/l10n_util.h"
-#include "url/gurl.h"
 #include "url/origin.h"
 
 #if BUILDFLAG(SAFE_BROWSING_AVAILABLE)
@@ -71,8 +62,6 @@ constexpr base::TimeDelta kRevocationThresholdWithDelayForTesting =
 
 namespace {
 
-constexpr char kUnknownContentSettingsType[] = "unknown";
-
 // Reflects the maximum number of days between a permissions being revoked and
 // the time when the user regrants the permission through the unused site
 // permission module of Safete Check. The maximum number of days is determined
@@ -115,52 +104,6 @@ bool IsChooserPermissionSupported() {
           kSafetyCheckUnusedSitePermissionsForSupportedChooserPermissions);
 }
 
-base::Value::List ConvertContentSettingsIntValuesToString(
-    const base::Value::List& content_settings_values_list,
-    bool* successful_migration) {
-  base::Value::List string_value_list;
-  for (const base::Value& setting_value : content_settings_values_list) {
-    if (setting_value.is_int()) {
-      int setting_int = setting_value.GetInt();
-      auto setting_name =
-          RevokedPermissionsService::ConvertContentSettingsTypeToKey(
-              static_cast<ContentSettingsType>(setting_int));
-      if (setting_name == kUnknownContentSettingsType) {
-        *successful_migration = false;
-        string_value_list.Append(setting_value.GetInt());
-      } else {
-        string_value_list.Append(setting_name);
-      }
-    } else {
-      DCHECK(setting_value.is_string());
-      // Store string group name values.
-      string_value_list.Append(setting_value.GetString());
-    }
-  }
-  return string_value_list;
-}
-
-base::Value::Dict ConvertChooserContentSettingsIntValuesToString(
-    const base::Value::Dict& chooser_content_settings_values_dict) {
-  base::Value::Dict string_keyed_dict;
-  for (const auto [key, value] : chooser_content_settings_values_dict) {
-    int number = -1;
-    base::StringToInt(key, &number);
-    // If number conversion fails it returns 0 which is not a chooser permission
-    // enum value so it will not clash with the conversion.
-    if (number == 0) {
-      // Store string keyed values as is.
-      string_keyed_dict.Set(key, value.GetDict().Clone());
-    } else {
-      string_keyed_dict.Set(
-          RevokedPermissionsService::ConvertContentSettingsTypeToKey(
-              static_cast<ContentSettingsType>(number)),
-          value.GetDict().Clone());
-    }
-  }
-  return string_keyed_dict;
-}
-
 content_settings::ContentSettingConstraints GetConstraintFromInfo(
     const content_settings::SettingInfo& info) {
   auto constraint = content_settings::ContentSettingConstraints(
@@ -195,45 +138,6 @@ bool IsDisruptiveNotificationPermissionRevocation(
 
 }  // namespace
 
-// static
-std::string RevokedPermissionsService::ConvertContentSettingsTypeToKey(
-    ContentSettingsType type) {
-  auto* website_setting_registry =
-      content_settings::WebsiteSettingsRegistry::GetInstance();
-  DCHECK(website_setting_registry);
-
-  auto* website_settings_info = website_setting_registry->Get(type);
-  if (!website_settings_info) {
-    auto integer_type = static_cast<int32_t>(type);
-    DVLOG(1) << "Couldn't retrieve website settings info entry from the "
-                "registry for type: "
-             << integer_type;
-    base::UmaHistogramSparse(
-        "Settings.SafetyCheck.UnusedSitePermissionsMigrationFail",
-        integer_type);
-    return kUnknownContentSettingsType;
-  }
-
-  return website_settings_info->name();
-}
-
-// static
-ContentSettingsType RevokedPermissionsService::ConvertKeyToContentSettingsType(
-    const std::string& key) {
-  auto* website_setting_registry =
-      content_settings::WebsiteSettingsRegistry::GetInstance();
-  return website_setting_registry->GetByName(key)->type();
-}
-
-// static
-url::Origin RevokedPermissionsService::ConvertPrimaryPatternToOrigin(
-    const ContentSettingsPattern& primary_pattern) {
-  GURL origin_url = GURL(primary_pattern.ToString());
-  CHECK(origin_url.is_valid());
-
-  return url::Origin::Create(origin_url);
-}
-
 base::TimeDelta RevokedPermissionsService::GetRepeatedUpdateInterval() {
   return content_settings::features::
       kSafetyCheckUnusedSitePermissionsRepeatedUpdateInterval.Get();
@@ -261,106 +165,6 @@ PermissionsData::PermissionsData(const PermissionsData& other)
   chooser_permissions_data = other.chooser_permissions_data.Clone();
 }
 
-RevokedPermissionsService::RevokedPermissionsResult::
-    RevokedPermissionsResult() = default;
-RevokedPermissionsService::RevokedPermissionsResult::
-    ~RevokedPermissionsResult() = default;
-
-RevokedPermissionsService::RevokedPermissionsResult::RevokedPermissionsResult(
-    const RevokedPermissionsResult&) = default;
-
-std::unique_ptr<SafetyHubService::Result>
-RevokedPermissionsService::RevokedPermissionsResult::Clone() const {
-  return std::make_unique<RevokedPermissionsResult>(*this);
-}
-
-void RevokedPermissionsService::RevokedPermissionsResult::AddRevokedPermission(
-    PermissionsData permissions_data) {
-  revoked_permissions_.push_back(std::move(permissions_data));
-}
-
-const std::list<PermissionsData>&
-RevokedPermissionsService::RevokedPermissionsResult::GetRevokedPermissions() {
-  return revoked_permissions_;
-}
-
-std::set<ContentSettingsPattern>
-RevokedPermissionsService::RevokedPermissionsResult::GetRevokedOrigins() const {
-  std::set<ContentSettingsPattern> origins;
-  for (const auto& permission : revoked_permissions_) {
-    origins.insert(permission.primary_pattern);
-  }
-  return origins;
-}
-
-base::Value::Dict
-RevokedPermissionsService::RevokedPermissionsResult::ToDictValue() const {
-  base::Value::Dict result = BaseToDictValue();
-  base::Value::List revoked_origins;
-  for (const auto& permission : revoked_permissions_) {
-    revoked_origins.Append(permission.primary_pattern.ToString());
-  }
-  result.Set(kRevokedPermissionsResultKey, std::move(revoked_origins));
-  return result;
-}
-
-bool RevokedPermissionsService::RevokedPermissionsResult::
-    IsTriggerForMenuNotification() const {
-  // A menu notification should be shown when there is at least one permission
-  // that was revoked.
-  return !GetRevokedOrigins().empty();
-}
-
-bool RevokedPermissionsService::RevokedPermissionsResult::
-    WarrantsNewMenuNotification(
-        const base::Value::Dict& previous_result_dict) const {
-  std::set<ContentSettingsPattern> old_origins;
-  for (const base::Value& origin_val :
-       *previous_result_dict.FindList(kRevokedPermissionsResultKey)) {
-    // Before crrev.com/c/5000387, the revoked permissions were stored in a dict
-    // that looked as follows:
-    // {
-    //    "origin": "site.com",
-    //    "permissionTypes": [...permissions],
-    //    "expiration": TimeValue
-    // }
-    // After this CL, the list was updated to a list of strings representing
-    // the origins. To maintain backwards compatibility, support these
-    // old values for now. This check can be deleted in the future.
-    const std::string* origin_str{};
-    if (origin_val.is_dict()) {
-      const base::Value::Dict& revoked_permission = origin_val.GetDict();
-      origin_str = revoked_permission.FindString(kSafetyHubOriginKey);
-    } else if (origin_val.is_string()) {
-      origin_str = &origin_val.GetString();
-    } else {
-      NOTREACHED();
-    }
-    ContentSettingsPattern origin =
-        ContentSettingsPattern::FromString(*origin_str);
-    old_origins.insert(origin);
-  }
-
-  std::set<ContentSettingsPattern> new_origins = GetRevokedOrigins();
-  return !std::ranges::includes(old_origins, new_origins);
-}
-
-std::u16string
-RevokedPermissionsService::RevokedPermissionsResult::GetNotificationString()
-    const {
-  if (revoked_permissions_.empty()) {
-    return std::u16string();
-  }
-  return l10n_util::GetPluralStringFUTF16(
-      IDS_SETTINGS_SAFETY_HUB_REVOKED_PERMISSIONS_MENU_NOTIFICATION,
-      revoked_permissions_.size());
-}
-
-int RevokedPermissionsService::RevokedPermissionsResult::
-    GetNotificationCommandId() const {
-  return IDC_OPEN_SAFETY_HUB;
-}
-
 void RevokedPermissionsService::TabHelper::PrimaryPageChanged(
     content::Page& page) {
   Profile* profile =
@@ -432,14 +236,8 @@ RevokedPermissionsService::RevokedPermissionsService(
                 browser_context_));
   }
 
-  bool migration_completed = pref_change_registrar_->prefs()->GetBoolean(
-      safety_hub_prefs::kUnusedSitePermissionsRevocationMigrationCompleted);
-  if (!migration_completed) {
-    // Convert all integer permission values to string, if there is any
-    // permission represented by integer stored in disk.
-    // TODO(crbug.com/41495119): Clean up this migration after some milestones.
-    UpdateIntegerValuesToGroupName();
-  }
+  unused_site_permissions_manager_ =
+      std::make_unique<UnusedSitePermissionsManager>(browser_context, prefs);
 
   InitializeLatestResult();
 
@@ -460,7 +258,7 @@ void RevokedPermissionsService::MaybeStartRepeatedUpdates() {
   }
 }
 
-std::unique_ptr<SafetyHubService::Result>
+std::unique_ptr<SafetyHubResult>
 RevokedPermissionsService::InitializeLatestResultImpl() {
   return GetRevokedPermissions();
 }
@@ -556,7 +354,8 @@ void RevokedPermissionsService::RegrantPermissionsForOrigin(
     // Look up ContentSettingsRegistry to see if type is content setting
     // or website setting.
     ContentSettingsType type =
-        ConvertKeyToContentSettingsType(permission_type.GetString());
+        UnusedSitePermissionsManager::ConvertKeyToContentSettingsType(
+            permission_type.GetString());
     if (IsContentSetting(type)) {
       // ContentSettingsRegistry-based permissions with ALLOW value were
       // revoked; re-grant them by setting ALLOW again.
@@ -571,15 +370,17 @@ void RevokedPermissionsService::RegrantPermissionsForOrigin(
       // Chooser permissions are WebsiteSettingsRegistry-based, so it is
       // re-granted by restoring the previously revoked Website Setting value.
       auto* revoked_value = chooser_permissions_data->FindDict(
-          ConvertContentSettingsTypeToKey(type));
+          UnusedSitePermissionsManager::ConvertContentSettingsTypeToKey(type));
       DCHECK(revoked_value);
       hcsm()->SetWebsiteSettingCustomScope(
           info.primary_pattern, info.secondary_pattern, type,
           base::Value(std::move(*revoked_value)));
     } else {
-      NOTREACHED() << "Unable to find ContentSettingsType in neither "
-                   << "ContentSettingsRegistry nor WebsiteSettingsRegistry: "
-                   << ConvertContentSettingsTypeToKey(type);
+      NOTREACHED()
+          << "Unable to find ContentSettingsType in neither "
+          << "ContentSettingsRegistry nor WebsiteSettingsRegistry: "
+          << UnusedSitePermissionsManager::ConvertContentSettingsTypeToKey(
+                 type);
     }
   }
   // Set this back to false, so that `OnContentSettingChanged` can cleanup
@@ -643,9 +444,11 @@ void RevokedPermissionsService::UndoRegrantPermissionsForOrigin(
           permissions_data.primary_pattern.ToRepresentativeUrl(), GURL(),
           permission, base::Value());
     } else {
-      NOTREACHED() << "Unable to find ContentSettingsType in neither "
-                   << "ContentSettingsRegistry nor WebsiteSettingsRegistry: "
-                   << ConvertContentSettingsTypeToKey(permission);
+      NOTREACHED()
+          << "Unable to find ContentSettingsType in neither "
+          << "ContentSettingsRegistry nor WebsiteSettingsRegistry: "
+          << UnusedSitePermissionsManager::ConvertContentSettingsTypeToKey(
+                 permission);
     }
   }
   // Set this back to false, so that `OnContentSettingChanged` can cleanup
@@ -728,13 +531,13 @@ void RevokedPermissionsService::DeletePatternFromRevokedPermissionList(
       ContentSettingsType::REVOKED_UNUSED_SITE_PERMISSIONS, {});
 }
 
-base::OnceCallback<std::unique_ptr<SafetyHubService::Result>()>
+base::OnceCallback<std::unique_ptr<SafetyHubResult>()>
 RevokedPermissionsService::GetBackgroundTask() {
   return base::BindOnce(&RevokedPermissionsService::UpdateOnBackgroundThread,
                         clock_, base::WrapRefCounted(hcsm()));
 }
 
-std::unique_ptr<SafetyHubService::Result>
+std::unique_ptr<SafetyHubResult>
 RevokedPermissionsService::UpdateOnBackgroundThread(
     base::Clock* clock,
     const scoped_refptr<HostContentSettingsMap> hcsm) {
@@ -767,25 +570,22 @@ RevokedPermissionsService::UpdateOnBackgroundThread(
         // origin. Therefore, it has a fully defined URL+scheme+port which makes
         // converting primary pattern to origin successful.
         url::Origin origin =
-            ConvertPrimaryPatternToOrigin(setting.primary_pattern);
+            UnusedSitePermissionsManager::ConvertPrimaryPatternToOrigin(
+                setting.primary_pattern);
         recently_unused[origin.Serialize()].push_back(
             {type, std::move(setting)});
       }
     }
   }
 
-  auto result =
-      std::make_unique<RevokedPermissionsService::RevokedPermissionsResult>();
+  auto result = std::make_unique<RevokedPermissionsResult>();
   result->SetRecentlyUnusedPermissions(recently_unused);
   return std::move(result);
 }
 
-std::unique_ptr<SafetyHubService::Result>
-RevokedPermissionsService::UpdateOnUIThread(
-    std::unique_ptr<SafetyHubService::Result> result) {
-  auto* interim_result =
-      static_cast<RevokedPermissionsService::RevokedPermissionsResult*>(
-          result.get());
+std::unique_ptr<SafetyHubResult> RevokedPermissionsService::UpdateOnUIThread(
+    std::unique_ptr<SafetyHubResult> result) {
+  auto* interim_result = static_cast<RevokedPermissionsResult*>(result.get());
   recently_unused_permissions_ = interim_result->GetRecentlyUnusedPermissions();
   if (IsUnusedSiteAutoRevocationEnabled()) {
     RevokeUnusedPermissions();
@@ -799,12 +599,11 @@ RevokedPermissionsService::UpdateOnUIThread(
   return GetRevokedPermissions();
 }
 
-std::unique_ptr<RevokedPermissionsService::RevokedPermissionsResult>
+std::unique_ptr<RevokedPermissionsResult>
 RevokedPermissionsService::GetRevokedPermissions() {
   ContentSettingsForOneType settings = hcsm()->GetSettingsForOneType(
       ContentSettingsType::REVOKED_UNUSED_SITE_PERMISSIONS);
-  auto result =
-      std::make_unique<RevokedPermissionsService::RevokedPermissionsResult>();
+  auto result = std::make_unique<RevokedPermissionsResult>();
 
   for (const auto& revoked_permissions : settings) {
     PermissionsData permissions_data;
@@ -822,7 +621,8 @@ RevokedPermissionsService::GetRevokedPermissions() {
       }
 
       ContentSettingsType type =
-          ConvertKeyToContentSettingsType(type_value.GetString());
+          UnusedSitePermissionsManager::ConvertKeyToContentSettingsType(
+              type_value.GetString());
       permissions_data.permission_types.insert(type);
     }
 
@@ -977,8 +777,8 @@ void RevokedPermissionsService::RevokeUnusedPermissions() {
          permission_itr != unused_site_permissions.end();) {
       const ContentSettingEntry& entry = *permission_itr;
       // Check if the current permission can be auto revoked.
-      if (!content_settings::CanBeAutoRevoked(entry.type,
-                                              entry.source.setting_value)) {
+      if (!content_settings::CanBeAutoRevoked(
+              /*type=*/entry.type, /*value=*/entry.source.setting_value)) {
         permission_itr++;
         continue;
       }
@@ -1011,7 +811,8 @@ void RevokedPermissionsService::RevokeUnusedPermissions() {
         } else if (IsChooserPermissionSupported() &&
                    IsWebsiteSetting(entry.type)) {
           chooser_permissions_data.Set(
-              ConvertContentSettingsTypeToKey(entry.type),
+              UnusedSitePermissionsManager::ConvertContentSettingsTypeToKey(
+                  entry.type),
               entry.source.setting_value.Clone());
           hcsm()->SetWebsiteSettingCustomScope(entry.source.primary_pattern,
                                                entry.source.secondary_pattern,
@@ -1020,7 +821,8 @@ void RevokedPermissionsService::RevokeUnusedPermissions() {
           NOTREACHED()
               << "Unable to find ContentSettingsType in neither "
               << "ContentSettingsRegistry nor WebsiteSettingsRegistry: "
-              << ConvertContentSettingsTypeToKey(entry.type);
+              << UnusedSitePermissionsManager::ConvertContentSettingsTypeToKey(
+                     entry.type);
         }
         unused_site_permissions.erase(permission_itr++);
       } else {
@@ -1116,8 +918,11 @@ void RevokedPermissionsService::StorePermissionInUnusedSitePermissionSetting(
     // corresponding data to be restored in `chooser_permissions_data`.
     DCHECK(IsContentSetting(permission) || !IsChooserPermissionSupported() ||
            chooser_permissions_data.contains(
-               ConvertContentSettingsTypeToKey(permission)));
-    permission_type_list.Append(ConvertContentSettingsTypeToKey(permission));
+               UnusedSitePermissionsManager::ConvertContentSettingsTypeToKey(
+                   permission)));
+    permission_type_list.Append(
+        UnusedSitePermissionsManager::ConvertContentSettingsTypeToKey(
+            permission));
   }
 
   dict.Set(permissions::kRevokedKey,
@@ -1132,7 +937,9 @@ void RevokedPermissionsService::StorePermissionInUnusedSitePermissionSetting(
     for (auto data : chooser_permissions_data) {
       // Chooser permissions data should have its permission type included in
       // `permissions` set.
-      DCHECK(permissions.contains(ConvertKeyToContentSettingsType(data.first)));
+      DCHECK(permissions.contains(
+          UnusedSitePermissionsManager::ConvertKeyToContentSettingsType(
+              data.first)));
       existing_chooser_permissions_data.Set(data.first, data.second.Clone());
     }
     dict.Set(permissions::kRevokedChooserPermissionsKey,
@@ -1161,7 +968,7 @@ void RevokedPermissionsService::OnPermissionsAutorevocationControlChanged() {
   }
 }
 
-std::vector<RevokedPermissionsService::ContentSettingEntry>
+std::vector<ContentSettingEntry>
 RevokedPermissionsService::GetTrackedUnusedPermissionsForTesting() {
   std::vector<ContentSettingEntry> result;
   for (const auto& list : recently_unused_permissions_) {
@@ -1213,56 +1020,3 @@ RevokedPermissionsService::GetRevokedUnusedSitePermissionTypes(
   }
   return permissions_without_revoked_abusive_notification_manager;
 }
-
-void RevokedPermissionsService::UpdateIntegerValuesToGroupName() {
-  ContentSettingsForOneType settings = hcsm()->GetSettingsForOneType(
-      ContentSettingsType::REVOKED_UNUSED_SITE_PERMISSIONS);
-
-  bool successful_migration = true;
-  for (const auto& revoked_permissions : settings) {
-    const base::Value& stored_value = revoked_permissions.setting_value;
-    DCHECK(stored_value.is_dict());
-    base::Value updated_dict(stored_value.Clone());
-
-    const base::Value::List* permission_value_list =
-        stored_value.GetDict().FindList(permissions::kRevokedKey);
-    if (permission_value_list) {
-      base::Value::List updated_permission_value_list =
-          ConvertContentSettingsIntValuesToString(
-              permission_value_list->Clone(), &successful_migration);
-      updated_dict.GetDict().Set(permissions::kRevokedKey,
-                                 std::move(updated_permission_value_list));
-    }
-
-    const base::Value::Dict* chooser_permission_value_dict =
-        stored_value.GetDict().FindDict(
-            permissions::kRevokedChooserPermissionsKey);
-    if (chooser_permission_value_dict) {
-      base::Value::Dict updated_chooser_permission_value_dict =
-          ConvertChooserContentSettingsIntValuesToString(
-              chooser_permission_value_dict->Clone());
-      updated_dict.GetDict().Set(
-          permissions::kRevokedChooserPermissionsKey,
-          std::move(updated_chooser_permission_value_dict));
-    }
-
-    // Create a new constraint with the old creation time of the original
-    // exception.
-    base::Time creation_time = revoked_permissions.metadata.expiration() -
-                               revoked_permissions.metadata.lifetime();
-    content_settings::ContentSettingConstraints constraints(creation_time);
-    constraints.set_lifetime(revoked_permissions.metadata.lifetime());
-
-    hcsm()->SetWebsiteSettingCustomScope(
-        revoked_permissions.primary_pattern,
-        revoked_permissions.secondary_pattern,
-        ContentSettingsType::REVOKED_UNUSED_SITE_PERMISSIONS,
-        std::move(updated_dict), constraints);
-  }
-
-  if (successful_migration) {
-    pref_change_registrar_->prefs()->SetBoolean(
-        safety_hub_prefs::kUnusedSitePermissionsRevocationMigrationCompleted,
-        true);
-  }
-}
