@@ -25,6 +25,7 @@
 #include "chrome/browser/ui/views/side_panel/side_panel_entry_id.h"
 #include "chrome/browser/ui/views/side_panel/side_panel_enums.h"
 #include "chrome/browser/ui/views/side_panel/side_panel_ui.h"
+#include "chrome/common/chrome_features.h"
 #include "chrome/common/webui_url_constants.h"
 #include "chrome/grit/branded_strings.h"
 #include "chrome/grit/generated_resources.h"
@@ -105,8 +106,8 @@ void ToastService::RegisterToasts(
   // updated.
   toast_registry_->RegisterToast(
       ToastId::kNonMilestoneUpdate,
-      ToastSpecification::Builder(kLinkChromeRefreshIcon,
-                                  IDS_LINK_COPIED_TOAST_BODY)
+      ToastSpecification::Builder(kBrowserLogoIcon,
+                                  IDS_NON_MILESTONE_UPDATE_TOAST_BODY)
           .AddGlobalScoped()
           .Build());
 
@@ -250,6 +251,16 @@ void ToastService::RegisterToasts(
                                     IDS_DATA_SHARING_TOAST_BLOCK_LEAVE)
             .AddGlobalScoped()
             .Build());
+
+    // The version has been updated and shared tab groups is enabled again.
+    toast_registry_->RegisterToast(
+        ToastId::kTabGroupSharingVersionUpToDate,
+        ToastSpecification::Builder(
+            kTabGroupSharingIcon,
+            IDS_COLLABORATION_SHARED_TAB_GROUPS_AVAILABLE_AGAIN_IPH_MESSAGE)
+            .AddCloseButton()
+            .AddGlobalScoped()
+            .Build());
   }
 
   if (toast_features::IsEnabled(toast_features::kPinnedTabToastOnClose)) {
@@ -260,4 +271,28 @@ void ToastService::RegisterToasts(
             .Build());
   }
 
+  if (features::kGlicActorUiToast.Get()) {
+    toast_registry_->RegisterToast(
+        ToastId::kGeminiWorkingOnTask,
+        ToastSpecification::Builder(kScreensaverAutoIcon,
+                                    IDS_GEMINI_WORKING_ON_TASK_BODY)
+            .AddCloseButton()
+            .Build());
+  }
+
+  toast_registry_->RegisterToast(
+      ToastId::kDiceUserMigrated,
+      ToastSpecification::Builder(vector_icons::kCelebrationIcon,
+                                  IDS_DICE_MIGRATION_CONFIRMATION_TOAST_MESSAGE)
+          .AddCloseButton()
+          .AddActionButton(IDS_DICE_MIGRATION_CONFIRMATION_TOAST_BUTTON,
+                           base::BindRepeating(
+                               [](BrowserWindowInterface* window) {
+                                 chrome::ShowSettingsSubPageForProfile(
+                                     window->GetProfile(),
+                                     chrome::kSyncSetupSubPage);
+                               },
+                               base::Unretained(browser_window_interface)))
+          .AddGlobalScoped()
+          .Build());
 }  // RegisterToasts() end.
