@@ -11,7 +11,6 @@
 #include "build/build_config.h"
 #include "components/commerce/core/commerce_constants.h"
 #include "components/history_clusters/history_clusters_internals/webui/url_constants.h"
-#include "components/nacl/common/buildflags.h"
 #include "components/optimization_guide/optimization_guide_internals/webui/url_constants.h"
 #include "components/password_manager/content/common/web_ui_constants.h"
 #include "components/safe_browsing/core/common/web_ui_constants.h"
@@ -84,6 +83,7 @@ base::span<const base::cstring_view> ChromeURLHosts() {
       kChromeUIChromeURLsHost,
       kChromeUIComponentsHost,
       commerce::kChromeUICommerceInternalsHost,
+      kChromeUIConnectorsInternalsHost,
       kChromeUICrashesHost,
       kChromeUICreditsHost,
 #if BUILDFLAG(IS_CHROMEOS) && !defined(OFFICIAL_BUILD)
@@ -193,10 +193,6 @@ base::span<const base::cstring_view> ChromeURLHosts() {
       kChromeUIInternetDetailDialogHost,
       kChromeUIAssistantOptInHost,
 #endif
-#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX) || \
-    BUILDFLAG(IS_CHROMEOS)
-      kChromeUIConnectorsInternalsHost,
-#endif
 #if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX) || \
     BUILDFLAG(IS_CHROMEOS) || BUILDFLAG(IS_DESKTOP_ANDROID)
       kChromeUIDiscardsHost,
@@ -214,9 +210,6 @@ base::span<const base::cstring_view> ChromeURLHosts() {
 #if BUILDFLAG(IS_WIN)
       kChromeUIConflictsHost,
 #endif
-#if BUILDFLAG(ENABLE_NACL)
-      kChromeUINaClHost,
-#endif
 #if BUILDFLAG(ENABLE_EXTENSIONS_CORE)
       kChromeUIExtensionsHost,
       kChromeUIExtensionsInternalsHost,
@@ -228,6 +221,9 @@ base::span<const base::cstring_view> ChromeURLHosts() {
 #if BUILDFLAG(IS_CHROMEOS)
       kChromeUIDlpInternalsHost,
 #endif  // BUILDFLAG(IS_CHROMEOS)
+#if !BUILDFLAG(IS_ANDROID)
+      kChromeUIWebuiBrowserHost,
+#endif  // !BUILDFLAG(IS_ANDROID)
   });
 
   return base::span(kChromeURLHosts);
