@@ -519,6 +519,12 @@ void ExtensionRegistrar::AddComponentExtension(const Extension* extension) {
             << old_version_string << "' to "
             << extension->version().GetString();
 
+    // If there was a previous installation, we need to clear the extension
+    // service worker. This is a workaround to ensure component extension
+    // updates are applied. See crbug.com/425464855.
+    if (old_version.IsValid()) {
+      UnregisterServiceWorkerWithRootScope(extension);
+    }
     // TODO(crbug.com/40508457): If needed, add support for Declarative Net
     // Request to component extensions and pass the ruleset install prefs here.
     AddNewOrUpdatedExtension(extension, {}, kInstallFlagNone,
