@@ -233,50 +233,37 @@ HostPermissionsAccess GetHostPermissionAccessLevelForExtension(
   return HostPermissionsAccess::kOnClick;
 }
 
-void LogHostPermissionsAccess(const Extension& extension,
-                              bool should_record_incremented_metrics) {
+// Emits metrics for the host permissions access that an extension has. Meant to
+// be called only for profiles where users can install extensions, specifically
+// profiles that can have non-component extensions installed.
+void LogHostPermissionsAccess(const Extension& extension) {
   HostPermissionsAccess access_level =
       GetHostPermissionAccessLevelForExtension(extension);
-  // Extensions.HostPermissions.GrantedAccess is emitted for every
-  // extension.
-  base::UmaHistogramEnumeration("Extensions.HostPermissions.GrantedAccess",
+  // Extensions.HostPermissions.GrantedAccess is emitted for every extension.
+  base::UmaHistogramEnumeration("Extensions.HostPermissions.GrantedAccess2",
                                 access_level);
-  if (should_record_incremented_metrics) {
-    base::UmaHistogramEnumeration("Extensions.HostPermissions.GrantedAccess2",
-                                  access_level);
-  }
 
   const PermissionSet& active_permissions =
       extension.permissions_data()->active_permissions();
   const PermissionSet& withheld_permissions =
       extension.permissions_data()->withheld_permissions();
 
-  // Since we only care about host permissions here, we don't want to
-  // look at API permissions that might cause Chrome to warn about all hosts
-  // (like debugger or devtools).
+  // Since we only care about host permissions here, we don't want to look at
+  // API permissions that might cause Chrome to warn about all hosts (like
+  // debugger or devtools).
   static constexpr bool kIncludeApiPermissions = false;
   if (active_permissions.ShouldWarnAllHosts(kIncludeApiPermissions) ||
       withheld_permissions.ShouldWarnAllHosts(kIncludeApiPermissions)) {
     // Extension requests access to at least one eTLD.
     base::UmaHistogramEnumeration(
-        "Extensions.HostPermissions.GrantedAccessForBroadRequests",
+        "Extensions.HostPermissions.GrantedAccessForBroadRequests2",
         access_level);
-    if (should_record_incremented_metrics) {
-      base::UmaHistogramEnumeration(
-          "Extensions.HostPermissions.GrantedAccessForBroadRequests2",
-          access_level);
-    }
   } else if (!active_permissions.effective_hosts().is_empty() ||
              !withheld_permissions.effective_hosts().is_empty()) {
     // Extension requests access to hosts, but not eTLD.
     base::UmaHistogramEnumeration(
-        "Extensions.HostPermissions.GrantedAccessForTargetedRequests",
+        "Extensions.HostPermissions.GrantedAccessForTargetedRequests2",
         access_level);
-    if (should_record_incremented_metrics) {
-      base::UmaHistogramEnumeration(
-          "Extensions.HostPermissions.GrantedAccessForTargetedRequests2",
-          access_level);
-    }
   }
 }
 
@@ -418,24 +405,15 @@ void InstalledLoader::LoadAllExtensions(Profile* profile) {
     }
   }
 
-  UMA_HISTOGRAM_COUNTS_100("Extensions.LoadAll",
-                           extension_registry_->enabled_extensions().size());
-  UMA_HISTOGRAM_COUNTS_100("Extensions.Disabled",
-                           extension_registry_->disabled_extensions().size());
+  const base::TimeDelta load_all_time =
+      base::TimeTicks::Now() - load_start_time;
   if (is_user_profile) {
     UMA_HISTOGRAM_COUNTS_100("Extensions.LoadAll2",
                              extension_registry_->enabled_extensions().size());
     UMA_HISTOGRAM_COUNTS_100("Extensions.Disabled2",
                              extension_registry_->disabled_extensions().size());
-  }
-
-  RecordExtensionsMetrics(profile, is_user_profile);
-
-  const base::TimeDelta load_all_time =
-      base::TimeTicks::Now() - load_start_time;
-  UMA_HISTOGRAM_TIMES("Extensions.LoadAllTime2", load_all_time);
-  if (is_user_profile) {
     UMA_HISTOGRAM_TIMES("Extensions.LoadAllTime2.User", load_all_time);
+    RecordExtensionsMetrics(profile);
   } else {
     UMA_HISTOGRAM_TIMES("Extensions.LoadAllTime2.NonUser", load_all_time);
   }
@@ -445,38 +423,28 @@ void InstalledLoader::LoadAllExtensions(Profile* profile) {
 void InstalledLoader::RecordPermissionMessagesHistogram(
     const Extension* extension,
     const char* histogram_basename,
-    bool log_user_profile_histograms) {
+    Profile* profile) {
+  DCHECK(profile_util::ProfileCanUseNonComponentExtensions(profile));
+
   PermissionIDSet permissions =
       PermissionMessageProvider::Get()->GetAllPermissionIDs(
           extension->permissions_data()->active_permissions(),
           extension->GetType());
+
   base::UmaHistogramBoolean(
-      base::StringPrintf("Extensions.HasPermissions_%s3", histogram_basename),
+      base::StringPrintf("Extensions.HasPermissions_%s4", histogram_basename),
       !permissions.empty());
 
-  std::string permissions_histogram_name =
-      base::StringPrintf("Extensions.Permissions_%s3", histogram_basename);
+  std::string permissions_histogram_name_incremented =
+      base::StringPrintf("Extensions.Permissions_%s4", histogram_basename);
   for (const PermissionID& id : permissions) {
-    base::UmaHistogramEnumeration(permissions_histogram_name, id.id());
-  }
-
-  if (log_user_profile_histograms) {
-    base::UmaHistogramBoolean(
-        base::StringPrintf("Extensions.HasPermissions_%s4", histogram_basename),
-        !permissions.empty());
-
-    std::string permissions_histogram_name_incremented =
-        base::StringPrintf("Extensions.Permissions_%s4", histogram_basename);
-    for (const PermissionID& id : permissions) {
-      base::UmaHistogramEnumeration(permissions_histogram_name_incremented,
-                                    id.id());
-    }
+    base::UmaHistogramEnumeration(permissions_histogram_name_incremented,
+                                  id.id());
   }
 }
 
 void InstalledLoader::RecordExtensionsMetricsForTesting() {
-  RecordExtensionsMetrics(profile_,
-                          /*is_user_profile=*/false);
+  RecordExtensionsMetrics(profile_);
 }
 
 void InstalledLoader::RecordExtensionsIncrementedMetricsForTesting(
@@ -485,18 +453,17 @@ void InstalledLoader::RecordExtensionsIncrementedMetricsForTesting(
 }
 
 // TODO(crbug.com/40739895): Separate out Webstore/Offstore metrics.
-void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
-                                              bool is_user_profile) {
+void InstalledLoader::RecordExtensionsMetrics(Profile* profile) {
+  DCHECK(profile_util::ProfileCanUseNonComponentExtensions(profile));
+
   int app_user_count = 0;
   int app_external_count = 0;
   int hosted_app_count = 0;
   int legacy_packaged_app_count = 0;
   int platform_app_count = 0;
-  int user_script_count = 0;
   int extension_user_count = 0;
   int extension_external_count = 0;
   int theme_count = 0;
-  int page_action_count = 0;
   int browser_action_count = 0;
   int no_action_count = 0;
   int disabled_for_permissions_count = 0;
@@ -527,7 +494,6 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
   ManifestVersion2And3Counts component_manifest_version_counts;
   ManifestVersion2And3Counts unpacked_manifest_version_counts;
 
-  bool should_record_incremented_metrics = is_user_profile;
   bool dev_mode_enabled =
       GetCurrentDeveloperMode(util::GetBrowserContextId(profile));
 
@@ -544,19 +510,14 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
     // muck up any of the stats. Later, though, we want to omit component and
     // unpacked, as they are less interesting.
 
-    if (extension->is_app() && should_record_incremented_metrics) {
+    if (extension->is_app()) {
       UMA_HISTOGRAM_ENUMERATION("Extensions.AppLocation2", location);
     } else if (extension->is_extension()) {
-      UMA_HISTOGRAM_ENUMERATION("Extensions.ExtensionLocation", location);
-      if (should_record_incremented_metrics) {
-        UMA_HISTOGRAM_ENUMERATION("Extensions.ExtensionLocation2", location);
-      }
+      UMA_HISTOGRAM_ENUMERATION("Extensions.ExtensionLocation2", location);
     }
+
     if (!UpdatesFromWebstore(*extension)) {
-      UMA_HISTOGRAM_ENUMERATION("Extensions.NonWebstoreLocation", location);
-      if (should_record_incremented_metrics) {
-        UMA_HISTOGRAM_ENUMERATION("Extensions.NonWebstoreLocation2", location);
-      }
+      UMA_HISTOGRAM_ENUMERATION("Extensions.NonWebstoreLocation2", location);
 
       // Check for inconsistencies if the extension was supposedly installed
       // from the webstore.
@@ -567,13 +528,9 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
         kDeprecatedIsExternal = 1,
       };
       if (extension->from_webstore()) {
-        UMA_HISTOGRAM_ENUMERATION("Extensions.FromWebstoreInconsistency",
+        UMA_HISTOGRAM_ENUMERATION("Extensions.FromWebstoreInconsistency2",
                                   kBadUpdateUrl, 2);
-        if (should_record_incremented_metrics) {
-          UMA_HISTOGRAM_ENUMERATION("Extensions.FromWebstoreInconsistency2",
-                                    kBadUpdateUrl, 2);
-        }
-      } else if (is_user_profile) {
+      } else {
         // Record enabled non-webstore extensions based on developer mode
         // status.
         if (dev_mode_enabled) {
@@ -588,27 +545,17 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
       }
     }
 
-    if (is_user_profile) {
-      base::UmaHistogramBoolean("Extensions.DeveloperModeEnabled",
-                                dev_mode_enabled);
-    }
+    base::UmaHistogramBoolean("Extensions.DeveloperModeEnabled",
+                              dev_mode_enabled);
 
     if (Manifest::IsExternalLocation(location)) {
       // See loop below for DISABLED.
       if (UpdatesFromWebstore(*extension)) {
-        base::UmaHistogramEnumeration("Extensions.ExternalItemState",
+        base::UmaHistogramEnumeration("Extensions.ExternalItemState2",
                                       ExternalItemState::kWebstoreEnabled);
-        if (should_record_incremented_metrics) {
-          base::UmaHistogramEnumeration("Extensions.ExternalItemState2",
-                                        ExternalItemState::kWebstoreEnabled);
-        }
       } else {
-        base::UmaHistogramEnumeration("Extensions.ExternalItemState",
+        base::UmaHistogramEnumeration("Extensions.ExternalItemState2",
                                       ExternalItemState::kNonwebstoreEnabled);
-        if (should_record_incremented_metrics) {
-          base::UmaHistogramEnumeration("Extensions.ExternalItemState2",
-                                        ExternalItemState::kNonwebstoreEnabled);
-        }
       }
     }
 
@@ -628,7 +575,7 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
     // Manifest::TYPE_EXTENSION. An ungrouped histogram is below, includes all
     // extension-y types (such as platform apps and hosted apps), and doesn't
     // include unpacked or component locations.
-    if (extension->is_extension() && is_user_profile) {
+    if (extension->is_extension()) {
       const char* location_histogram_name = nullptr;
       ManifestVersion2And3Counts* manifest_version_counts = nullptr;
       switch (extension->location()) {
@@ -728,22 +675,16 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
       continue;
     }
 
-    if (should_record_incremented_metrics) {
-      UMA_HISTOGRAM_ENUMERATION("Extensions.ManifestVersion2",
-                                extension->manifest_version(),
-                                kMaxManifestVersion);
-    }
+    UMA_HISTOGRAM_ENUMERATION("Extensions.ManifestVersion2",
+                              extension->manifest_version(),
+                              kMaxManifestVersion);
 
     // We might have wanted to count legacy packaged apps here, too, since they
     // are effectively extensions. Unfortunately, it's too late, as we don't
     // want to mess up the existing stats.
     if (type == Manifest::TYPE_EXTENSION) {
-      base::UmaHistogramEnumeration("Extensions.BackgroundPageType",
+      base::UmaHistogramEnumeration("Extensions.BackgroundPageType2",
                                     GetBackgroundPageType(extension));
-      if (should_record_incremented_metrics) {
-        base::UmaHistogramEnumeration("Extensions.BackgroundPageType2",
-                                      GetBackgroundPageType(extension));
-      }
 
       if (GetBackgroundPageType(extension) == BackgroundPageType::kEventPage) {
         // Count extension event pages with no registered events. Either the
@@ -760,18 +701,14 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
     // Using an enumeration shows us the total installed ratio across all users.
     // Using the totals per user at each startup tells us the distribution of
     // usage for each user (e.g. 40% of users have at least one app installed).
-    UMA_HISTOGRAM_ENUMERATION(
-        "Extensions.LoadType", type, Manifest::NUM_LOAD_TYPES);
-    if (should_record_incremented_metrics) {
-      UMA_HISTOGRAM_ENUMERATION("Extensions.LoadType2", type,
-                                Manifest::NUM_LOAD_TYPES);
-    }
+    UMA_HISTOGRAM_ENUMERATION("Extensions.LoadType2", type,
+                              Manifest::NUM_LOAD_TYPES);
     switch (type) {
       case Manifest::TYPE_THEME:
         ++theme_count;
         break;
       case Manifest::TYPE_USER_SCRIPT:
-        ++user_script_count;
+        // No histogram.
         break;
       case Manifest::TYPE_HOSTED_APP:
         ++hosted_app_count;
@@ -811,16 +748,17 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
     // we want to know how many extensions have a given type of action as part
     // of their code, rather than as part of the extension action redesign
     // (which gives each extension an action).
+    // TODO(devlin): This is wrong -- it's not counting manifest_keys::kAction,
+    // which is the most popular (and only allowed option in MV3+).
     if (extension->manifest()->FindKey(manifest_keys::kPageAction)) {
-      ++page_action_count;
+      // No histogram.
     } else if (extension->manifest()->FindKey(manifest_keys::kBrowserAction)) {
       ++browser_action_count;
     } else {
       ++no_action_count;
     }
 
-    RecordPermissionMessagesHistogram(extension, "Load",
-                                      should_record_incremented_metrics);
+    RecordPermissionMessagesHistogram(extension, "Load", profile);
 
     // For incognito and file access, skip anything that doesn't appear in
     // settings. Also, policy-installed (and unpacked of course, checked above)
@@ -854,13 +792,8 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
       bool extension_has_withheld_hosts =
           permissions_manager->HasWithheldHostPermissions(*extension);
       UMA_HISTOGRAM_BOOLEAN(
-          "Extensions.RuntimeHostPermissions.ExtensionHasWithheldHosts",
+          "Extensions.RuntimeHostPermissions.ExtensionHasWithheldHosts2",
           extension_has_withheld_hosts);
-      if (should_record_incremented_metrics) {
-        UMA_HISTOGRAM_BOOLEAN(
-            "Extensions.RuntimeHostPermissions.ExtensionHasWithheldHosts2",
-            extension_has_withheld_hosts);
-      }
       if (extension_has_withheld_hosts) {
         // Record the number of granted hosts if and only if the extension
         // has withheld host permissions. This lets us equate "0" granted
@@ -880,18 +813,12 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
         // permissions). We could potentially also record the granted hosts that
         // were explicitly not requested.
         UMA_HISTOGRAM_COUNTS_100(
-            "Extensions.RuntimeHostPermissions.GrantedHostCount",
+            "Extensions.RuntimeHostPermissions.GrantedHostCount2",
             num_granted_hosts);
-        if (should_record_incremented_metrics) {
-          UMA_HISTOGRAM_COUNTS_100(
-              "Extensions.RuntimeHostPermissions.GrantedHostCount2",
-              num_granted_hosts);
-        }
       }
     }
 
-    LogHostPermissionsAccess(*extension, should_record_incremented_metrics);
-
+    LogHostPermissionsAccess(*extension);
     if (ExtensionAllowlist::Get(profile)->GetExtensionAllowlistState(
             extension->id()) == ALLOWLIST_NOT_ALLOWLISTED) {
       // Record the number of not allowlisted enabled extensions.
@@ -901,49 +828,34 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
 
   const ExtensionSet& disabled_extensions =
       extension_registry_->disabled_extensions();
-
   for (const scoped_refptr<const Extension>& disabled_extension :
        disabled_extensions) {
-    mojom::ManifestLocation location = disabled_extension->location();
+    mojom::ManifestLocation disabled_location = disabled_extension->location();
     if (extension_prefs_->DidExtensionEscalatePermissions(
             disabled_extension->id())) {
       ++disabled_for_permissions_count;
     }
-    if (should_record_incremented_metrics) {
-      RecordDisableReasons(
-          extension_prefs_->GetDisableReasons(disabled_extension->id()));
-    }
-    if (Manifest::IsExternalLocation(location)) {
+    RecordDisableReasons(
+        extension_prefs_->GetDisableReasons(disabled_extension->id()));
+    if (Manifest::IsExternalLocation(disabled_location)) {
       // See loop above for ENABLED.
-      if (UpdatesFromWebstore(*disabled_extension)) {
-        base::UmaHistogramEnumeration("Extensions.ExternalItemState",
-                                      ExternalItemState::kWebstoreDisabled);
-        if (should_record_incremented_metrics) {
-          base::UmaHistogramEnumeration("Extensions.ExternalItemState2",
-                                        ExternalItemState::kWebstoreDisabled);
-        }
-      } else {
-        base::UmaHistogramEnumeration("Extensions.ExternalItemState",
-                                      ExternalItemState::kNonwebstoreDisabled);
-        if (should_record_incremented_metrics) {
-          base::UmaHistogramEnumeration(
-              "Extensions.ExternalItemState2",
-              ExternalItemState::kNonwebstoreDisabled);
-        }
-      }
+      ExternalItemState state = UpdatesFromWebstore(*disabled_extension)
+                                    ? ExternalItemState::kWebstoreDisabled
+                                    : ExternalItemState::kNonwebstoreDisabled;
+      base::UmaHistogramEnumeration("Extensions.ExternalItemState2", state);
     }
 
     // Record disabled non-webstore extensions based on developer mode status.
-    if (is_user_profile && !UpdatesFromWebstore(*disabled_extension) &&
+    if (!UpdatesFromWebstore(*disabled_extension) &&
         !disabled_extension->from_webstore()) {
       if (dev_mode_enabled) {
         base::UmaHistogramEnumeration(
             "Extensions.NonWebstoreLocationWithDeveloperModeOn.Disabled3",
-            location);
+            disabled_location);
       } else {
         base::UmaHistogramEnumeration(
             "Extensions.NonWebstoreLocationWithDeveloperModeOff.Disabled3",
-            location);
+            disabled_location);
       }
     }
 
@@ -954,210 +866,131 @@ void InstalledLoader::RecordExtensionsMetrics(Profile* profile,
     }
   }
 
-  if (is_user_profile) {
-    base::UmaHistogramCounts100(
-        "Extensions.ManifestVersion2Count.Internal",
-        internal_manifest_version_counts.version_2_count);
-    base::UmaHistogramCounts100(
-        "Extensions.ManifestVersion3Count.Internal",
-        internal_manifest_version_counts.version_3_count);
-    base::UmaHistogramCounts100(
-        "Extensions.ManifestVersion2Count.External",
-        external_manifest_version_counts.version_2_count);
-    base::UmaHistogramCounts100(
-        "Extensions.ManifestVersion3Count.External",
-        external_manifest_version_counts.version_3_count);
-    base::UmaHistogramCounts100(
-        "Extensions.ManifestVersion2Count.Component",
-        component_manifest_version_counts.version_2_count);
-    base::UmaHistogramCounts100(
-        "Extensions.ManifestVersion3Count.Component",
-        component_manifest_version_counts.version_3_count);
-    base::UmaHistogramCounts100("Extensions.ManifestVersion2Count.Policy",
-                                policy_manifest_version_counts.version_2_count);
-    base::UmaHistogramCounts100("Extensions.ManifestVersion3Count.Policy",
-                                policy_manifest_version_counts.version_3_count);
-    base::UmaHistogramCounts100(
-        "Extensions.ManifestVersion2Count.Unpacked",
-        unpacked_manifest_version_counts.version_2_count);
-    base::UmaHistogramCounts100(
-        "Extensions.ManifestVersion3Count.Unpacked",
-        unpacked_manifest_version_counts.version_3_count);
+  base::UmaHistogramCounts100("Extensions.ManifestVersion2Count.Internal",
+                              internal_manifest_version_counts.version_2_count);
+  base::UmaHistogramCounts100("Extensions.ManifestVersion3Count.Internal",
+                              internal_manifest_version_counts.version_3_count);
+  base::UmaHistogramCounts100("Extensions.ManifestVersion2Count.External",
+                              external_manifest_version_counts.version_2_count);
+  base::UmaHistogramCounts100("Extensions.ManifestVersion3Count.External",
+                              external_manifest_version_counts.version_3_count);
+  base::UmaHistogramCounts100(
+      "Extensions.ManifestVersion2Count.Component",
+      component_manifest_version_counts.version_2_count);
+  base::UmaHistogramCounts100(
+      "Extensions.ManifestVersion3Count.Component",
+      component_manifest_version_counts.version_3_count);
+  base::UmaHistogramCounts100("Extensions.ManifestVersion2Count.Policy",
+                              policy_manifest_version_counts.version_2_count);
+  base::UmaHistogramCounts100("Extensions.ManifestVersion3Count.Policy",
+                              policy_manifest_version_counts.version_3_count);
+  base::UmaHistogramCounts100("Extensions.ManifestVersion2Count.Unpacked",
+                              unpacked_manifest_version_counts.version_2_count);
+  base::UmaHistogramCounts100("Extensions.ManifestVersion3Count.Unpacked",
+                              unpacked_manifest_version_counts.version_3_count);
 
-    auto get_manifest_version_population_split =
-        [](const ManifestVersion2And3Counts& counts) {
-          if (counts.version_2_count == 0 && counts.version_3_count == 0) {
-            return ManifestVersionPopulationSplit::kNoExtensions;
-          }
-          if (counts.version_2_count > 0 && counts.version_3_count == 0) {
-            return ManifestVersionPopulationSplit::kMv2ExtensionsOnly;
-          }
-          if (counts.version_3_count > 0 && counts.version_2_count == 0) {
-            return ManifestVersionPopulationSplit::kMv3ExtensionsOnly;
-          }
-          return ManifestVersionPopulationSplit::kMv2AndMv3Extensions;
-        };
-    base::UmaHistogramEnumeration(
-        "Extensions.ManifestVersionPopulationSplit.Internal",
-        get_manifest_version_population_split(
-            internal_manifest_version_counts));
-    base::UmaHistogramEnumeration(
-        "Extensions.ManifestVersionPopulationSplit.External",
-        get_manifest_version_population_split(
-            external_manifest_version_counts));
-    base::UmaHistogramEnumeration(
-        "Extensions.ManifestVersionPopulationSplit.Component",
-        get_manifest_version_population_split(
-            component_manifest_version_counts));
-    base::UmaHistogramEnumeration(
-        "Extensions.ManifestVersionPopulationSplit.Unpacked",
-        get_manifest_version_population_split(
-            unpacked_manifest_version_counts));
-    ManifestVersion2And3Counts internal_and_external_counts;
-    internal_and_external_counts.version_2_count =
-        internal_manifest_version_counts.version_2_count +
-        external_manifest_version_counts.version_2_count;
-    internal_and_external_counts.version_3_count =
-        internal_manifest_version_counts.version_3_count +
-        external_manifest_version_counts.version_3_count;
-    // We log an additional one for the combination of internal and external
-    // since these are both "user controlled" and not unpacked.
-    base::UmaHistogramEnumeration(
-        "Extensions.ManifestVersionPopulationSplit.InternalAndExternal",
-        get_manifest_version_population_split(
-            internal_manifest_version_counts));
-  }
+  auto get_manifest_version_population_split =
+      [](const ManifestVersion2And3Counts& counts) {
+        if (counts.version_2_count == 0 && counts.version_3_count == 0) {
+          return ManifestVersionPopulationSplit::kNoExtensions;
+        }
+        if (counts.version_2_count > 0 && counts.version_3_count == 0) {
+          return ManifestVersionPopulationSplit::kMv2ExtensionsOnly;
+        }
+        if (counts.version_3_count > 0 && counts.version_2_count == 0) {
+          return ManifestVersionPopulationSplit::kMv3ExtensionsOnly;
+        }
+        return ManifestVersionPopulationSplit::kMv2AndMv3Extensions;
+      };
+  base::UmaHistogramEnumeration(
+      "Extensions.ManifestVersionPopulationSplit.Internal",
+      get_manifest_version_population_split(internal_manifest_version_counts));
+  base::UmaHistogramEnumeration(
+      "Extensions.ManifestVersionPopulationSplit.External",
+      get_manifest_version_population_split(external_manifest_version_counts));
+  base::UmaHistogramEnumeration(
+      "Extensions.ManifestVersionPopulationSplit.Component",
+      get_manifest_version_population_split(component_manifest_version_counts));
+  base::UmaHistogramEnumeration(
+      "Extensions.ManifestVersionPopulationSplit.Unpacked",
+      get_manifest_version_population_split(unpacked_manifest_version_counts));
+  ManifestVersion2And3Counts internal_and_external_counts;
+  internal_and_external_counts.version_2_count =
+      internal_manifest_version_counts.version_2_count +
+      external_manifest_version_counts.version_2_count;
+  internal_and_external_counts.version_3_count =
+      internal_manifest_version_counts.version_3_count +
+      external_manifest_version_counts.version_3_count;
+  // We log an additional one for the combination of internal and external
+  // since these are both "user controlled" and not unpacked.
+  base::UmaHistogramEnumeration(
+      "Extensions.ManifestVersionPopulationSplit.InternalAndExternal",
+      get_manifest_version_population_split(internal_manifest_version_counts));
 
-  base::UmaHistogramCounts100("Extensions.LoadApp",
+  base::UmaHistogramCounts100("Extensions.LoadApp2",
                               app_user_count + app_external_count);
-  base::UmaHistogramCounts100("Extensions.LoadAppUser", app_user_count);
-  base::UmaHistogramCounts100("Extensions.LoadAppExternal", app_external_count);
-  base::UmaHistogramCounts100("Extensions.LoadHostedApp", hosted_app_count);
-  base::UmaHistogramCounts100("Extensions.LoadPackagedApp",
+  base::UmaHistogramCounts100("Extensions.LoadAppUser2", app_user_count);
+  base::UmaHistogramCounts100("Extensions.LoadAppExternal2",
+                              app_external_count);
+  base::UmaHistogramCounts100("Extensions.LoadHostedApp2", hosted_app_count);
+  base::UmaHistogramCounts100("Extensions.LoadPackagedApp2",
                               legacy_packaged_app_count);
-  base::UmaHistogramCounts100("Extensions.LoadPlatformApp", platform_app_count);
-  base::UmaHistogramCounts100("Extensions.LoadExtension",
+  base::UmaHistogramCounts100("Extensions.LoadPlatformApp2",
+                              platform_app_count);
+  base::UmaHistogramCounts100("Extensions.LoadExtension2",
                               extension_user_count + extension_external_count);
-  base::UmaHistogramCounts100("Extensions.LoadExtensionExternal",
+  base::UmaHistogramCounts100("Extensions.LoadExtensionUser2",
+                              extension_user_count);
+  base::UmaHistogramCounts100("Extensions.LoadExtensionExternal2",
                               extension_external_count);
-  base::UmaHistogramCounts100("Extensions.LoadTheme", theme_count);
-  // Histogram name different for legacy reasons.
-  base::UmaHistogramCounts100("PageActionController.ExtensionsWithPageActions",
-                              page_action_count);
-  base::UmaHistogramCounts100("Extensions.LoadBrowserAction",
+  base::UmaHistogramCounts100("Extensions.LoadTheme2", theme_count);
+  base::UmaHistogramCounts100("Extensions.LoadBrowserAction2",
                               browser_action_count);
-  base::UmaHistogramCounts100("Extensions.LoadNoExtensionAction",
+  base::UmaHistogramCounts100("Extensions.LoadNoExtensionAction2",
                               no_action_count);
-  base::UmaHistogramCounts100("Extensions.DisabledForPermissions",
+  base::UmaHistogramCounts100("Extensions.DisabledForPermissions2",
                               disabled_for_permissions_count);
-  base::UmaHistogramCounts100("Extensions.NonWebStoreNewTabPageOverrides",
+  base::UmaHistogramCounts100("Extensions.NonWebStoreNewTabPageOverrides2",
                               non_webstore_ntp_override_count);
-  base::UmaHistogramCounts100("Extensions.NewTabPageOverrides",
+  base::UmaHistogramCounts100("Extensions.NewTabPageOverrides2",
                               ntp_override_count);
-  base::UmaHistogramCounts100("Extensions.SearchEngineOverrides",
+  base::UmaHistogramCounts100("Extensions.SearchEngineOverrides2",
                               search_engine_override_count);
-  base::UmaHistogramCounts100("Extensions.StartupPagesOverrides",
+  base::UmaHistogramCounts100("Extensions.StartupPagesOverrides2",
                               startup_pages_override_count);
-  base::UmaHistogramCounts100("Extensions.HomepageOverrides",
+  base::UmaHistogramCounts100("Extensions.HomepageOverrides2",
                               homepage_override_count);
-  if (should_record_incremented_metrics) {
-    base::UmaHistogramCounts100("Extensions.LoadApp2",
-                                app_user_count + app_external_count);
-    base::UmaHistogramCounts100("Extensions.LoadAppUser2", app_user_count);
-    base::UmaHistogramCounts100("Extensions.LoadAppExternal2",
-                                app_external_count);
-    base::UmaHistogramCounts100("Extensions.LoadHostedApp2", hosted_app_count);
-    base::UmaHistogramCounts100("Extensions.LoadPackagedApp2",
-                                legacy_packaged_app_count);
-    base::UmaHistogramCounts100("Extensions.LoadPlatformApp2",
-                                platform_app_count);
-    base::UmaHistogramCounts100(
-        "Extensions.LoadExtension2",
-        extension_user_count + extension_external_count);
-    base::UmaHistogramCounts100("Extensions.LoadExtensionUser2",
-                                extension_user_count);
-    base::UmaHistogramCounts100("Extensions.LoadExtensionExternal2",
-                                extension_external_count);
-    base::UmaHistogramCounts100("Extensions.LoadUserScript2",
-                                user_script_count);
-    base::UmaHistogramCounts100("Extensions.LoadTheme2", theme_count);
-    base::UmaHistogramCounts100("Extensions.ExtensionsWithPageActions",
-                                page_action_count);
-    base::UmaHistogramCounts100("Extensions.LoadBrowserAction2",
-                                browser_action_count);
-    base::UmaHistogramCounts100("Extensions.LoadNoExtensionAction2",
-                                no_action_count);
-    base::UmaHistogramCounts100("Extensions.DisabledForPermissions2",
-                                disabled_for_permissions_count);
-    base::UmaHistogramCounts100("Extensions.NonWebStoreNewTabPageOverrides2",
-                                non_webstore_ntp_override_count);
-    base::UmaHistogramCounts100("Extensions.NewTabPageOverrides2",
-                                ntp_override_count);
-    base::UmaHistogramCounts100("Extensions.SearchEngineOverrides2",
-                                search_engine_override_count);
-    base::UmaHistogramCounts100("Extensions.StartupPagesOverrides2",
-                                startup_pages_override_count);
-    base::UmaHistogramCounts100("Extensions.HomepageOverrides2",
-                                homepage_override_count);
-  }
 
   if (incognito_allowed_count + incognito_not_allowed_count > 0) {
-    base::UmaHistogramCounts100("Extensions.IncognitoAllowed",
+    base::UmaHistogramCounts100("Extensions.IncognitoAllowed2",
                                 incognito_allowed_count);
-    if (should_record_incremented_metrics) {
-      base::UmaHistogramCounts100("Extensions.IncognitoAllowed2",
-                                  incognito_allowed_count);
-    }
   }
-  if (file_access_allowed_count + file_access_not_allowed_count > 0 &&
-      should_record_incremented_metrics) {
+  if (file_access_allowed_count + file_access_not_allowed_count > 0) {
     base::UmaHistogramCounts100("Extensions.FileAccessAllowed2",
                                 file_access_allowed_count);
     base::UmaHistogramCounts100("Extensions.FileAccessNotAllowed2",
                                 file_access_not_allowed_count);
   }
-  base::UmaHistogramCounts100(
-      "Extensions.CorruptExtensionTotalDisables",
-      extension_prefs_->GetPrefAsInteger(kCorruptedDisableCount));
-  base::UmaHistogramCounts100("Extensions.LoadOffStoreItems",
-                              off_store_item_count);
-  base::UmaHistogramCounts100("Extensions.WebRequestBlockingCount",
-                              web_request_blocking_count);
-  base::UmaHistogramCounts100("Extensions.WebRequestCount", web_request_count);
-  base::UmaHistogramCounts100("Extensions.NotAllowlistedEnabled",
-                              enabled_not_allowlisted_count);
-  base::UmaHistogramCounts100("Extensions.NotAllowlistedDisabled",
-                              disabled_not_allowlisted_count);
 
-  if (should_record_incremented_metrics) {
-    base::UmaHistogramCounts100(
-        "Extensions.CorruptExtensionTotalDisables2",
-        extension_prefs_->GetPrefAsInteger(kCorruptedDisableCount));
-    base::UmaHistogramCounts100("Extensions.EventlessEventPages2",
-                                eventless_event_pages_count);
-    base::UmaHistogramCounts100("Extensions.LoadOffStoreItems2",
-                                off_store_item_count);
-    base::UmaHistogramCounts100("Extensions.WebRequestBlockingCount2",
-                                web_request_blocking_count);
-    base::UmaHistogramCounts100("Extensions.WebRequestCount2",
-                                web_request_count);
-    base::UmaHistogramCounts100("Extensions.NotAllowlistedEnabled2",
-                                enabled_not_allowlisted_count);
-    base::UmaHistogramCounts100("Extensions.NotAllowlistedDisabled2",
-                                disabled_not_allowlisted_count);
-  }
+  base::UmaHistogramCounts100(
+      "Extensions.CorruptExtensionTotalDisables2",
+      extension_prefs_->GetPrefAsInteger(kCorruptedDisableCount));
+  base::UmaHistogramCounts100("Extensions.EventlessEventPages2",
+                              eventless_event_pages_count);
+  base::UmaHistogramCounts100("Extensions.LoadOffStoreItems2",
+                              off_store_item_count);
+  base::UmaHistogramCounts100("Extensions.WebRequestBlockingCount2",
+                              web_request_blocking_count);
+  base::UmaHistogramCounts100("Extensions.WebRequestCount2", web_request_count);
+  base::UmaHistogramCounts100("Extensions.NotAllowlistedEnabled2",
+                              enabled_not_allowlisted_count);
+  base::UmaHistogramCounts100("Extensions.NotAllowlistedDisabled2",
+                              disabled_not_allowlisted_count);
   if (safe_browsing::IsEnhancedProtectionEnabled(*profile->GetPrefs())) {
-    base::UmaHistogramCounts100("Extensions.NotAllowlistedEnabledAndEsbUser",
+    base::UmaHistogramCounts100("Extensions.NotAllowlistedEnabledAndEsbUser2",
                                 enabled_not_allowlisted_count);
-    base::UmaHistogramCounts100("Extensions.NotAllowlistedDisabledAndEsbUser",
+    base::UmaHistogramCounts100("Extensions.NotAllowlistedDisabledAndEsbUser2",
                                 disabled_not_allowlisted_count);
-    if (should_record_incremented_metrics) {
-      base::UmaHistogramCounts100("Extensions.NotAllowlistedEnabledAndEsbUser2",
-                                  enabled_not_allowlisted_count);
-      base::UmaHistogramCounts100(
-          "Extensions.NotAllowlistedDisabledAndEsbUser2",
-          disabled_not_allowlisted_count);
-    }
   }
 }
 
