@@ -19,12 +19,12 @@
 #include "base/strings/utf_string_conversions.h"
 #include "build/build_config.h"
 #include "build/buildflag.h"
-#include "chrome/browser/bookmarks/bookmark_model_factory.h"
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/content_settings/cookie_settings_factory.h"
 #include "chrome/browser/content_settings/host_content_settings_map_factory.h"
 #include "chrome/browser/enterprise/util/managed_browser_utils.h"
 #include "chrome/browser/metrics/chrome_metrics_service_accessor.h"
+#include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/profiles/profile_attributes_entry.h"
 #include "chrome/browser/profiles/profile_attributes_storage.h"
 #include "chrome/browser/profiles/profile_manager.h"
@@ -33,12 +33,12 @@
 #include "chrome/browser/signin/chrome_device_id_helper.h"
 #include "chrome/browser/signin/force_signin_verifier.h"
 #include "chrome/browser/signin/identity_manager_factory.h"
+#include "chrome/browser/signin/signin_hats_util.h"
 #include "chrome/browser/signin/signin_util.h"
+#include "chrome/browser/ui/hats/survey_config.h"
 #include "chrome/common/buildflags.h"
 #include "chrome/common/channel_info.h"
 #include "chrome/common/pref_names.h"
-#include "components/bookmarks/browser/bookmark_model.h"
-#include "components/bookmarks/browser/url_and_title.h"
 #include "components/content_settings/core/browser/cookie_settings.h"
 #include "components/metrics/metrics_service.h"
 #include "components/policy/core/browser/browser_policy_connector.h"
@@ -75,7 +75,6 @@
 #endif
 
 #if !BUILDFLAG(IS_ANDROID)
-#include "chrome/browser/profiles/profile_window.h"
 #include "chrome/browser/ui/browser.h"
 #endif
 
@@ -88,12 +87,6 @@
 #include "chrome/browser/signin/wait_for_network_callback_helper_chrome.h"
 #endif
 
-#if BUILDFLAG(ENABLE_EXTENSIONS)
-#include "extensions/browser/extension_registry.h"
-#include "extensions/browser/extension_registry_factory.h"
-#include "extensions/common/manifest.h"
-#endif
-
 #if BUILDFLAG(ENABLE_BOUND_SESSION_CREDENTIALS)
 #include "chrome/browser/signin/bound_session_credentials/bound_session_cookie_refresh_service.h"
 #include "chrome/browser/signin/bound_session_credentials/bound_session_cookie_refresh_service_factory.h"
@@ -161,75 +154,36 @@ signin_metrics::ProfileSignout kAlwaysAllowedSignoutSources[] = {
     signin_metrics::ProfileSignout::kMovePrimaryAccount,
     // Allowed as the profile is being deleted anyway.
     signin_metrics::ProfileSignout::kSignoutDuringProfileDeletion,
+    // Allowed as the user declined the enterprise management disclaimer.
+    signin_metrics::ProfileSignout::kUserDeclinedEnterpriseManagementDisclaimer,
 };
 
-// Returns the histogram suffix name per group of `signin_metrics::AccessPoint`.
-std::string_view NameOfGroupedAccessPointHistogram(
+// Returns the HaTS survey trigger corresponding to the given AccessPoint, or
+// the empty string if there is no such survey.
+std::string HatsSurveyTriggerForAccessPoint(
     signin_metrics::AccessPoint access_point) {
   switch (access_point) {
-    case signin_metrics::AccessPoint::kWebSignin:
-      return ".PreUnoWebSignin";
-    case signin_metrics::AccessPoint::kChromeSigninInterceptBubble:
-      return ".UnoSigninBubble";
-    case signin_metrics::AccessPoint::kUserManager:
-    case signin_metrics::AccessPoint::kForYouFre:
-    case signin_metrics::AccessPoint::kSigninInterceptFirstRunExperience:
-    case signin_metrics::AccessPoint::kStartPage:
-      return ".ProfileCreation";
+#if BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_WIN)
+    case signin_metrics::AccessPoint::kAddressBubble:
+      return kHatsSurveyTriggerIdentityAddressBubbleSignin;
     case signin_metrics::AccessPoint::kAvatarBubbleSignIn:
-      return ".ProfileMenu";
+    case signin_metrics::AccessPoint::kAvatarBubbleSignInWithSyncPromo:
+      return kHatsSurveyTriggerIdentityProfileMenuSignin;
+    case signin_metrics::AccessPoint::kForYouFre:
+      return kHatsSurveyTriggerIdentityFirstRunSignin;
+    case signin_metrics::AccessPoint::kPasswordBubble:
+      return kHatsSurveyTriggerIdentityPasswordBubbleSignin;
+    case signin_metrics::AccessPoint::kSigninInterceptFirstRunExperience:
+      return kHatsSurveyTriggerIdentitySigninInterceptProfileSeparation;
+    case signin_metrics::AccessPoint::kUserManager:
+      return kHatsSurveyTriggerIdentityProfilePickerAddProfileSignin;
+#endif  // BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_WIN)
     default:
-      return ".Other";
+      // No HaTS survey is defined for the rest of the access point.
+      return std::string();
   }
 }
 
-void RecordBookmarksCounts(signin_metrics::AccessPoint access_point,
-                           signin::ConsentLevel consent_level,
-                           size_t all_bookmarks_count,
-                           size_t bar_bookmarks_count) {
-  static constexpr std::string_view kBaseHistogramName = "Signin.Bookmarks";
-
-  std::string_view consent_level_token =
-      consent_level == signin::ConsentLevel::kSignin ? ".OnSignin" : ".OnSync";
-
-  std::string all_bookmarks_histogram_name =
-      base::StrCat({kBaseHistogramName, consent_level_token, ".AllBookmarks"});
-  base::UmaHistogramCounts1000(all_bookmarks_histogram_name,
-                               all_bookmarks_count);
-  base::UmaHistogramCounts1000(
-      base::StrCat({all_bookmarks_histogram_name,
-                    NameOfGroupedAccessPointHistogram(access_point)}),
-      all_bookmarks_count);
-
-  std::string bar_bookmarks_histogram_name =
-      base::StrCat({kBaseHistogramName, consent_level_token, ".BookmarksBar"});
-  base::UmaHistogramCounts1000(bar_bookmarks_histogram_name,
-                               bar_bookmarks_count);
-  base::UmaHistogramCounts1000(
-      base::StrCat({bar_bookmarks_histogram_name,
-                    NameOfGroupedAccessPointHistogram(access_point)}),
-      bar_bookmarks_count);
-}
-
-#if BUILDFLAG(ENABLE_EXTENSIONS)
-void RecordExtensionsCounts(signin_metrics::AccessPoint access_point,
-                            signin::ConsentLevel consent_level,
-                            int extensions_count) {
-  static constexpr std::string_view kBaseHistogramName = "Signin.Extensions";
-
-  std::string_view consent_level_token =
-      consent_level == signin::ConsentLevel::kSignin ? ".OnSignin" : ".OnSync";
-
-  base::UmaHistogramCounts1000(
-      base::StrCat({kBaseHistogramName, consent_level_token}),
-      extensions_count);
-  base::UmaHistogramCounts1000(
-      base::StrCat({kBaseHistogramName, consent_level_token,
-                    NameOfGroupedAccessPointHistogram(access_point)}),
-      extensions_count);
-}
-#endif
-
 }  // namespace
 
 ChromeSigninClient::ChromeSigninClient(Profile* profile)
@@ -472,24 +426,12 @@ void ChromeSigninClient::OnPrimaryAccountChanged(
         signin_metrics::AccessPoint access_point =
             event_details.GetSetPrimaryAccountAccessPoint().value();
 
-        std::optional<size_t> all_bookmarks_count = GetAllBookmarksCount();
-        std::optional<size_t> bar_bookmarks_count =
-            GetBookmarkBarBookmarksCount();
-        if (all_bookmarks_count.has_value() &&
-            bar_bookmarks_count.has_value()) {
-          RecordBookmarksCounts(access_point, consent_level,
-                                all_bookmarks_count.value(),
-                                bar_bookmarks_count.value());
+        if (consent_level == signin::ConsentLevel::kSignin) {
+          std::string trigger = HatsSurveyTriggerForAccessPoint(access_point);
+          signin::LaunchSigninHatsSurveyForProfile(
+              trigger, profile_, /*defer_if_no_browser=*/true);
         }
 
-#if BUILDFLAG(ENABLE_EXTENSIONS)
-        std::optional<size_t> extensions_count = GetExtensionsCount();
-        if (extensions_count.has_value()) {
-          RecordExtensionsCounts(access_point, consent_level,
-                                 extensions_count.value());
-        }
-#endif
-
 #if !BUILDFLAG(IS_CHROMEOS)
         RecordOpenTabCount(access_point, consent_level);
 #endif
@@ -503,18 +445,18 @@ void ChromeSigninClient::OnPrimaryAccountChanged(
   }
 }
 
-#if BUILDFLAG(ENABLE_BOUND_SESSION_CREDENTIALS)
 std::unique_ptr<signin::BoundSessionOAuthMultiLoginDelegate>
 ChromeSigninClient::CreateBoundSessionOAuthMultiloginDelegate() const {
+#if BUILDFLAG(ENABLE_BOUND_SESSION_CREDENTIALS)
   if (BoundSessionCookieRefreshService* bound_session_cookie_refresh_service =
           BoundSessionCookieRefreshServiceFactory::GetForProfile(profile_);
       bound_session_cookie_refresh_service) {
     return std::make_unique<BoundSessionOAuthMultiLoginDelegateImpl>(
         bound_session_cookie_refresh_service->GetWeakPtr());
   }
+#endif  // BUILDFLAG(ENABLE_BOUND_SESSION_CREDENTIALS)
   return nullptr;
 }
-#endif
 
 SigninClient::SignoutDecision ChromeSigninClient::GetSignoutDecision(
     bool has_sync_account,
@@ -593,65 +535,6 @@ void ChromeSigninClient::OnTokenFetchComplete(bool token_is_valid) {
 }
 #endif
 
-std::optional<size_t> ChromeSigninClient::GetAllBookmarksCount() {
-  bookmarks::BookmarkModel* bookmarks =
-      BookmarkModelFactory::GetForBrowserContext(profile_);
-  if (!bookmarks || !bookmarks->root_node()) {
-    return std::nullopt;
-  }
-
-  // Recursive traversal of the root node, counting URLs only.
-  size_t count = 0;
-  ui::TreeNodeIterator<const bookmarks::BookmarkNode> iterator(
-      bookmarks->root_node());
-  while (iterator.has_next()) {
-    const bookmarks::BookmarkNode* const node = iterator.Next();
-    // Skip folders.
-    if (node->is_url()) {
-      ++count;
-    }
-  }
-  return count;
-}
-
-std::optional<size_t> ChromeSigninClient::GetBookmarkBarBookmarksCount() {
-  bookmarks::BookmarkModel* bookmarks =
-      BookmarkModelFactory::GetForBrowserContext(profile_);
-  if (!bookmarks || !bookmarks->bookmark_bar_node()) {
-    return std::nullopt;
-  }
-
-  // It is intended that we only count the visible bookmarks on the bar, meaning
-  // we are not interested in the bookmarks within a folder or subfolder of the
-  // bar. Counting the children only gets us the first layer that appears on the
-  // bar which is the count we need (Note: a folder on that layer counts as 1).
-  return bookmarks->bookmark_bar_node()->children().size();
-}
-
-#if BUILDFLAG(ENABLE_EXTENSIONS)
-std::optional<size_t> ChromeSigninClient::GetExtensionsCount() {
-  extensions::ExtensionRegistry* registry =
-      extensions::ExtensionRegistryFactory::GetForBrowserContext(profile_);
-  if (!registry) {
-    return std::nullopt;
-  }
-
-  size_t user_installed_extension_count = 0;
-  for (auto& extension : registry->enabled_extensions()) {
-    // Mimics the count done for the Histograms `Extensions.LoadExtensionUser2`
-    // that counts the user installed extensions.
-    if (extension->is_extension() &&
-        !extensions::Manifest::IsExternalLocation(extension->location()) &&
-        !extensions::Manifest::IsUnpackedLocation(extension->location()) &&
-        !extensions::Manifest::IsComponentLocation(extension->location())) {
-      ++user_installed_extension_count;
-    }
-  }
-
-  return user_installed_extension_count;
-}
-#endif
-
 #if !BUILDFLAG(IS_CHROMEOS)
 void ChromeSigninClient::RecordOpenTabCount(
     signin_metrics::AccessPoint access_point,
