@@ -5,9 +5,11 @@
 #include "chrome/browser/signin/signin_util.h"
 
 #include <memory>
+#include <string_view>
 
 #include "base/barrier_closure.h"
 #include "base/containers/contains.h"
+#include "base/feature_list.h"
 #include "base/functional/bind.h"
 #include "base/memory/raw_ptr.h"
 #include "base/memory/weak_ptr.h"
@@ -19,12 +21,12 @@
 #include "chrome/browser/browser_process.h"
 #include "chrome/browser/enterprise/profile_management/profile_management_features.h"
 #include "chrome/browser/enterprise/util/managed_browser_utils.h"
-#include "chrome/browser/policy/cloud/user_policy_signin_service_internal.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/profiles/profiles_state.h"
 #include "chrome/browser/signin/account_reconcilor_factory.h"
 #include "chrome/browser/signin/identity_manager_factory.h"
 #include "chrome/browser/sync/sync_service_factory.h"
+#include "chrome/browser/ui/webui/signin/signin_utils_desktop.h"
 #include "chrome/common/pref_names.h"
 #include "chrome/common/url_constants.h"
 #include "chrome/grit/generated_resources.h"
@@ -33,8 +35,10 @@
 #include "components/prefs/pref_service.h"
 #include "components/signin/core/browser/account_reconcilor.h"
 #include "components/signin/public/base/signin_pref_names.h"
+#include "components/signin/public/base/signin_switches.h"
 #include "components/signin/public/identity_manager/account_managed_status_finder.h"
 #include "components/signin/public/identity_manager/accounts_mutator.h"
+#include "components/signin/public/identity_manager/tribool.h"
 #include "components/sync/base/user_selectable_type.h"
 #include "components/sync/service/sync_service.h"
 #include "components/sync/service/sync_user_settings.h"
@@ -47,7 +51,9 @@
 #include "ui/base/l10n/l10n_util.h"
 
 namespace signin_util {
+
 namespace {
+
 enum ForceSigninPolicyCache {
   NOT_CACHED = 0,
   ENABLE,
@@ -344,6 +350,25 @@ SignedInState GetSignedInState(
   return SignedInState::kSignedOut;
 }
 
+std::string SignedInStateToString(SignedInState state) {
+  switch (state) {
+    case SignedInState::kSignedOut:
+      return "Signed Out";
+    case SignedInState::kSignedIn:
+      return "Signed In";
+    case SignedInState::kSyncing:
+      return "Syncing";
+    case SignedInState::kSignInPending:
+      return "Sign-in Pending";
+    case SignedInState::kWebOnlySignedIn:
+      return "Web Only Signed In";
+    case SignedInState::kSyncPaused:
+      return "Sync Paused";
+    default:
+      NOTREACHED();
+  }
+}
+
 #if BUILDFLAG(IS_LINUX) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN)
 bool ShouldShowHistorySyncOptinScreen(Profile& profile) {
   if (GetSignedInState(IdentityManagerFactory::GetForProfile(&profile)) !=
@@ -383,6 +408,62 @@ bool ShouldShowHistorySyncOptinScreen(Profile& profile) {
   }
   return true;
 }
+
+bool ShouldShowAvatarSyncPromo(Profile* profile) {
+  CHECK(switches::IsAvatarSyncPromoFeatureEnabled());
+
+  // Do not show the promo for users that are not signed in. (E.g. Signed out,
+  // Signin Pending or already syncing).
+  if (GetSignedInState(IdentityManagerFactory::GetForProfile(profile)) !=
+      signin_util::SignedInState::kSignedIn) {
+    return false;
+  }
+
+  // SyncService should be usable.
+  syncer::SyncService* sync_service =
+      SyncServiceFactory::GetForProfile(profile);
+  if (!sync_service) {
+    return false;
+  }
+  if (sync_service->HasDisableReason(
+          syncer::SyncService::DISABLE_REASON_ENTERPRISE_POLICY)) {
+    return false;
+  }
+
+  signin::IdentityManager* identity_manager =
+      IdentityManagerFactory::GetForProfile(profile);
+  CHECK(identity_manager->AreRefreshTokensLoaded());
+  AccountInfo account_info = identity_manager->FindExtendedAccountInfo(
+      identity_manager->GetPrimaryAccountInfo(signin::ConsentLevel::kSignin));
+  // Do not show the promo for non signed in accounts, or managed accounts.
+  if (account_info.IsEmpty() ||
+      account_info.IsManaged() != signin::Tribool::kFalse) {
+    return false;
+  }
+
+  // Do not show the promo if there was a previously syncing account that does
+  // not match the currently signed in one.
+  PrefService* pref_service = profile->GetPrefs();
+  GaiaId previously_syncing_gaia_id =
+      GaiaId(pref_service->GetString(prefs::kGoogleServicesLastSyncingGaiaId));
+  if (IsCrossAccountError(profile, account_info.gaia)) {
+    return false;
+  }
+
+  // For non-dice users, do not show the promo for users that have been signed
+  // for a short period of time.
+  if (pref_service->GetBoolean(prefs::kExplicitBrowserSignin)) {
+    const base::Time last_changed = base::Time::FromSecondsSinceUnixEpoch(
+        pref_service->GetDouble(prefs::kGaiaCookieChangedTime));
+    if (last_changed.is_null() ||
+        (base::Time::Now() - last_changed <
+         switches::GetAvatarSyncPromoFeatureMinimumCookeAgeParam())) {
+      return false;
+    }
+  }
+
+  return true;
+}
 #endif  // BUILDFLAG(IS_LINUX) ||  BUILDFLAG(IS_MAC) ||  BUILDFLAG(IS_WIN)
 
 }  // namespace signin_util
