@@ -12,6 +12,7 @@
 #include "base/feature_list.h"
 #include "base/functional/bind.h"
 #include "base/functional/callback.h"
+#include "base/functional/callback_helpers.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/metrics/user_metrics.h"
 #include "base/notreached.h"
@@ -39,6 +40,7 @@
 #include "chrome/browser/signin/chrome_signin_client_factory.h"
 #include "chrome/browser/signin/identity_manager_factory.h"
 #include "chrome/browser/signin/signin_error_controller_factory.h"
+#include "chrome/browser/signin/signin_hats_util.h"
 #include "chrome/browser/signin/signin_ui_util.h"
 #include "chrome/browser/signin/signin_util.h"
 #include "chrome/browser/sync/sync_service_factory.h"
@@ -51,6 +53,7 @@
 #include "chrome/browser/ui/browser_navigator_params.h"
 #include "chrome/browser/ui/browser_window/public/browser_window_features.h"
 #include "chrome/browser/ui/color/chrome_color_id.h"
+#include "chrome/browser/ui/hats/survey_config.h"
 #include "chrome/browser/ui/managed_ui.h"
 #include "chrome/browser/ui/passwords/ui_utils.h"
 #include "chrome/browser/ui/profiles/profile_colors_util.h"
@@ -110,18 +113,24 @@
 
 namespace {
 
-std::u16string GetSyncErrorButtonText(AvatarSyncErrorType error) {
+std::u16string GetSyncErrorButtonText(Profile* profile,
+                                      AvatarSyncErrorType error) {
   switch (error) {
-    case AvatarSyncErrorType::kSyncPaused:
     case AvatarSyncErrorType::kUnrecoverableError:
+      if (!ChromeSigninClientFactory::GetForProfile(profile)
+               ->IsClearPrimaryAccountAllowed(
+                   IdentityManagerFactory::GetForProfile(profile)
+                       ->HasPrimaryAccount(signin::ConsentLevel::kSync))) {
+        // As opposed to the corresponding error in an unmanaged account,
+        // sign-out hasn't happened here yet. The button directs to the sign-out
+        // confirmation dialog in settings.
+        return l10n_util::GetStringUTF16(
+            IDS_SYNC_ERROR_USER_MENU_SIGNOUT_BUTTON);
+      }
+      [[fallthrough]];
+    case AvatarSyncErrorType::kSyncPaused:
       // The user was signed out. Offer them to sign in again.
       return l10n_util::GetStringUTF16(IDS_SYNC_ERROR_USER_MENU_SIGNIN_BUTTON);
-    case AvatarSyncErrorType::kManagedUserUnrecoverableError:
-      // As opposed to the corresponding error in an unmanaged account
-      // (AvatarSyncErrorType::kUnrecoverableError), sign-out hasn't happened
-      // here yet. The button directs to the sign-out confirmation dialog in
-      // settings.
-      return l10n_util::GetStringUTF16(IDS_SYNC_ERROR_USER_MENU_SIGNOUT_BUTTON);
     case AvatarSyncErrorType::kUpgradeClientError:
       return l10n_util::GetStringUTF16(IDS_SYNC_ERROR_USER_MENU_UPGRADE_BUTTON);
     case AvatarSyncErrorType::kPassphraseError:
@@ -154,6 +163,11 @@ std::u16string GetProfileIdentifier(const ProfileAttributesEntry& entry) {
 }
 
 std::u16string GetSyncPromoDescription(std::string_view email) {
+  if (switches::IsAvatarSyncPromoFeatureEnabled()) {
+    return l10n_util::GetStringUTF16(
+        IDS_PROFILE_MENU_DESCRIPTION_WITH_SYNC_PROMO);
+  }
+
 #if BUILDFLAG(ENABLE_DICE_SUPPORT)
   if (base::FeatureList::IsEnabled(
           switches::kEnableHistorySyncOptinExpansionPill)) {
@@ -183,6 +197,11 @@ std::u16string GetSyncPromoDescription(std::string_view email) {
 }
 
 std::u16string GetSyncPromoButtonLabel() {
+  if (switches::IsAvatarSyncPromoFeatureEnabled()) {
+    return l10n_util::GetStringUTF16(
+        IDS_PROFILE_MENU_BUTTON_LABEL_WITH_SYNC_PROMO);
+  }
+
 #if BUILDFLAG(ENABLE_DICE_SUPPORT)
   if (base::FeatureList::IsEnabled(
           switches::kEnableHistorySyncOptinExpansionPill)) {
@@ -218,10 +237,27 @@ ProfileMenuView::ProfileMenuView(
       browser_(raw_ref<Browser>::from_ptr(browser)),
       explicit_signin_access_point_(explicit_signin_access_point) {
   set_close_on_deactivate(close_on_deactivate_for_testing_);
+
+  // Set the callback to launch a HaTS survey upon menu dismissal.
+  // We use `SetCloseCallback` instead of `SetCancelCallback` because the close
+  // callback is also executed when users dismiss the menu by clicking outside,
+  // unlike the cancel callback.
+  SetCloseCallback(
+      base::BindOnce(&ProfileMenuView::OnClose, base::Unretained(this)));
 }
 
 ProfileMenuView::~ProfileMenuView() = default;
 
+void ProfileMenuView::OnClose() {
+  if (!actionable_item_clicked()) {
+    // Launch a HaTS survey only if the user dismissed the profile menu by
+    // clicking outside or pressing the Escape key. Do not launch if a button
+    // within the menu was clicked.
+    signin::LaunchSigninHatsSurveyForProfile(
+        kHatsSurveyTriggerIdentityProfileMenuDismissed, &profile());
+  }
+}
+
 void ProfileMenuView::BuildMenu() {
   if (profile().IsGuestSession()) {
     BuildGuestIdentity();
@@ -236,9 +272,10 @@ void ProfileMenuView::BuildMenu() {
 
   const bool is_web_app = web_app::AppBrowserController::IsWebApp(&browser());
   if (is_web_app) {
-    browser().window()->NotifyFeaturePromoFeatureUsed(
-        feature_engagement::kIPHPasswordsWebAppProfileSwitchFeature,
-        FeaturePromoFeatureUsedAction::kClosePromoIfPresent);
+    BrowserUserEducationInterface::From(&browser())
+        ->NotifyFeaturePromoFeatureUsed(
+            feature_engagement::kIPHPasswordsWebAppProfileSwitchFeature,
+            FeaturePromoFeatureUsedAction::kClosePromoIfPresent);
   }
 
   // Users should not be able to use features from WebApps.
@@ -279,7 +316,7 @@ std::u16string ProfileMenuView::GetAccessibleWindowTitle() const {
 }
 
 void ProfileMenuView::OnProfileManagementButtonClicked() {
-  RecordClick(ActionableItem::kProfileManagementLabel);
+  OnActionableItemClicked(ActionableItem::kProfileManagementLabel);
   if (!perform_menu_actions()) {
     return;
   }
@@ -287,7 +324,7 @@ void ProfileMenuView::OnProfileManagementButtonClicked() {
 }
 
 void ProfileMenuView::OnManageGoogleAccountButtonClicked() {
-  RecordClick(ActionableItem::kManageGoogleAccountButton);
+  OnActionableItemClicked(ActionableItem::kManageGoogleAccountButton);
   if (!perform_menu_actions()) {
     return;
   }
@@ -302,7 +339,7 @@ void ProfileMenuView::OnManageGoogleAccountButtonClicked() {
 }
 
 void ProfileMenuView::OnGuestProfileButtonClicked() {
-  RecordClick(ActionableItem::kGuestProfileButton);
+  OnActionableItemClicked(ActionableItem::kGuestProfileButton);
   if (!perform_menu_actions()) {
     return;
   }
@@ -311,7 +348,7 @@ void ProfileMenuView::OnGuestProfileButtonClicked() {
 }
 
 void ProfileMenuView::OnExitProfileButtonClicked() {
-  RecordClick(ActionableItem::kExitProfileButton);
+  OnActionableItemClicked(ActionableItem::kExitProfileButton);
   if (!perform_menu_actions()) {
     return;
   }
@@ -319,7 +356,7 @@ void ProfileMenuView::OnExitProfileButtonClicked() {
 }
 
 void ProfileMenuView::OnSyncSettingsButtonClicked() {
-  RecordClick(ActionableItem::kSyncSettingsButton);
+  OnActionableItemClicked(ActionableItem::kSyncSettingsButton);
   if (!perform_menu_actions()) {
     return;
   }
@@ -327,19 +364,25 @@ void ProfileMenuView::OnSyncSettingsButtonClicked() {
 }
 
 void ProfileMenuView::OnSyncErrorButtonClicked(AvatarSyncErrorType error) {
-  RecordClick(ActionableItem::kSyncErrorButton);
+  OnActionableItemClicked(ActionableItem::kSyncErrorButton);
   if (!perform_menu_actions()) {
     return;
   }
 
   // The logic below must be consistent with GetSyncInfoForAvatarErrorType().
   switch (error) {
-    case AvatarSyncErrorType::kManagedUserUnrecoverableError:
-      chrome::ShowSettingsSubPage(&browser(), chrome::kSignOutSubPage);
-      break;
     case AvatarSyncErrorType::kUnrecoverableError: {
       signin::IdentityManager* identity_manager =
           IdentityManagerFactory::GetForProfile(&profile());
+      // Managed users get directed to the sign-out confirmation dialog in
+      // settings.
+      if (!ChromeSigninClientFactory::GetForProfile(&profile())
+               ->IsClearPrimaryAccountAllowed(
+                   identity_manager->HasPrimaryAccount(
+                       signin::ConsentLevel::kSync))) {
+        chrome::ShowSettingsSubPage(&browser(), chrome::kSignOutSubPage);
+        break;
+      }
       // This error means that the Sync engine failed to initialize. Shutdown
       // Sync engine by revoking sync consent.
       identity_manager->GetPrimaryAccountMutator()->RevokeSyncConsent(
@@ -392,24 +435,16 @@ void ProfileMenuView::OnSigninButtonClicked(
     CoreAccountInfo account,
     ActionableItem button_type,
     signin_metrics::AccessPoint access_point) {
-  RecordClick(button_type);
+  OnActionableItemClicked(button_type);
 
   if (!perform_menu_actions()) {
     return;
   }
   GetWidget()->CloseWithReason(views::Widget::ClosedReason::kUnspecified);
 
-#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
-  // TODO(crbug.com/404807488): Update the button and the dialog strings.
-  if (base::FeatureList::IsEnabled(switches::kEnableHistorySyncOptin)) {
-    browser()
-        .GetFeatures()
-        .signin_view_controller()
-        ->ShowModalHistorySyncOptInDialog();
-    return;
-  }
-#endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
-
+  // TODO(crbug.com/418145883): Trigger the history sync optin
+  // screen for the case of a signed in with history sync off.
+  // Pending while the HistorySyncPillExperiment is in progress.
   if (button_type == ActionableItem::kSigninReauthButton) {
     // The reauth button does not trigger a sync opt in.
     signin_ui_util::ShowReauthForAccount(&profile(), account.email,
@@ -429,7 +464,7 @@ void ProfileMenuView::OnSignoutButtonClicked() {
       << "Clear primary account is not allowed. Signout should not be offered "
          "in the UI.";
 
-  RecordClick(ActionableItem::kSignoutButton);
+  OnActionableItemClicked(ActionableItem::kSignoutButton);
   if (!perform_menu_actions()) {
     return;
   }
@@ -443,14 +478,26 @@ void ProfileMenuView::OnSignoutButtonClicked() {
 
 void ProfileMenuView::OnOtherProfileSelected(
     const base::FilePath& profile_path) {
-  RecordClick(ActionableItem::kOtherProfileButton);
+  OnActionableItemClicked(ActionableItem::kOtherProfileButton);
   if (!perform_menu_actions()) {
     return;
   }
 
   if (!web_app::AppBrowserController::IsWebApp(&browser())) {
     GetWidget()->CloseWithReason(views::Widget::ClosedReason::kUnspecified);
-    profiles::SwitchToProfile(profile_path, /*always_create=*/false);
+    // Switch to the selected profile and launch a HaTS survey for the
+    // associated non-webapp browser.
+    profiles::SwitchToProfile(
+        profile_path, /*always_create=*/false,
+        base::BindOnce(
+            [](Browser* browser) {
+              if (!browser) {
+                return;
+              }
+              signin::LaunchSigninHatsSurveyForProfile(
+                  kHatsSurveyTriggerIdentitySwitchProfileFromProfileMenu,
+                  browser->GetProfile());
+            }));
   } else {
     // Open the same web app for another profile.
     // On non-macOS the only allowlisted case is PasswordManager WebApp, which
@@ -483,7 +530,7 @@ void ProfileMenuView::OnOtherProfileSelected(
 }
 
 void ProfileMenuView::OnAddNewProfileButtonClicked() {
-  RecordClick(ActionableItem::kAddNewProfileButton);
+  OnActionableItemClicked(ActionableItem::kAddNewProfileButton);
   if (!perform_menu_actions()) {
     return;
   }
@@ -492,7 +539,7 @@ void ProfileMenuView::OnAddNewProfileButtonClicked() {
 }
 
 void ProfileMenuView::OnManageProfilesButtonClicked() {
-  RecordClick(ActionableItem::kManageProfilesButton);
+  OnActionableItemClicked(ActionableItem::kManageProfilesButton);
   if (!perform_menu_actions()) {
     return;
   }
@@ -501,7 +548,7 @@ void ProfileMenuView::OnManageProfilesButtonClicked() {
 }
 
 void ProfileMenuView::OnEditProfileButtonClicked() {
-  RecordClick(ActionableItem::kEditProfileButton);
+  OnActionableItemClicked(ActionableItem::kEditProfileButton);
   if (!perform_menu_actions()) {
     return;
   }
@@ -509,7 +556,7 @@ void ProfileMenuView::OnEditProfileButtonClicked() {
 }
 
 void ProfileMenuView::OnAutofillSettingsButtonClicked() {
-  RecordClick(ActionableItem::kAutofillSettingsButton);
+  OnActionableItemClicked(ActionableItem::kAutofillSettingsButton);
   if (!perform_menu_actions()) {
     return;
   }
@@ -517,7 +564,7 @@ void ProfileMenuView::OnAutofillSettingsButtonClicked() {
 }
 
 void ProfileMenuView::OnBuildBatchUploadButtonClicked() {
-  RecordClick(ActionableItem::kBatchUploadButton);
+  OnActionableItemClicked(ActionableItem::kBatchUploadButton);
   if (!perform_menu_actions()) {
     return;
   }
@@ -589,8 +636,6 @@ ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
       GetAvatarSyncErrorType(&profile());
   const signin::IdentityManager* identity_manager =
       IdentityManagerFactory::GetForProfile(&profile());
-  const bool is_sync_feature_enabled =
-      identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSync);
   const CoreAccountInfo primary_account_info =
       identity_manager->GetPrimaryAccountInfo(signin::ConsentLevel::kSignin);
   const AccountInfo primary_extended_account_info =
@@ -646,11 +691,14 @@ ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
     return params;
   }
 
-  // Sync error, including "paused".
-  if (error.has_value()) {
-    params.subtitle = GetAvatarSyncErrorDescription(
-        *error, is_sync_feature_enabled, primary_account_info.email);
-    params.button_text = GetSyncErrorButtonText(error.value());
+  // Avoid reacting to AvatarSyncErrorType::kSyncPaused in case of no sync
+  // consent, as kSignInPending is handled differently below.
+  if (error.has_value() &&
+      (error.value() != AvatarSyncErrorType::kSyncPaused ||
+       identity_manager->HasPrimaryAccount(signin::ConsentLevel::kSync))) {
+    params.subtitle =
+        GetAvatarSyncErrorDescription(*error, primary_account_info.email);
+    params.button_text = GetSyncErrorButtonText(&profile(), error.value());
     params.button_action =
         base::BindRepeating(&ProfileMenuView::OnSyncErrorButtonClicked,
                             base::Unretained(this), error.value());
@@ -668,7 +716,10 @@ ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
         access_point =
             signin_metrics::AccessPoint::kAvatarBubbleSignInWithSyncPromo;
         params.subtitle = l10n_util::GetStringUTF16(
-            IDS_PROFILE_MENU_SIGNIN_PROMO_DESCRIPTION);
+            base::FeatureList::IsEnabled(
+                syncer::kReplaceSyncPromosWithSignInPromos)
+                ? IDS_PROFILE_MENU_SIGNIN_PROMO_DESCRIPTION_WITH_BOOKMARKS
+                : IDS_PROFILE_MENU_SIGNIN_PROMO_DESCRIPTION);
         params.button_text =
             l10n_util::GetStringUTF16(IDS_PROFILE_MENU_SIGNIN_PROMO_BUTTON);
         signin_metrics::LogSignInOffered(
@@ -684,7 +735,10 @@ ProfileMenuView::GetIdentitySectionParams(const ProfileAttributesEntry& entry) {
           signin_ui_util::GetSingleAccountForPromos(identity_manager);
       account_info_for_signin_action = account_info_for_promos;
       params.subtitle = l10n_util::GetStringFUTF16(
-          IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL,
+          base::FeatureList::IsEnabled(
+              syncer::kReplaceSyncPromosWithSignInPromos)
+              ? IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL_WITH_BOOKMARKS
+              : IDS_SETTINGS_PEOPLE_ACCOUNT_AWARE_SIGNIN_ACCOUNT_ROW_SUBTITLE_WITH_EMAIL,
           base::UTF8ToUTF16(account_info_for_promos.email));
       params.button_text = l10n_util::GetStringFUTF16(
           IDS_PROFILES_DICE_WEB_ONLY_SIGNIN_BUTTON,
