@@ -21,7 +21,6 @@
 #include "chrome/browser/extensions/cws_info_service_factory.h"
 #include "chrome/browser/profiles/profile.h"
 #include "chrome/browser/signin/identity_manager_factory.h"
-#include "chrome/browser/ui/safety_hub/card_data_helper.h"
 #include "chrome/browser/ui/safety_hub/extensions_result.h"
 #include "chrome/browser/ui/safety_hub/menu_notification_service_factory.h"
 #include "chrome/browser/ui/safety_hub/notification_permission_review_service.h"
@@ -30,9 +29,11 @@
 #include "chrome/browser/ui/safety_hub/password_status_check_service_factory.h"
 #include "chrome/browser/ui/safety_hub/revoked_permissions_service.h"
 #include "chrome/browser/ui/safety_hub/revoked_permissions_service_factory.h"
+#include "chrome/browser/ui/safety_hub/safe_browsing_result.h"
 #include "chrome/browser/ui/safety_hub/safety_hub_constants.h"
 #include "chrome/browser/ui/safety_hub/safety_hub_hats_service.h"
 #include "chrome/browser/ui/safety_hub/safety_hub_hats_service_factory.h"
+#include "chrome/browser/ui/safety_hub/safety_hub_result.h"
 #include "chrome/browser/ui/safety_hub/safety_hub_util.h"
 #include "chrome/browser/ui/webui/settings/site_settings_helper.h"
 #include "chrome/browser/ui/webui/version/version_ui.h"
@@ -260,8 +261,8 @@ base::Value::List SafetyHubHandler::PopulateUnusedSitePermissionsData() {
   RevokedPermissionsService* service =
       RevokedPermissionsServiceFactory::GetForProfile(profile_);
   CHECK(service);
-  std::unique_ptr<RevokedPermissionsService::RevokedPermissionsResult>
-      service_result = service->GetRevokedPermissions();
+  std::unique_ptr<RevokedPermissionsResult> service_result =
+      service->GetRevokedPermissions();
   for (const auto& permissions_data : service_result->GetRevokedPermissions()) {
     base::Value::Dict revoked_permission_value;
     revoked_permission_value.Set(site_settings::kOrigin,
@@ -444,8 +445,9 @@ void SafetyHubHandler::HandleGetSafeBrowsingCardData(
   CHECK_EQ(1U, args.size());
   const base::Value& callback_id = args[0];
 
-  ResolveJavascriptCallback(callback_id,
-                            safety_hub::GetSafeBrowsingCardData(profile_));
+  ResolveJavascriptCallback(
+      callback_id, SafetyHubSafeBrowsingResult::GetSafeBrowsingCardData(
+                       profile_->GetPrefs()));
 }
 
 void SafetyHubHandler::HandleGetNumberOfExtensionsThatNeedReview(
@@ -463,8 +465,12 @@ void SafetyHubHandler::HandleGetPasswordCardData(
   CHECK_EQ(1U, args.size());
   const base::Value& callback_id = args[0];
 
-  ResolveJavascriptCallback(
-      callback_id, base::Value(safety_hub::GetPasswordCardData(profile_)));
+  PasswordStatusCheckService* service =
+      PasswordStatusCheckServiceFactory::GetForProfile(profile_);
+  CHECK(service);
+
+  ResolveJavascriptCallback(callback_id,
+                            base::Value(service->GetPasswordCardData()));
 }
 
 void SafetyHubHandler::HandleGetVersionCardData(const base::Value::List& args) {
@@ -474,7 +480,7 @@ void SafetyHubHandler::HandleGetVersionCardData(const base::Value::List& args) {
   const base::Value& callback_id = args[0];
 
   ResolveJavascriptCallback(callback_id,
-                            base::Value(safety_hub::GetVersionCardData()));
+                            base::Value(safety_hub_util::GetVersionCardData()));
 }
 
 void SafetyHubHandler::HandleGetSafetyHubEntryPointData(
@@ -549,15 +555,20 @@ SafetyHubHandler::GetSafetyHubModulesWithRecommendations() {
   std::set<SafetyHubModule> modules;
 
   // Passwords module
-  if (CardHasRecommendations(safety_hub::GetPasswordCardData(profile_))) {
+  PasswordStatusCheckService* psc_service =
+      PasswordStatusCheckServiceFactory::GetForProfile(profile_);
+  CHECK(psc_service);
+  if (CardHasRecommendations(psc_service->GetPasswordCardData())) {
     modules.insert(SafetyHubModule::kPasswords);
   }
   // Version module
-  if (CardHasRecommendations(safety_hub::GetVersionCardData())) {
+  if (CardHasRecommendations(safety_hub_util::GetVersionCardData())) {
     modules.insert(SafetyHubModule::kVersion);
   }
   // SafeBrowsing module
-  if (CardHasRecommendations(safety_hub::GetSafeBrowsingCardData(profile_))) {
+  if (CardHasRecommendations(
+          SafetyHubSafeBrowsingResult::GetSafeBrowsingCardData(
+              profile_->GetPrefs()))) {
     modules.insert(SafetyHubModule::kSafeBrowsing);
   }
   // Extensions module
@@ -565,10 +576,10 @@ SafetyHubHandler::GetSafetyHubModulesWithRecommendations() {
     modules.insert(SafetyHubModule::kExtensions);
   }
   // Notifications module
-  NotificationPermissionsReviewService* service =
+  NotificationPermissionsReviewService* npr_service =
       NotificationPermissionsReviewServiceFactory::GetForProfile(profile_);
-  CHECK(service);
-  if (!service->PopulateNotificationPermissionReviewData().empty()) {
+  CHECK(npr_service);
+  if (!npr_service->PopulateNotificationPermissionReviewData().empty()) {
     modules.insert(SafetyHubModule::kNotifications);
   }
   // Unused site permission module
@@ -725,7 +736,7 @@ void SafetyHubHandler::SendNotificationPermissionReviewList() {
 }
 
 void SafetyHubHandler::InitSafetyHubExtensionResults() {
-  std::optional<std::unique_ptr<SafetyHubService::Result>> sh_result =
+  std::optional<std::unique_ptr<SafetyHubResult>> sh_result =
       SafetyHubExtensionsResult::GetResult(profile_, false);
   if (sh_result.has_value()) {
     extension_sh_result_ = std::make_unique<SafetyHubExtensionsResult>(
