@@ -37,6 +37,7 @@
 #include "components/signin/public/identity_manager/identity_manager.h"
 #include "components/signin/public/identity_manager/tribool.h"
 #include "components/strings/grit/components_strings.h"
+#include "components/sync/base/features.h"
 #include "content/public/browser/web_ui.h"
 #include "content/public/browser/web_ui_data_source.h"
 #include "extensions/browser/extension_registry.h"
@@ -55,12 +56,6 @@ ManagedUserProfileNoticeUI::ManagedUserProfileNoticeUI(content::WebUI* web_ui)
 
   static constexpr webui::ResourcePath kResources[] = {
       {"icons.html.js", IDR_SIGNIN_ICONS_HTML_JS},
-      {"legacy_managed_user_profile_notice_app.js",
-       IDR_SIGNIN_MANAGED_USER_PROFILE_NOTICE_LEGACY_MANAGED_USER_PROFILE_NOTICE_APP_JS},
-      {"legacy_managed_user_profile_notice_app.css.js",
-       IDR_SIGNIN_MANAGED_USER_PROFILE_NOTICE_LEGACY_MANAGED_USER_PROFILE_NOTICE_APP_CSS_JS},
-      {"legacy_managed_user_profile_notice_app.html.js",
-       IDR_SIGNIN_MANAGED_USER_PROFILE_NOTICE_LEGACY_MANAGED_USER_PROFILE_NOTICE_APP_HTML_JS},
       {"managed_user_profile_notice_app.js",
        IDR_SIGNIN_MANAGED_USER_PROFILE_NOTICE_MANAGED_USER_PROFILE_NOTICE_APP_JS},
       {"managed_user_profile_notice_app.css.js",
@@ -150,9 +145,6 @@ ManagedUserProfileNoticeUI::ManagedUserProfileNoticeUI(content::WebUI* web_ui)
   source->AddLocalizedString(
       "profileDisclosureTitle",
       IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_WORK_TITLE);
-  source->AddLocalizedString(
-      "profileOidcDisclosureTitle",
-      IDS_ENTERPRISE_WELCOME_PROFILE_OIDC_DISCLOSURE_TITLE);
   source->AddLocalizedString(
       "profileDisclosureSubtitle",
       IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_SUBTITLE);
@@ -185,7 +177,7 @@ ManagedUserProfileNoticeUI::ManagedUserProfileNoticeUI(content::WebUI* web_ui)
       "separateBrowsingDataTitle",
       IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_WORK_TITLE);
   source->AddLocalizedString(
-      "valuePropositionTitle",
+      "valuePropTitle",
       IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_SUGGESTED_TITLE);
   source->AddLocalizedString("valuePropSubtitle",
                              IDS_ENTERPRISE_VALUE_PROPOSITION_WORK_SUBTITLE);
@@ -202,13 +194,8 @@ ManagedUserProfileNoticeUI::ManagedUserProfileNoticeUI(content::WebUI* web_ui)
   source->AddLocalizedString(
       "mergeBrowsingDataChoiceDetails",
       IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_CHOICE_DETAILS);
-
-  source->AddBoolean("useUpdatedUi",
-                     base::FeatureList::IsEnabled(
-                         features::kEnterpriseUpdatedProfileCreationScreen));
   source->AddBoolean("showLinkDataCheckbox", false);
   source->AddBoolean("isModalDialog", false);
-  source->AddBoolean("isOidcDialog", false);
   source->AddBoolean("enforcedByPolicy", false);
   source->AddInteger("initialState",
                      ManagedUserProfileNoticeHandler::State::kDisclosure);
@@ -226,6 +213,8 @@ void ManagedUserProfileNoticeUI::Initialize(
       create_param->account_info.capabilities.can_use_edu_features() ==
       signin::Tribool::kTrue;
   base::Value::Dict update_data;
+  std::string domain =
+      enterprise_util::GetDomainFromEmail(create_param->account_info.email);
   if (type ==
       ManagedUserProfileNoticeUI::ScreenType::kEnterpriseAccountCreation) {
     update_data.Set("isModalDialog", true);
@@ -238,10 +227,9 @@ void ManagedUserProfileNoticeUI::Initialize(
           signin_util::IsProfileSeparationEnforcedByProfile(
               profile, create_param->account_info.email)
               ? GetEnterpriseAccountDomain(*profile).value_or(std::string())
-              : enterprise_util::GetDomainFromEmail(
-                    create_param->account_info.email);
+              : domain;
       update_data.Set(
-          "valuePropositionTitle",
+          "valuePropTitle",
           manager.empty()
               ? l10n_util::GetStringUTF16(
                     IDS_ENTERPRISE_VALUE_PROPOSITION_PROFILE_REQUIRED_BY_ORG_TITLE)
@@ -256,7 +244,7 @@ void ManagedUserProfileNoticeUI::Initialize(
                     create_param->show_link_data_option);
     // If the user is already signed in and is trying to turn sync on, we can
     // skip the value proposition screen since they are already signed in.
-    if (create_param->turn_sync_on_signed_profile) {
+    if (create_param->user_already_signed_in) {
       update_data.Set("initialState",
                       ManagedUserProfileNoticeHandler::State::kDisclosure);
     } else {
@@ -270,71 +258,74 @@ void ManagedUserProfileNoticeUI::Initialize(
     update_data.Set("initialState",
                     ManagedUserProfileNoticeHandler::State::kDisclosure);
     update_data.Set("isModalDialog", true);
-    update_data.Set("isOidcDialog", true);
     update_data.Set(
         "enterpriseProfileWelcomeTitle",
         l10n_util::GetStringUTF16(IDS_ENTERPRISE_WELCOME_PROFILE_SETUP_TITLE));
+    update_data.Set("profileDisclosureTitle",
+                    l10n_util::GetStringUTF16(
+                        IDS_ENTERPRISE_WELCOME_PROFILE_OIDC_DISCLOSURE_TITLE));
 
     update_data.Set("showLinkDataCheckbox", false);
-#if !BUILDFLAG(IS_CHROMEOS)
-    update_data.Set(
-        "useUpdatedUi",
-        base::FeatureList::IsEnabled(
-            features::kEnterpriseUpdatedProfileCreationScreen) ||
-            base::FeatureList::IsEnabled(
-                profile_management::features::kOidcAuthProfileManagement));
-#endif
   }
   if (create_param->account_info.IsManaged() == signin::Tribool::kTrue) {
     update_data.Set(
         "profileDisclosureSubtitle",
         l10n_util::GetStringFUTF16(
             IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_KNOWN_DOMAIN_SUBTITLE,
-            base::UTF8ToUTF16(enterprise_util::GetDomainFromEmail(
-                create_param->account_info.email))));
+            base::UTF8ToUTF16(domain)));
   }
 
   if (create_param->account_info.IsManaged() != signin::Tribool::kTrue) {
-    update_data.Set("valuePropSubtitle",
-                    l10n_util::GetStringUTF16(
-                        IDS_ENTERPRISE_VALUE_PROPOSITION_CONSUMER_SUBTITLE));
+    update_data.Set(
+        "valuePropSubtitle",
+        l10n_util::GetStringUTF16(
+            base::FeatureList::IsEnabled(
+                syncer::kReplaceSyncPromosWithSignInPromos)
+                ? IDS_ENTERPRISE_VALUE_PROPOSITION_CONSUMER_SUBTITLE_WITH_BOOKMARKS
+                : IDS_ENTERPRISE_VALUE_PROPOSITION_CONSUMER_SUBTITLE));
     update_data.Set(
         "separateBrowsingDataTitle",
         l10n_util::GetStringUTF16(
             IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_CONSUMER_TITLE));
-  } else if (create_param->turn_sync_on_signed_profile) {
+  } else if (create_param->user_already_signed_in ||
+             base::FeatureList::IsEnabled(
+                 switches::kEnforceManagementDisclaimer)) {
     update_data.Set(
         "separateBrowsingDataTitle",
         l10n_util::GetStringUTF16(
-            IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_TURN_SYNC_ON_TITLE));
+            IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_ALREADY_SIGNED_IN_TITLE));
     update_data.Set(
         "profileDisclosureTitle",
         l10n_util::GetStringUTF16(
-            IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_TURN_SYNC_ON_TITLE));
+            IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_TITLE));
     update_data.Set(
         "profileDisclosureSubtitle",
         l10n_util::GetStringFUTF16(
-            IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_TURN_SYNC_ON_SUBTITLE,
-            base::UTF8ToUTF16(enterprise_util::GetDomainFromEmail(
-                create_param->account_info.email))));
+            create_param->profile_creation_required_by_policy
+                ? IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_ENFORCED_SUBTITLE
+                : IDS_ENTERPRISE_WELCOME_PROFILE_DISCLOSURE_ALREADY_SIGNED_IN_SUBTITLE,
+            base::UTF8ToUTF16(domain)));
     update_data.Set(
         "mergeBrowsingDataChoiceTitle",
         l10n_util::GetStringUTF16(
-            IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_TURN_SYNC_ON_CHOICE));
+            IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_ALREADY_SIGNED_IN_CHOICE));
     update_data.Set(
         "separateBrowsingDataChoiceTitle",
         l10n_util::GetStringUTF16(
-            IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_TURN_SYNC_ON_CHOICE));
+            IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_ALREADY_SIGNED_IN_CHOICE));
     update_data.Set(
         "separateBrowsingDataChoiceDetails",
         l10n_util::GetStringFUTF16(
-            IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_TURN_SYNC_ON_DETAILS,
-            base::UTF8ToUTF16(create_param->account_info.email)));
-    // Canceling when profile separation is enabled forces the user to signout.
-    if (create_param->profile_creation_required_by_policy) {
+            IDS_ENTERPRISE_WELCOME_SEPARATE_BROWSING_DATA_CHOICE_ALREADY_SIGNED_IN_DETAILS,
+            base::UTF8ToUTF16(domain)));
+    if (type ==
+        ManagedUserProfileNoticeUI::ScreenType::kEnterpriseAccountCreation) {
       update_data.Set(
           "cancelLabel",
-          l10n_util::GetStringUTF16(IDS_SYNC_ERROR_USER_MENU_SIGNOUT_BUTTON));
+          l10n_util::GetStringUTF16(
+              create_param->profile_creation_required_by_policy
+                  ? IDS_SYNC_ERROR_USER_MENU_SIGNOUT_BUTTON
+                  : IDS_SIGNIN_DICE_WEB_INTERCEPT_BUBBLE_CHROME_SIGNIN_DECLINE_TEXT));
     }
   } else if (is_school_account) {
     update_data.Set("separateBrowsingDataTitle",
@@ -380,7 +371,7 @@ void ManagedUserProfileNoticeUI::Initialize(
     ProfileStatisticsFactory::GetForProfile(profile)->GatherStatistics(
         base::BindRepeating(
             &ManagedUserProfileNoticeUI::UpdateBrowsingDataStringWithCounts,
-            weak_ptr_factory_.GetWeakPtr()));
+            weak_ptr_factory_.GetWeakPtr(), base::UTF8ToUTF16(domain)));
   }
 
   content::WebUIDataSource::Update(
@@ -400,6 +391,7 @@ ManagedUserProfileNoticeUI::GetHandlerForTesting() {
 }
 
 void ManagedUserProfileNoticeUI::UpdateBrowsingDataStringWithCounts(
+    std::u16string domain,
     profiles::ProfileCategoryStats stats) {
   int browsing_history_count = 0;
   int bookmarks_count = 0;
@@ -437,24 +429,25 @@ void ManagedUserProfileNoticeUI::UpdateBrowsingDataStringWithCounts(
   if (string_replacements.empty()) {
     return;
   }
+  string_replacements.push_back(std::move(domain));
 
   base::Value::Dict update_data;
   std::u16string browsing_data_string;
-  if (string_replacements.size() == 1) {
+  if (string_replacements.size() == 2) {
     update_data.Set(
         "mergeBrowsingDataChoiceDetails",
         l10n_util::GetStringFUTF16(
             IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_ONE_COUNT_CHOICE_DETAILS,
             string_replacements, nullptr));
   }
-  if (string_replacements.size() == 2) {
+  if (string_replacements.size() == 3) {
     update_data.Set(
         "mergeBrowsingDataChoiceDetails",
         l10n_util::GetStringFUTF16(
             IDS_ENTERPRISE_WELCOME_MERGE_BROWSING_DATA_WITH_TWO_COUNTS_CHOICE_DETAILS,
             string_replacements, nullptr));
   }
-  if (string_replacements.size() == 3) {
+  if (string_replacements.size() == 4) {
     update_data.Set(
         "mergeBrowsingDataChoiceDetails",
         l10n_util::GetStringFUTF16(
