@@ -184,14 +184,14 @@ TurnSyncOnHelper::TurnSyncOnHelper(
     SigninAbortedMode signin_aborted_mode,
     std::unique_ptr<Delegate> delegate,
     base::OnceClosure callback,
-    bool turn_sync_on_signed_profile)
+    bool user_already_signed_in)
     : delegate_(std::move(delegate)),
       profile_(profile),
       identity_manager_(IdentityManagerFactory::GetForProfile(profile)),
       signin_access_point_(signin_access_point),
       signin_promo_action_(signin_promo_action),
       signin_aborted_mode_(signin_aborted_mode),
-      turn_sync_on_signed_profile_(turn_sync_on_signed_profile),
+      user_already_signed_in_(user_already_signed_in),
       account_info_(
           identity_manager_->FindExtendedAccountInfoByAccountId(account_id)),
       scoped_callback_runner_(std::move(callback)),
@@ -201,7 +201,10 @@ TurnSyncOnHelper::TurnSyncOnHelper(
           TurnSyncOnHelperShutdownNotifierFactory::GetInstance()
               ->Get(profile)
               ->Subscribe(base::BindOnce(&TurnSyncOnHelper::AbortAndDelete,
-                                         base::Unretained(this)))) {
+                                         base::Unretained(this)))),
+      enable_automatic_management_disclaimer_on_primary_account_change_(
+          enterprise_util::DisableAutomaticManagementDisclaimerUntilReset(
+              profile)) {
   DCHECK(delegate_);
   DCHECK(profile_);
   // Should not start syncing if the profile is already authenticated
@@ -226,7 +229,7 @@ TurnSyncOnHelper::TurnSyncOnHelper(
     const CoreAccountId& account_id,
     SigninAbortedMode signin_aborted_mode,
     bool is_sync_promo,
-    bool turn_sync_on_signed_profile)
+    bool user_already_signed_in)
     : TurnSyncOnHelper(profile,
                        signin_access_point,
                        signin_promo_action,
@@ -235,9 +238,9 @@ TurnSyncOnHelper::TurnSyncOnHelper(
                        std::make_unique<TurnSyncOnHelperDelegateImpl>(
                            browser,
                            is_sync_promo,
-                           turn_sync_on_signed_profile),
+                           user_already_signed_in),
                        base::OnceClosure(),
-                       turn_sync_on_signed_profile) {
+                       user_already_signed_in) {
   // If this is a promo, the account should not be removed on abort.
   CHECK(!is_sync_promo ||
         signin_aborted_mode == SigninAbortedMode::KEEP_ACCOUNT);
@@ -329,7 +332,7 @@ void TurnSyncOnHelper::OnEnterpriseAccountConfirmation(
       if (delegate_->IsProfileCreationRequiredByPolicy() &&
           !enterprise_util::UserAcceptedAccountManagement(profile_)) {
         signin_aborted_mode_ = SigninAbortedMode::REMOVE_ACCOUNT;
-      } else if (!turn_sync_on_signed_profile_) {
+      } else if (!user_already_signed_in_) {
         signin_aborted_mode_ = SigninAbortedMode::KEEP_ACCOUNT_ON_WEB_ONLY;
       }
       base::RecordAction(
@@ -354,6 +357,13 @@ void TurnSyncOnHelper::OnEnterpriseAccountConfirmation(
 void TurnSyncOnHelper::TurnSyncOnWithProfileMode(ProfileMode profile_mode) {
   switch (profile_mode) {
     case ProfileMode::CURRENT_PROFILE: {
+      if (base::FeatureList::IsEnabled(
+              switches::kEnforceManagementDisclaimer) &&
+          account_info_.CanApplyAccountLevelEnterprisePolicies() ==
+              signin::Tribool::kFalse) {
+        SigninAndShowSyncConfirmationUI();
+        return;
+      }
       // If this is a new signin (no account authenticated yet) try loading
       // policy for this user now, before any signed in services are
       // initialized.
@@ -597,7 +607,7 @@ void TurnSyncOnHelper::ShowSyncConfirmationUI() {
   }
   // Use the email-based heuristic if `account_info_` isn't fully initialized.
   const bool is_managed_account = signin::TriboolToBoolOr(
-      account_info_.IsManaged(),
+      account_info_.CanApplyAccountLevelEnterprisePolicies(),
       signin::AccountManagedStatusFinder::MayBeEnterpriseUserBasedOnEmail(
           account_info_.email));
   delegate_->ShowSyncDisabledConfirmation(
