@@ -12,12 +12,14 @@
 #include "base/check_op.h"
 #include "base/containers/contains.h"
 #include "base/containers/to_vector.h"
+#include "base/feature_list.h"
 #include "base/functional/callback.h"
 #include "base/memory/weak_ptr.h"
 #include "base/notreached.h"
 #include "base/strings/utf_string_conversions.h"
 #include "components/autofill/core/browser/country_type.h"
 #include "components/autofill/core/browser/data_manager/addresses/address_data_cleaner.h"
+#include "components/autofill/core/browser/data_manager/addresses/home_and_work_metadata_store.h"
 #include "components/autofill/core/browser/data_quality/addresses/profile_requirement_utils.h"
 #include "components/autofill/core/browser/geo/alternative_state_name_map_updater.h"
 #include "components/autofill/core/browser/geo/autofill_country.h"
@@ -125,9 +127,10 @@ AddressDataManager::~AddressDataManager() {
 }
 
 void AddressDataManager::Shutdown() {
-  // These classes' sync observers needs to be unregistered.
+  // These classes' sync observers need to be unregistered.
   contact_info_precondition_checker_.reset();
   address_data_cleaner_.reset();
+  home_and_work_metadata_.reset();
 }
 
 void AddressDataManager::AddObserver(AddressDataManager::Observer* obs) {
@@ -157,7 +160,12 @@ void AddressDataManager::OnWebDataServiceRequestDone(
   std::vector<AutofillProfile> profiles_from_db =
       static_cast<WDResult<std::vector<AutofillProfile>>*>(result.get())
           ->GetValue();
-  profiles_ = std::move(profiles_from_db);
+  if (!home_and_work_metadata_) {
+    profiles_ = std::move(profiles_from_db);
+  } else {
+    profiles_ = home_and_work_metadata_->ApplyMetadata(
+        std::move(profiles_from_db), !has_initial_load_finished_);
+  }
 
   if (!has_initial_load_finished_) {
     has_initial_load_finished_ = true;
@@ -177,9 +185,15 @@ std::vector<const AutofillProfile*> AddressDataManager::GetProfiles(
 std::vector<const AutofillProfile*> AddressDataManager::GetProfilesByRecordType(
     AutofillProfile::RecordType record_type,
     ProfileOrder order) const {
+  return GetProfilesByRecordType(DenseSet({record_type}), order);
+}
+
+std::vector<const AutofillProfile*> AddressDataManager::GetProfilesByRecordType(
+    DenseSet<AutofillProfile::RecordType> record_types,
+    ProfileOrder order) const {
   std::vector<const AutofillProfile*> profiles = GetProfiles(order);
   std::erase_if(profiles, [&](const AutofillProfile* p) {
-    return p->record_type() != record_type;
+    return !record_types.contains(p->record_type());
   });
   return profiles;
 }
@@ -187,19 +201,9 @@ std::vector<const AutofillProfile*> AddressDataManager::GetProfilesByRecordType(
 std::vector<const AutofillProfile*> AddressDataManager::GetProfilesToSuggest()
     const {
   if (!IsAutofillProfileEnabled()) {
-    return std::vector<const AutofillProfile*>{};
+    return {};
   }
-  std::vector<const AutofillProfile*> profiles =
-      GetProfiles(ProfileOrder::kHighestFrecencyDesc);
-  // H/W addresses are prioritized for suggestion purposes.
-  std::ranges::stable_partition(profiles,
-                                &AutofillProfile::IsHomeAndWorkProfile);
-  if (profiles.size() >= 2 &&
-      profiles[0]->record_type() == AutofillProfile::RecordType::kAccountWork &&
-      profiles[1]->record_type() == AutofillProfile::RecordType::kAccountHome) {
-    std::swap(profiles[0], profiles[1]);
-  }
-  return profiles;
+  return GetProfiles(ProfileOrder::kHighestFrecencyDesc);
 }
 
 std::vector<const AutofillProfile*> AddressDataManager::GetProfilesForSettings()
@@ -333,6 +337,9 @@ void AddressDataManager::RecordUseOf(const AutofillProfile& profile) {
   }
   AutofillProfile updated_profile = *adm_profile;
   updated_profile.RecordAndLogUse();
+  if (home_and_work_metadata_) {
+    home_and_work_metadata_->RecordProfileFill(updated_profile);
+  }
   UpdateProfile(updated_profile);
 }
 
@@ -480,6 +487,13 @@ void AddressDataManager::SetPrefService(PrefService* pref_service) {
         prefs::kAutofillProfileEnabled, pref_service_,
         base::BindRepeating(&AddressDataManager::OnAutofillProfilePrefChanged,
                             base::Unretained(this)));
+    if (base::FeatureList::IsEnabled(
+            features::kAutofillEnableSupportForHomeAndWork)) {
+      home_and_work_metadata_ = std::make_unique<HomeAndWorkMetadataStore>(
+          pref_service_, sync_service_,
+          base::BindRepeating(&AddressDataManager::LoadProfiles,
+                              base::Unretained(this)));
+    }
   }
 }
 
@@ -749,6 +763,9 @@ void AddressDataManager::HandleNextProfileChange(const std::string& guid) {
       break;
     }
   }
+  if (home_and_work_metadata_) {
+    home_and_work_metadata_->ApplyChange(change);
+  }
   is_ongoing = true;
 }
 
@@ -793,9 +810,9 @@ void AddressDataManager::RemoveProfileImpl(const std::string& guid,
     return;
   }
 
-  // Find the profile to remove.
-  // TODO(crbug.com/40258814): This shouldn't be necessary. Providing a `guid`
-  // to the `AutofillProfileChange()` should suffice for removals.
+  // Find the profile to remove. Even for removals the profile is a necessary
+  // part of the AutofillProfileChange, so downstream code an distinguish by
+  // RecordType.
   const AutofillProfile* profile =
       ProfileChangesAreOngoing(guid)
           ? &ongoing_profile_changes_[guid].back().first.data_model()
@@ -807,7 +824,8 @@ void AddressDataManager::RemoveProfileImpl(const std::string& guid,
 
   ongoing_profile_changes_[guid].emplace_back(
       AutofillProfileChange(
-          profile->IsAccountProfile() && is_deduplication_initiated
+          (profile->IsAccountProfile() && is_deduplication_initiated) ||
+                  profile->IsHomeAndWorkProfile()
               ? AutofillProfileChange::HIDE_IN_AUTOFILL
               : AutofillProfileChange::REMOVE,
           guid, *profile),
