@@ -5,9 +5,14 @@
 #include "components/signin/public/base/signin_switches.h"
 
 #include "base/feature_list.h"
+#include "base/time/time.h"
 #include "components/prefs/pref_service.h"
 #include "components/signin/public/base/signin_pref_names.h"
 
+#if BUILDFLAG(IS_WIN)
+#include "base/win/windows_version.h"
+#endif
+
 namespace switches {
 
 // All switches in alphabetical order.
@@ -17,16 +22,20 @@ BASE_FEATURE(kCctSignInPrompt,
              "CctSignInPrompt",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
+BASE_FEATURE(kForceHistoryOptInScreen,
+             "ForceHistoryOptInScreen",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
 // Add history sync opt-in promo in the History Page.
 BASE_FEATURE(kHistoryPageHistorySyncPromo,
              "HistoryPageHistorySyncPromo",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+             base::FEATURE_ENABLED_BY_DEFAULT);
 
 // Makes the History Page history opt-in promo use a different CTA String.
 // No-op unless "HistoryPageHistorySyncPromo" is enabled.
 BASE_FEATURE(kHistoryPagePromoCtaStringVariation,
              "HistoryPagePromoCtaStringVariation",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+             base::FEATURE_ENABLED_BY_DEFAULT);
 
 // Enables a history sync educational tip in the magic stack on NTP.
 BASE_FEATURE(kHistoryOptInEducationalTip,
@@ -58,6 +67,10 @@ BASE_FEATURE(kUseHostedDomainForManagementCheckOnSignin,
 BASE_FEATURE(kMakeAccountsAvailableInIdentityManager,
              "MakeAccountsAvailableInIdentityManager",
              base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kSmartEmailLineBreaking,
+             "SmartEmailLineBreaking",
+             base::FEATURE_ENABLED_BY_DEFAULT);
 #endif
 
 #if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
@@ -78,6 +91,13 @@ BASE_FEATURE(kEnableHistorySyncOptinFromTabHelper,
 BASE_FEATURE(kBrowserSigninInSyncHeaderOnGaiaIntegration,
              "BrowserSigninInSyncHeaderOnGaiaIntegration",
              base::FEATURE_ENABLED_BY_DEFAULT);
+// Whether we re-try showing the signing in interception bubble if the Dice
+// sync header does not arrive within a time window from the LST token.
+// This flag is meant to be used as a kill switch, as the feature starts enabled
+// by default.
+BASE_FEATURE(kRetryInterceptionBubbleOnDiceSyncHeaderTimeout,
+             "RetryInterceptionBubbleOnDiceSyncHeaderTimeout",
+             base::FEATURE_ENABLED_BY_DEFAULT);
 
 // Enables the History Sync Opt-in expansion pill on Desktop.
 BASE_FEATURE(kEnableHistorySyncOptinExpansionPill,
@@ -125,7 +145,12 @@ BASE_FEATURE(kWebSigninLeadsToImplicitlySignedInState,
 // Enable experimental binding session credentials to the device.
 BASE_FEATURE(kEnableBoundSessionCredentials,
              "EnableBoundSessionCredentials",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+#if BUILDFLAG(IS_WIN)
+             base::FEATURE_ENABLED_BY_DEFAULT
+#else
+             base::FEATURE_DISABLED_BY_DEFAULT
+#endif
+);
 
 bool IsBoundSessionCredentialsEnabled(const PrefService* profile_prefs) {
   // Enterprise policy takes precedence over the feature value.
@@ -153,6 +178,13 @@ const base::FeatureParam<std::string>
     kEnableBoundSessionCredentialsExclusiveRegistrationPath{
         &kEnableBoundSessionCredentials, "exclusive-registration-path", ""};
 
+// Allows to disable the bound session credentials code in case of emergency.
+BASE_FEATURE(kBoundSessionCredentialsKillSwitch,
+             "BoundSessionCredentialsKillSwitch",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+#endif  // BUILDFLAG(ENABLE_BOUND_SESSION_CREDENTIALS)
+
+#if BUILDFLAG(ENABLE_DICE_SUPPORT)
 // Enables Chrome refresh tokens binding to a device.
 BASE_FEATURE(kEnableChromeRefreshTokenBinding,
              "EnableChromeRefreshTokenBinding",
@@ -167,17 +199,12 @@ bool IsChromeRefreshTokenBindingEnabled(const PrefService* profile_prefs) {
   return base::FeatureList::IsEnabled(kEnableChromeRefreshTokenBinding);
 }
 
-// Allows to disable the bound session credentials code in case of emergency.
-BASE_FEATURE(kBoundSessionCredentialsKillSwitch,
-             "BoundSessionCredentialsKillSwitch",
-             base::FEATURE_DISABLED_BY_DEFAULT);
-
 // When enabled, Chrome will always use the /IssueToken endpoint to fetch access
 // tokens, no matter if a refresh token is bound or not.
 BASE_FEATURE(kUseIssueTokenToFetchAccessTokens,
              "UseIssueTokenToFetchAccessTokens",
              base::FEATURE_DISABLED_BY_DEFAULT);
-#endif
+#endif  // BUILDFLAG(ENABLE_DICE_SUPPORT)
 
 BASE_FEATURE(kEnablePreferencesAccountStorage,
              "EnablePreferencesAccountStorage",
@@ -203,6 +230,32 @@ BASE_FEATURE(kInterceptBubblesDismissibleByAvatarButton,
              "InterceptBubblesDismissibleByAvatarButton",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
+BASE_FEATURE(kOfferMigrationToDiceUsers,
+             "OfferMigrationToDiceUsers",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kRollbackDiceMigration,
+             "RollbackDiceMigration",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kOfferMigrationToDiceUsersMinDelay,
+                   &kOfferMigrationToDiceUsers,
+                   "offer_migration_to_dice_users_min_delay",
+                   base::Seconds(30));
+
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kOfferMigrationToDiceUsersMaxDelay,
+                   &kOfferMigrationToDiceUsers,
+                   "offer_migration_to_dice_users_max_delay",
+                   base::Minutes(5));
+
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kOfferMigrationToDiceUsersMinTimeBetweenDialogs,
+                   &kOfferMigrationToDiceUsers,
+                   "offer_migration_to_dice_users_min_time_between_dialogs",
+                   base::Days(7));
+
 #if BUILDFLAG(IS_IOS)
 
 BASE_FEATURE(kEnableIdentityInAuthError,
@@ -216,22 +269,15 @@ BASE_FEATURE(kEnableErrorBadgeOnIdentityDisc,
 BASE_FEATURE(kEnableASWebAuthenticationSession,
              "EnableASWebAuthenticationSession",
              base::FEATURE_ENABLED_BY_DEFAULT);
-#endif
 
-// Enables showing the enterprise dialog after every signin into a managed
-// account.
-BASE_FEATURE(kShowEnterpriseDialogForAllManagedAccountsSignin,
-             "ShowEnterpriseDialogForAllManagedAccountsSignin",
-             base::FEATURE_ENABLED_BY_DEFAULT);
+BASE_FEATURE(kAllowlistScopesForMdmErrors,
+             "AllowlistScopesForMdmErrors",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+#endif
 
 BASE_FEATURE(kEnableExtensionsExplicitBrowserSignin,
              "EnableExtensionsExplicitBrowserSignin",
-#if BUILDFLAG(IS_IOS) || BUILDFLAG(IS_ANDROID)
-             base::FEATURE_ENABLED_BY_DEFAULT
-#else
-             base::FEATURE_DISABLED_BY_DEFAULT
-#endif
-);
+             base::FEATURE_ENABLED_BY_DEFAULT);
 
 bool IsExtensionsExplicitBrowserSigninEnabled() {
   return base::FeatureList::IsEnabled(kEnableExtensionsExplicitBrowserSignin);
@@ -246,16 +292,128 @@ BASE_FEATURE(kSyncEnableBookmarksInTransportMode,
 #endif  // BUILDFLAG(IS_IOS)
 );
 
-BASE_FEATURE(kDeferWebSigninTrackerCreation,
-             "DeferWebSigninTrackerCreation",
-             base::FEATURE_ENABLED_BY_DEFAULT);
-
 #if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
 BASE_FEATURE(kSignInPromoMaterialNextUI,
              "SignInPromoMaterialNextUI",
              base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveyAddressBubbleSignin,
+             "ChromeIdentitySurveyAddressBubbleSignin",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveyDiceWebSigninAccepted,
+             "ChromeIdentitySurveyDiceWebSigninAccepted",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveyDiceWebSigninDeclined,
+             "ChromeIdentitySurveyDiceWebSigninDeclined",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveyFirstRunSignin,
+             "ChromeIdentitySurveyFirstRunSignin",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveyPasswordBubbleSignin,
+             "ChromeIdentitySurveyPasswordBubbleSignin",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveyProfileMenuDismissed,
+             "ChromeIdentitySurveyProfileMenuDismissed",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveyProfileMenuSignin,
+             "ChromeIdentitySurveyProfileMenuSignin",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveyProfilePickerAddProfileSignin,
+             "ChromeIdentitySurveyProfilePickerAddProfileSignin",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveySigninInterceptProfileSeparation,
+             "ChromeIdentitySurveySigninInterceptProfileSeparation",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveySigninPromoBubbleDismissed,
+             "ChromeIdentitySurveySigninPromoBubbleDismissed",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveySwitchProfileFromProfileMenu,
+             "ChromeIdentitySurveySwitchProfileFromProfileMenu",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveySwitchProfileFromProfilePicker,
+             "ChromeIdentitySurveySwitchProfileFromProfilePicker",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kChromeIdentitySurveyLaunchWithDelay,
+             "ChromeIdentitySurveyLaunchWithDelay",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kChromeIdentitySurveyLaunchWithDelayDuration,
+                   &kChromeIdentitySurveyLaunchWithDelay,
+                   "launch_delay_duration",
+                   base::Milliseconds(3000));
+
 #endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC) || BUILDFLAG(IS_LINUX)
 
+#if BUILDFLAG(ENABLE_DICE_SUPPORT)
+// Enables the management disclaimer for managed signed profiles. All signed in
+// profiles that never saw the management disclaimer will be shown the
+// management disclaimer when they open Chrome. Every time the primary signed in
+// account changes to a managed account, the management disclaimer will be
+// shown. This is only for desktop platforms.
+BASE_FEATURE(kEnforceManagementDisclaimer,
+             "EnforceManagementDisclaimer",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+#endif
+
+#if BUILDFLAG(IS_WIN)
+// Enables expanding the Avatar Pill to show a sync promo. Expected to be used
+// by Windows users only.
+BASE_FEATURE(kAvatarButtonSyncPromo,
+             "AvatarButtonSyncPromo",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kAvatarButtonSyncPromoMinimumCookieAgeParam,
+                   &kAvatarButtonSyncPromo,
+                   "minimum-cookie-age",
+                   base::Days(14));
+#endif
+// Convenient testing flag for `kAvatarButtonSyncPromo` on all platforms.
+// Also reduces the minimum cookie age to 30 seconds.
+BASE_FEATURE(kAvatarButtonSyncPromoForTesting,
+             "AvatarButtonSyncPromoForTesting",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+bool IsAvatarSyncPromoFeatureEnabled() {
+  if (base::FeatureList::IsEnabled(
+          switches::kAvatarButtonSyncPromoForTesting)) {
+    return true;
+  }
+#if BUILDFLAG(IS_WIN)
+  return (base::win::GetVersion() >= base::win::Version::WIN7 &&
+          base::win::GetVersion() <= base::win::Version::WIN10_22H2) &&
+         base::FeatureList::IsEnabled(switches::kAvatarButtonSyncPromo);
+#else
+  return false;
+#endif
+}
+
+base::TimeDelta GetAvatarSyncPromoFeatureMinimumCookeAgeParam() {
+  CHECK(IsAvatarSyncPromoFeatureEnabled());
+
+  if (base::FeatureList::IsEnabled(
+          switches::kAvatarButtonSyncPromoForTesting)) {
+    return base::Seconds(30);
+  }
+#if BUILDFLAG(IS_WIN)
+  return kAvatarButtonSyncPromoMinimumCookieAgeParam.Get();
+#else
+  NOTREACHED();
+#endif
+}
+
 }  // namespace switches
 
 #if BUILDFLAG(IS_CHROMEOS)
@@ -280,7 +438,3 @@ BASE_FEATURE(kIgnoreMirrorHeadersInBackgoundTabs,
 BASE_FEATURE(kNonDefaultGaiaOriginCheck,
              "NonDefaultGaiaOriginCheck",
              base::FEATURE_ENABLED_BY_DEFAULT);
-
-BASE_FEATURE(kUseAccountCapabilityToDetermineAccountManagement,
-             "UseAccountCapabilityToDetermineAccountManagement",
-             base::FEATURE_DISABLED_BY_DEFAULT);
