@@ -60,7 +60,7 @@ BASE_FEATURE(kOfferPinToTaskbarWhenSettingToDefault,
              base::FEATURE_ENABLED_BY_DEFAULT);
 BASE_FEATURE(kOfferPinToTaskbarInFirstRunExperience,
              "OfferPinToTaskbarInFirstRunExperience",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+             base::FEATURE_ENABLED_BY_DEFAULT);
 BASE_FEATURE(kOfferPinToTaskbarInfoBar,
              "OfferPinToTaskbarInfoBar",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -70,6 +70,17 @@ BASE_FEATURE(kOfferPinToTaskbarInfoBar,
 // Shows an infobar on PDFs offering to become the default PDF viewer if Chrome
 // isn't the default already.
 BASE_FEATURE(kPdfInfoBar, "PdfInfoBar", base::FEATURE_DISABLED_BY_DEFAULT);
+
+constexpr base::FeatureParam<PdfInfoBarTrigger>::Option
+    kPdfInfoBarTriggerOptions[] = {{PdfInfoBarTrigger::kPdfLoad, "pdf-load"},
+                                   {PdfInfoBarTrigger::kStartup, "startup"}};
+
+BASE_FEATURE_ENUM_PARAM(PdfInfoBarTrigger,
+                        kPdfInfoBarTrigger,
+                        &kPdfInfoBar,
+                        "trigger",
+                        PdfInfoBarTrigger::kPdfLoad,
+                        &kPdfInfoBarTriggerOptions);
 #endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC)
 
 // Preloads a WebContents with a Top Chrome WebUI on BrowserView initialization,
@@ -85,11 +96,16 @@ BASE_FEATURE(kPreloadTopChromeWebUILessNavigations,
 
 // Enables exiting browser fullscreen (users putting the browser itself into the
 // fullscreen mode via the browser UI or shortcuts) with press-and-hold Esc.
-#if !BUILDFLAG(IS_ANDROID)
 BASE_FEATURE(kPressAndHoldEscToExitBrowserFullscreen,
              "PressAndHoldEscToExitBrowserFullscreen",
              base::FEATURE_ENABLED_BY_DEFAULT);
-#endif
+
+// When enabled, reloading using the toolbar button, hotkey, and web contents
+// context menu will only reload the active tab. The tab context menu will still
+// use the selection model to reload.
+BASE_FEATURE(kReloadSelectionModel,
+             "ReloadSelectionModel",
+             base::FEATURE_DISABLED_BY_DEFAULT);
 
 // When enabled, a scrim is shown behind window modal dialogs to cover the
 // entire browser window. This gives user a visual cue that the browser window
@@ -112,41 +128,61 @@ BASE_FEATURE_PARAM(base::TimeDelta,
                    kSideBySideShowDropTargetDelay,
                    &kSideBySide,
                    "drop_target_show_delay",
-                   base::Seconds(1));
-
-// The padding inside the drop target that determines the overall width.
+                   base::Milliseconds(500));
 BASE_FEATURE_PARAM(int,
-                   kSideBySideDropTargetInnerPadding,
+                   kSideBySideDropTargetMinWidth,
                    &kSideBySide,
-                   "drop_target_inner_padding",
-                   37);
+                   "drop_target_min_width",
+                   120);
+BASE_FEATURE_PARAM(int,
+                   kSideBySideDropTargetMaxWidth,
+                   &kSideBySide,
+                   "drop_target_max_width",
+                   360);
+BASE_FEATURE_PARAM(int,
+                   kSideBySideDropTargetTargetWidthPercentage,
+                   &kSideBySide,
+                   "drop_target_width_percentage",
+                   30);
 
 constexpr base::FeatureParam<MiniToolbarActiveConfiguration>::Option
     kMiniToolbarActiveConfigurationOptions[] = {
         {MiniToolbarActiveConfiguration::Hide, "hide"},
-        {MiniToolbarActiveConfiguration::ShowMenuOnly, "showmenuonly"},
-        {MiniToolbarActiveConfiguration::ShowAll, "showall"}};
+        {MiniToolbarActiveConfiguration::ShowMenu, "showmenu"},
+        {MiniToolbarActiveConfiguration::ShowClose, "showclose"}};
 
 // The active configuration for the mini toolbar on active view of a split.
 BASE_FEATURE_ENUM_PARAM(MiniToolbarActiveConfiguration,
                         kSideBySideMiniToolbarActiveConfiguration,
                         &kSideBySide,
                         "mini_toolbar_active_config",
-                        MiniToolbarActiveConfiguration::Hide,
+                        MiniToolbarActiveConfiguration::ShowMenu,
                         &kMiniToolbarActiveConfigurationOptions);
 
+BASE_FEATURE_PARAM(int,
+                   kSideBySideSnapDistance,
+                   &kSideBySide,
+                   "snap_distance",
+                   5);
+
+// When enabled along with SideBySide flag, split tabs will be restored on
+// startup.
+BASE_FEATURE(kSideBySideSessionRestore,
+             "SideBySideSessionRestore",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+bool IsRestoringSplitViewEnabled() {
+  return base::FeatureList::IsEnabled(features::kSideBySide) &&
+         base::FeatureList::IsEnabled(features::kSideBySideSessionRestore);
+}
+
 BASE_FEATURE(kSideBySideLinkMenuNewBadge,
              "SideBySideLinkMenuNewBadge",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
-bool IsNtpFooterEnabledWithoutSideBySide() {
-  return (base::FeatureList::IsEnabled(ntp_features::kNtpFooter) &&
-          !base::FeatureList::IsEnabled(features::kSideBySide));
-}
-
 BASE_FEATURE(kSidePanelResizing,
              "SidePanelResizing",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+             base::FEATURE_ENABLED_BY_DEFAULT);
 
 BASE_FEATURE(kTabDuplicateMetrics,
              "TabDuplicateMetrics",
@@ -174,6 +210,10 @@ BASE_FEATURE(kTabHoverCardImages,
 #endif
 );
 
+BASE_FEATURE(kTabModalUsesDesktopWidget,
+             "TabModalUsesDesktopWidget",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
 BASE_FEATURE(kTabOrganization,
              "TabOrganization",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -182,6 +222,36 @@ bool IsTabOrganization() {
   return base::FeatureList::IsEnabled(features::kTabOrganization);
 }
 
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kTabOrganizationTriggerPeriod,
+                   &kTabOrganization,
+                   "trigger_period",
+                   base::Hours(6));
+
+BASE_FEATURE_PARAM(double,
+                   kTabOrganizationTriggerBackoffBase,
+                   &kTabOrganization,
+                   "backoff_base",
+                   2.0);
+
+BASE_FEATURE_PARAM(double,
+                   kTabOrganizationTriggerThreshold,
+                   &kTabOrganization,
+                   "trigger_threshold",
+                   7.0);
+
+BASE_FEATURE_PARAM(double,
+                   kTabOrganizationTriggerSensitivityThreshold,
+                   &kTabOrganization,
+                   "trigger_sensitivity_threshold",
+                   0.5);
+
+BASE_FEATURE_PARAM(bool,
+                   KTabOrganizationTriggerDemoMode,
+                   &kTabOrganization,
+                   "trigger_demo_mode",
+                   false);
+
 BASE_FEATURE(kTabstripDeclutter,
              "TabstripDeclutter",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -190,6 +260,24 @@ bool IsTabstripDeclutterEnabled() {
   return base::FeatureList::IsEnabled(features::kTabstripDeclutter);
 }
 
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kTabstripDeclutterStaleThresholdDuration,
+                   &kTabstripDeclutter,
+                   "stale_threshold_duration",
+                   base::Days(7));
+
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kTabstripDeclutterTimerInterval,
+                   &kTabstripDeclutter,
+                   "declutter_timer_interval",
+                   base::Minutes(10));
+
+BASE_FEATURE_PARAM(base::TimeDelta,
+                   kTabstripDeclutterNudgeTimerInterval,
+                   &kTabstripDeclutter,
+                   "nudge_timer_interval",
+                   base::Minutes(6 * 60));
+
 BASE_FEATURE(kTabstripDedupe,
              "TabstripDedupe",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -227,12 +315,6 @@ BASE_FEATURE(kThreeButtonPasswordSaveDialog,
              base::FEATURE_DISABLED_BY_DEFAULT);
 #endif
 
-#if !defined(ANDROID)
-BASE_FEATURE(kPinnedCastButton,
-             "PinnedCastButton",
-             base::FEATURE_ENABLED_BY_DEFAULT);
-#endif
-
 // Enables enterprise profile badging for managed profiles on the toolbar
 // avatar. On managed profiles, a "Work" or "School" label will be used in the
 // toolbar.
@@ -275,10 +357,6 @@ BASE_FEATURE(kEnterpriseManagementDisclaimerUsesCustomLabel,
              "EnterpriseManagementDisclaimerUsesCustomLabel",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
-BASE_FEATURE(kEnterpriseUpdatedProfileCreationScreen,
-             "EnterpriseUpdatedProfileCreationScreen",
-             base::FEATURE_ENABLED_BY_DEFAULT);
-
 BASE_FEATURE(kManagedProfileRequiredInterstitial,
              "ManagedProfileRequiredInterstitial",
              base::FEATURE_ENABLED_BY_DEFAULT);
@@ -334,9 +412,15 @@ BASE_FEATURE(kEnableManagementPromotionBanner,
              "EnableManagementPromotionBanner",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
+#if BUILDFLAG(IS_CHROMEOS)
 BASE_FEATURE(kEnablePolicyPromotionBanner,
              "EnablePolicyPromotionBanner",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+             base::FEATURE_ENABLED_BY_DEFAULT);
+#else
+BASE_FEATURE(kEnablePolicyPromotionBanner,
+             "EnablePolicyPromotionBanner",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+#endif
 
 BASE_FEATURE(kInlineFullscreenPerfExperiment,
              "InlineFullscreenPerfExperiment",
@@ -346,6 +430,120 @@ BASE_FEATURE(kPageActionsMigration,
              "PageActionsMigration",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationEnableAll,
+                   &kPageActionsMigration,
+                   "enable_all",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationLensOverlay,
+                   &kPageActionsMigration,
+                   "lens_overlay",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationMemorySaver,
+                   &kPageActionsMigration,
+                   "memory_saver",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationTranslate,
+                   &kPageActionsMigration,
+                   "translate",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationIntentPicker,
+                   &kPageActionsMigration,
+                   "intent_picker",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationZoom,
+                   &kPageActionsMigration,
+                   "zoom",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationOfferNotification,
+                   &kPageActionsMigration,
+                   "offer_notification",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationFileSystemAccess,
+                   &kPageActionsMigration,
+                   "file_system_access",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationPwaInstall,
+                   &kPageActionsMigration,
+                   "pwa_install",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationPriceInsights,
+                   &kPageActionsMigration,
+                   "price_insights",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationDiscounts,
+                   &kPageActionsMigration,
+                   "discounts",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationProductSpecifications,
+                   &kPageActionsMigration,
+                   "product_specifications",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationManagePasswords,
+                   &kPageActionsMigration,
+                   "manage_passwords",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationCookieControls,
+                   &kPageActionsMigration,
+                   "cookie_controls",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationAutofillAddress,
+                   &kPageActionsMigration,
+                   "autofill_address",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationFind,
+                   &kPageActionsMigration,
+                   "find",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationCollaborationMessaging,
+                   &kPageActionsMigration,
+                   "collaboration_messaging",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationPriceTracking,
+                   &kPageActionsMigration,
+                   "price_tracking",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kPageActionsMigrationAutofillMandatoryReauth,
+                   &kPageActionsMigration,
+                   "mandatory_reauth",
+                   false);
+
 BASE_FEATURE(kSavePasswordsContextualUi,
              "SavePasswordsContextualUi",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -366,6 +564,8 @@ BASE_FEATURE(kTabstripComboButton,
              "TabstripComboButton",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
+// This serves as a "kill-switch" for migrating the Tab Search feature to be a
+// toolbar button for non-ChromeOS users in the US.
 BASE_FEATURE(kLaunchedTabSearchToolbarButton,
              "LaunchedTabSearchToolbarButton",
 #if BUILDFLAG(IS_CHROMEOS)
@@ -375,6 +575,12 @@ BASE_FEATURE(kLaunchedTabSearchToolbarButton,
 #endif
 );
 
+BASE_FEATURE_PARAM(bool,
+                   kTabSearchToolbarButton,
+                   &kTabstripComboButton,
+                   "tab_search_toolbar_button",
+                   true);
+
 static std::string GetCountryCode() {
   if (!g_browser_process || !g_browser_process->variations_service()) {
     return std::string();
@@ -387,47 +593,30 @@ static std::string GetCountryCode() {
   return country_code;
 }
 
-bool IsTabSearchMoving() {
+bool HasTabSearchToolbarButton() {
   static const bool is_tab_search_moving = [] {
     if (GetCountryCode() == "us" &&
         base::FeatureList::IsEnabled(
             features::kLaunchedTabSearchToolbarButton)) {
       return true;
     }
-    return base::FeatureList::IsEnabled(features::kTabstripComboButton);
+    return base::FeatureList::IsEnabled(features::kTabstripComboButton) &&
+           features::kTabSearchToolbarButton.Get();
   }();
 
   return is_tab_search_moving;
 }
 
-bool HasTabstripComboButtonWithBackground() {
-  return IsTabSearchMoving() &&
-         features::kTabstripComboButtonHasBackground.Get() &&
-         !features::kTabSearchToolbarButton.Get();
-}
+BASE_FEATURE(kNonMilestoneUpdateToast,
+             "NonMilestoneUpdateToast",
+             base::FEATURE_DISABLED_BY_DEFAULT);
 
-bool HasTabstripComboButtonWithReverseButtonOrder() {
-  return IsTabSearchMoving() &&
-         features::kTabstripComboButtonHasReverseButtonOrder.Get() &&
-         !features::kTabSearchToolbarButton.Get();
-}
+BASE_FEATURE(kBookmarkTabGroupConversion,
+             "BookmarkTabGroupConversion",
+             base::FEATURE_DISABLED_BY_DEFAULT);
 
-bool HasTabSearchToolbarButton() {
-  static const bool has_tab_search_toolbar_button = [] {
-    if (!IsTabSearchMoving()) {
-      return false;
-    }
-    if (GetCountryCode() == "us" &&
-        base::FeatureList::IsEnabled(
-            features::kLaunchedTabSearchToolbarButton)) {
-      return true;
-    }
-    // Gate on server-side Finch config for all other countries
-    // as well as ChromeOS.
-    return features::kTabSearchToolbarButton.Get();
-  }();
-
-  return has_tab_search_toolbar_button;
+bool IsBookmarkTabGroupConversionEnabled() {
+  return base::FeatureList::IsEnabled(kBookmarkTabGroupConversion);
 }
 
 }  // namespace features
