@@ -135,13 +135,6 @@ BASE_FEATURE_PARAM(bool,
                    /*name=*/"SplitMaskedDomainList",
                    /*default_value=*/false);
 
-// When enabled, if the MaskedDomainList is used at all, it will use the
-// flatbuffer implementation (the `MaskedDomainList` class) instead of the
-// `UrlMatcherWithBypass` implementation.
-BASE_FEATURE(kMaskedDomainListFlatbufferImpl,
-             "MaskedDomainListFlatbufferImpl",
-             base::FEATURE_ENABLED_BY_DEFAULT);
-
 // If this feature is enabled, the mDNS responder service responds to queries
 // for TXT records associated with
 // "Generated-Names._mdns_name_generator._udp.local" with a list of generated
@@ -162,6 +155,30 @@ BASE_FEATURE(kOpaqueResponseBlockingErrorsForAllFetches,
 // https://tools.ietf.org/html/draft-davidben-http-client-hint-reliability-02#section-4.3
 BASE_FEATURE(kAcceptCHFrame, "AcceptCHFrame", base::FEATURE_ENABLED_BY_DEFAULT);
 
+// Enable offloading the network layer to check enabled client hints.
+// See crbug.com/406407746 for details.
+BASE_FEATURE(kOffloadAcceptCHFrameCheck,
+             "OffloadAcceptCHFrameCheck",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+// Enable offloading the network layer to check enabled client hints even when
+// cross origin redirect happens.
+// See crbug.com/406407746 for details.
+BASE_FEATURE_PARAM(bool,
+                   kAcceptCHOffloadWithRedirect,
+                   &kOffloadAcceptCHFrameCheck,
+                   "AcceptCHOffloadWithRedirect",
+                   false);
+
+// Enable offloading the network layer to check enabled client hints for
+// subframe requests.
+// See crbug.com/406407746 for details.
+BASE_FEATURE_PARAM(bool,
+                   kAcceptCHOffloadForSubframe,
+                   &kOffloadAcceptCHFrameCheck,
+                   "AcceptCHOffloadForSubframe",
+                   false);
+
 // https://fetch.spec.whatwg.org/#cors-non-wildcard-request-header-name
 BASE_FEATURE(kCorsNonWildcardRequestHeadersSupport,
              "CorsNonWildcardRequestHeadersSupport",
@@ -195,13 +212,7 @@ BASE_FEATURE(kReduceAcceptLanguageHTTP,
 // See: https://wicg.github.io/private-network-access/#cors-preflight
 BASE_FEATURE(kPrivateNetworkAccessPreflightShortTimeout,
              "PrivateNetworkAccessPreflightShortTimeout",
-             base::FEATURE_ENABLED_BY_DEFAULT);
-
-// When kPrivateNetworkAccessPermissionPrompt is enabled, public secure websites
-// are allowed to access private insecure subresources with user's permission.
-BASE_FEATURE(kPrivateNetworkAccessPermissionPrompt,
-             "PrivateNetworkAccessPermissionPrompt",
-             base::FEATURE_ENABLED_BY_DEFAULT);
+             base::FEATURE_DISABLED_BY_DEFAULT);
 
 // Enables Local Network Access checks.
 // Blocks local network requests without user permission to prevent exploitation
@@ -210,8 +221,7 @@ BASE_FEATURE(kPrivateNetworkAccessPermissionPrompt,
 // This feature is being built as a replacement for Private Network Access
 // (PNA), and if this is on PNA features may stop working.
 //
-// Public explainer:
-// https://github.com/explainers-by-googlers/local-network-access
+// Spec: https://wicg.github.io/local-network-access/
 BASE_FEATURE(kLocalNetworkAccessChecks,
              "LocalNetworkAccessChecks",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -223,6 +233,15 @@ BASE_FEATURE_PARAM(bool,
                    /*name=*/"LocalNetworkAccessChecksWarn",
                    /*default_value=*/true);
 
+// Enables Local Network Access checks for WebRTC.
+// Blocks local network requests without user permission to prevent exploitation
+// of vulnerable local devices.
+//
+// Spec: https://wicg.github.io/local-network-access/
+BASE_FEATURE(kLocalNetworkAccessChecksWebRTC,
+             "LocalNetworkAccessChecksWebRTC",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
 // If enabled, then the network service will parse the Cookie-Indices header.
 // This does not currently control changing cache behavior according to the
 // value of this header.
@@ -573,7 +592,7 @@ BASE_FEATURE(kGetCookiesOnSet,
 
 BASE_FEATURE(kIncreaseCookieAccessCacheSize,
              "IncreaseCookieAccessCacheSize",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+             base::FEATURE_ENABLED_BY_DEFAULT);
 
 BASE_FEATURE_PARAM(int,
                    kCookieAccessCacheSize,
@@ -628,8 +647,18 @@ BASE_FEATURE_PARAM(size_t,
                    /*name=*/"max_size",
                    1'000'000);
 
-BASE_FEATURE(kNetworkServiceScheduler,
-             "NetworkServiceScheduler",
+BASE_FEATURE(kNetworkServiceTaskScheduler,
+             "NetworkServiceTaskScheduler",
              base::FEATURE_DISABLED_BY_DEFAULT);
+BASE_FEATURE_PARAM(bool,
+                   kNetworkServiceTaskSchedulerResourceScheduler,
+                   &kNetworkServiceTaskScheduler,
+                   "resource_scheduler",
+                   false);
+BASE_FEATURE_PARAM(bool,
+                   kNetworkServiceTaskSchedulerURLLoader,
+                   &kNetworkServiceTaskScheduler,
+                   "url_loader",
+                   false);
 
 }  // namespace network::features
