@@ -10,6 +10,7 @@
 #include "base/feature_list.h"
 #include "build/build_config.h"
 #include "net/base/cronet_buildflags.h"
+#include "net/disk_cache/buildflags.h"
 #include "net/net_buildflags.h"
 
 #if BUILDFLAG(IS_WIN)
@@ -144,6 +145,14 @@ BASE_FEATURE(kPartitionConnectionsByNetworkIsolationKey,
              "PartitionConnectionsByNetworkIsolationKey",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
+BASE_FEATURE(kPrefixCookieHttp,
+             "PrefixCookieHttp",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
+BASE_FEATURE(kPrefixCookieHostHttp,
+             "PrefixCookieHostHttp",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
 BASE_FEATURE(kSearchEnginePreconnectInterval,
              "SearchEnginePreconnectInterval",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -181,6 +190,12 @@ BASE_FEATURE_PARAM(std::string,
                    "QuicConnectionOptions",
                    "");
 
+BASE_FEATURE_PARAM(bool,
+                   kFallbackInLowPowerMode,
+                   &kSearchEnginePreconnect2,
+                   "FallbackInLowPowerMode",
+                   false);
+
 BASE_FEATURE(kShortLaxAllowUnsafeThreshold,
              "ShortLaxAllowUnsafeThreshold",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -536,8 +551,17 @@ const base::FeatureParam<bool> kIpPrivacyDisableForEnterpriseByDefault{
 const base::FeatureParam<bool> kIpPrivacyEnableIppInDevTools{
     &kEnableIpProtectionProxy,
     /*name=*/"IpPrivacyEnableIppInDevTools",
+    /*default_value=*/true};
+
+const base::FeatureParam<bool> kIpPrivacyEnableIppPanelInDevTools{
+    &kEnableIpProtectionProxy,
+    /*name=*/"kIpPrivacyEnableIppPanelInDevTools",
     /*default_value=*/false};
 
+BASE_FEATURE(kEnableIpPrivacyProxyAdvancedFallbackLogic,
+             "EnableIpPrivacyProxyAdvancedFallbackLogic",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
 BASE_FEATURE(kExcludeLargeBodyReports,
              "ExcludeLargeReportBodies",
              base::FEATURE_ENABLED_BY_DEFAULT);
@@ -657,6 +681,9 @@ BASE_FEATURE_PARAM(bool,
 BASE_FEATURE(kDeviceBoundSessionsRefreshQuota,
              "DeviceBoundSessionsRefreshQuota",
              base::FEATURE_ENABLED_BY_DEFAULT);
+BASE_FEATURE(kDeviceBoundSessionsOriginTrialFeedback,
+             "DeviceBoundSessionsOriginTrialFeedback",
+             base::FEATURE_DISABLED_BY_DEFAULT);
 
 BASE_FEATURE(kPartitionProxyChains,
              "PartitionProxyChains",
@@ -684,24 +711,21 @@ BASE_FEATURE(kReportingApiEnableEnterpriseCookieIssues,
 
 BASE_FEATURE(kSimdutfBase64Support,
              "SimdutfBase64Support",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+#if BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN) || BUILDFLAG(IS_LINUX)
+             base::FEATURE_ENABLED_BY_DEFAULT
+#else
+             base::FEATURE_DISABLED_BY_DEFAULT
+#endif
+);
 
 BASE_FEATURE(kFurtherOptimizeParsingDataUrls,
              "FurtherOptimizeParsingDataUrls",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
-BASE_FEATURE(kKeepWhitespaceForDataUrls,
-             "KeepWhitespaceForDataUrls",
-             base::FEATURE_ENABLED_BY_DEFAULT);
-
 BASE_FEATURE(kNoVarySearchIgnoreUnrecognizedKeys,
              "NoVarySearchIgnoreUnrecognizedKeys",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
-BASE_FEATURE(kEncryptedAndPlaintextValuesAreInvalid,
-             "EncryptedAndPlaintextValuesAreInvalid",
-             base::FEATURE_ENABLED_BY_DEFAULT);
-
 BASE_FEATURE(kEnableStaticCTAPIEnforcement,
              "EnableStaticCTAPIEnforcement",
              base::FEATURE_ENABLED_BY_DEFAULT);
@@ -711,11 +735,15 @@ BASE_FEATURE(kDiskCacheBackendExperiment,
              base::FEATURE_DISABLED_BY_DEFAULT);
 constexpr base::FeatureParam<DiskCacheBackend>::Option
     kDiskCacheBackendOptions[] = {
+        {DiskCacheBackend::kDefault, "default"},
         {DiskCacheBackend::kSimple, "simple"},
         {DiskCacheBackend::kBlockfile, "blockfile"},
+#if BUILDFLAG(ENABLE_DISK_CACHE_SQL_BACKEND)
+        {DiskCacheBackend::kSql, "sql"},
+#endif  // ENABLE_DISK_CACHE_SQL_BACKEND
 };
 const base::FeatureParam<DiskCacheBackend> kDiskCacheBackendParam{
-    &kDiskCacheBackendExperiment, "backend", DiskCacheBackend::kBlockfile,
+    &kDiskCacheBackendExperiment, "backend", DiskCacheBackend::kDefault,
     &kDiskCacheBackendOptions};
 
 BASE_FEATURE(kIgnoreHSTSForLocalhost,
@@ -749,6 +777,12 @@ BASE_FEATURE(kHstsTopLevelNavigationsOnly,
              "HstsTopLevelNavigationsOnly",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
+#if BUILDFLAG(IS_WIN)
+BASE_FEATURE(kHttpCacheMappedFileFlushWin,
+             "HttpCacheMappedFileFlushWin",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+#endif
+
 BASE_FEATURE(kHttpCacheNoVarySearch,
              "HttpCacheNoVarySearch",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -759,6 +793,26 @@ BASE_FEATURE_PARAM(size_t,
                    "max_entries",
                    1000);
 
+// TODO(crbug.com/433551601): Change the default to `true` once it has been
+// verified working.
+BASE_FEATURE_PARAM(bool,
+                   kHttpCacheNoVarySearchApplyToExternalHits,
+                   &kHttpCacheNoVarySearch,
+                   "apply_to_external_hits",
+                   false);
+
+BASE_FEATURE_PARAM(bool,
+                   kHttpCacheNoVarySearchPersistenceEnabled,
+                   &kHttpCacheNoVarySearch,
+                   "persistence_enabled",
+                   true);
+
+BASE_FEATURE_PARAM(bool,
+                   kHttpCacheNoVarySearchFakePersistence,
+                   &kHttpCacheNoVarySearch,
+                   "fake_persistence",
+                   false);
+
 BASE_FEATURE(kReportingApiCorsOriginHeader,
              "ReportingApiCorsOriginHeader",
              base::FEATURE_ENABLED_BY_DEFAULT);
@@ -811,4 +865,48 @@ BASE_FEATURE_PARAM(int,
                    "TcpConnectionPoolSizeTrialWebSocket",
                    256);
 
+BASE_FEATURE(kNetTaskScheduler,
+             "NetTaskScheduler",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+BASE_FEATURE_PARAM(bool,
+                   kNetTaskSchedulerHttpProxyConnectJob,
+                   &kNetTaskScheduler,
+                   "http_proxy_connect_job",
+                   false);
+BASE_FEATURE_PARAM(bool,
+                   kNetTaskSchedulerHttpCacheTransaction,
+                   &kNetTaskScheduler,
+                   "http_cache_transaction",
+                   false);
+BASE_FEATURE_PARAM(bool,
+                   kNetTaskSchedulerHttpStreamFactoryJob,
+                   &kNetTaskScheduler,
+                   "http_stream_factory_job",
+                   false);
+BASE_FEATURE_PARAM(bool,
+                   kNetTaskSchedulerHttpStreamFactoryJobController,
+                   &kNetTaskScheduler,
+                   "http_stream_factory_job_controller",
+                   false);
+BASE_FEATURE_PARAM(bool,
+                   kNetTaskSchedulerURLRequestErrorJob,
+                   &kNetTaskScheduler,
+                   "url_request_error_job",
+                   false);
+BASE_FEATURE_PARAM(bool,
+                   kNetTaskSchedulerURLRequestHttpJob,
+                   &kNetTaskScheduler,
+                   "url_request_http_job",
+                   false);
+BASE_FEATURE_PARAM(bool,
+                   kNetTaskSchedulerURLRequestJob,
+                   &kNetTaskScheduler,
+                   "url_request_job",
+                   false);
+BASE_FEATURE_PARAM(bool,
+                   kNetTaskSchedulerURLRequestRedirectJob,
+                   &kNetTaskScheduler,
+                   "url_request_redirect_job",
+                   false);
+
 }  // namespace net::features
