@@ -6,9 +6,10 @@
 
 #include "base/feature_list.h"
 #include "base/metrics/user_metrics.h"
+#include "chrome/browser/autocomplete/aim_eligibility_service_factory.h"
 #include "chrome/browser/search_engines/template_url_service_factory.h"
 #include "chrome/browser/ui/search_engines/template_url_table_model.h"
-#include "components/omnibox/common/omnibox_features.h"
+#include "components/omnibox/browser/aim_eligibility_service.h"
 #include "components/prefs/pref_registry_simple.h"
 #include "components/search_engines/template_url.h"
 #include "components/search_engines/template_url_data.h"
@@ -18,7 +19,11 @@ using base::UserMetricsAction;
 
 KeywordEditorController::KeywordEditorController(Profile* profile)
     : url_model_(TemplateURLServiceFactory::GetForProfile(profile)) {
-  table_model_ = std::make_unique<TemplateURLTableModel>(url_model_);
+  AimEligibilityService* aim_eligibility_service =
+      AimEligibilityServiceFactory::GetForProfile(profile);
+  table_model_ = std::make_unique<TemplateURLTableModel>(
+      url_model_,
+      aim_eligibility_service && aim_eligibility_service->IsAimEligible());
 }
 
 KeywordEditorController::~KeywordEditorController() = default;
