@@ -18,6 +18,7 @@
 #include "base/strings/utf_string_conversions.h"
 #include "build/build_config.h"
 #include "components/history_embeddings/history_embeddings_features.h"
+#include "components/omnibox/browser/aim_eligibility_service.h"
 #include "components/omnibox/browser/autocomplete_input.h"
 #include "components/omnibox/browser/autocomplete_match.h"
 #include "components/omnibox/browser/autocomplete_match_classification.h"
@@ -289,27 +290,35 @@ void FeaturedSearchProvider::AddFeaturedKeywordMatches(
   for (TemplateURL* turl : turls) {
     if (turl->starter_pack_id() > 0 &&
         turl->is_active() == TemplateURLData::ActiveStatus::kTrue) {
-      // Don't add the expanded set of starter pack engines unless the feature
-      // is enabled.
-      if ((turl->starter_pack_id() == template_url_starter_pack_data::kGemini &&
-           !OmniboxFieldTrial::IsStarterPackExpansionEnabled()) ||
-          (turl->starter_pack_id() == template_url_starter_pack_data::kPage &&
-           !omnibox_feature_configs::ContextualSearch::Get()
-                .starter_pack_page)) {
+      // Skip @gemini if feature disabled.
+      if (turl->starter_pack_id() == template_url_starter_pack_data::kGemini &&
+          !OmniboxFieldTrial::IsStarterPackExpansionEnabled()) {
+        continue;
+      }
+      // Skip @page if feature disabled.
+      if (turl->starter_pack_id() == template_url_starter_pack_data::kPage &&
+          !omnibox_feature_configs::ContextualSearch::Get().starter_pack_page) {
+        continue;
+      }
+      // Skip @aimode if feature disabled.
+      if (turl->starter_pack_id() == template_url_starter_pack_data::kAiMode &&
+          (!omnibox_feature_configs::Toolbelt::Get().enabled ||
+           !client_->GetAimEligibilityService() ||
+           !client_->GetAimEligibilityService()->IsAimEligible())) {
         continue;
       }
       // The history starter pack engine is disabled in incognito mode.
-      if (client_->IsOffTheRecord() &&
-          turl->starter_pack_id() == template_url_starter_pack_data::kHistory) {
+      if (turl->starter_pack_id() == template_url_starter_pack_data::kHistory &&
+          client_->IsOffTheRecord()) {
         continue;
       }
       AddStarterPackMatch(*turl, input);
-      // Don't add enterprise search aggregator engines in incognito mode.
     } else if (turl->featured_by_policy() &&
                IsEnterpriseSearchAggregatorTemplateURLEnabled(
                    *turl, client_->IsOffTheRecord()) &&
                turl->is_active() == TemplateURLData::ActiveStatus::kTrue &&
                enterprise_count < kMaxEnterpriseSuggestions) {
+      // Don't add enterprise search aggregator engines in incognito mode.
       AddFeaturedEnterpriseSearchMatch(*turl, input);
       enterprise_count++;
     }
@@ -347,7 +356,7 @@ void FeaturedSearchProvider::AddStarterPackMatch(
       {0, ACMatchClassification::NONE},
       {template_url.keyword().size(), ACMatchClassification::DIM}};
   match.contents.clear();
-  match.contents_class = {{}};
+  match.contents_class = {};
   match.allowed_to_be_default_match = false;
   match.keyword = template_url.keyword();
   matches_.push_back(match);
@@ -405,7 +414,7 @@ void FeaturedSearchProvider::AddFeaturedEnterpriseSearchMatch(
       {0, ACMatchClassification::NONE},
       {template_url.keyword().size(), ACMatchClassification::DIM}};
   match.contents.clear();
-  match.contents_class = {{}};
+  match.contents_class = {};
   match.allowed_to_be_default_match = false;
   match.keyword = template_url.keyword();
   if (template_url.CreatedByEnterpriseSearchAggregatorPolicy()) {
