@@ -57,6 +57,7 @@
 #include "chrome/browser/ui/layout_constants.h"
 #include "chrome/browser/ui/lens/lens_overlay_controller.h"
 #include "chrome/browser/ui/lens/lens_overlay_entry_point_controller.h"
+#include "chrome/browser/ui/lens/lens_string_utils.h"
 #include "chrome/browser/ui/managed_ui.h"
 #include "chrome/browser/ui/profiles/profile_colors_util.h"
 #include "chrome/browser/ui/profiles/profile_view_utils.h"
@@ -72,10 +73,10 @@
 #include "chrome/browser/ui/tabs/tab_strip_model.h"
 #include "chrome/browser/ui/toolbar/app_menu_icon_controller.h"
 #include "chrome/browser/ui/toolbar/bookmark_sub_menu_model.h"
-#include "chrome/browser/ui/toolbar/chrome_labs/chrome_labs_model.h"
 #include "chrome/browser/ui/toolbar/chrome_labs/chrome_labs_prefs.h"
 #include "chrome/browser/ui/toolbar/chrome_labs/chrome_labs_utils.h"
 #include "chrome/browser/ui/ui_features.h"
+#include "chrome/browser/ui/user_education/browser_user_education_interface.h"
 #include "chrome/browser/ui/web_applications/web_app_dialog_utils.h"
 #include "chrome/browser/ui/web_applications/web_app_launch_utils.h"
 #include "chrome/browser/ui/webui/side_panel/customize_chrome/customize_chrome_page_handler.h"
@@ -865,9 +866,10 @@ void ToolsMenuModel::Build(Browser* browser) {
                                            ? IDS_DECLUTTER_MENU
                                            : IDS_DECLUTTER_MENU_NO_DEDUPE,
                                        kTabCloseInactiveIcon);
-      SetIsNewFeatureAt(GetIndexOfCommandId(IDC_DECLUTTER_TABS).value(),
-                        browser->window()->MaybeShowNewBadgeFor(
-                            features::kTabstripDeclutter));
+      SetIsNewFeatureAt(
+          GetIndexOfCommandId(IDC_DECLUTTER_TABS).value(),
+          BrowserUserEducationInterface::From(browser)->MaybeShowNewBadgeFor(
+              features::kTabstripDeclutter));
     }
   }
 
@@ -915,9 +917,8 @@ void ToolsMenuModel::Build(Browser* browser) {
   }
   if (IsChromeLabsEnabled()) {
     auto* profile = browser->profile();
-    chrome_labs_model_ = std::make_unique<ChromeLabsModel>();
-    UpdateChromeLabsNewBadgePrefs(profile, chrome_labs_model_.get());
-    if (ShouldShowChromeLabsUI(chrome_labs_model_.get(), profile)) {
+    UpdateChromeLabsNewBadgePrefs(profile);
+    if (ShouldShowChromeLabsUI(profile)) {
       BooleanPrefMember show_chrome_labs_item;
       show_chrome_labs_item.Init(
           chrome_labs_prefs::kBrowserLabsEnabledEnterprisePolicy,
@@ -988,11 +989,6 @@ AppMenuModel::AppMenuModel(ui::AcceleratorProvider* provider,
 
 AppMenuModel::~AppMenuModel() = default;
 
-void AppMenuModel::SetHighlightedIdentifier(
-    ui::ElementIdentifier highlighted_menu_identifier) {
-  highlighted_menu_identifier_ = highlighted_menu_identifier;
-}
-
 void AppMenuModel::Init() {
   Build();
 
@@ -1091,9 +1087,10 @@ void AppMenuModel::LogMenuMetrics(int command_id) {
       }
       LogMenuAction(MENU_ACTION_SHOW_BOOKMARK_SIDE_PANEL);
       // Close IPH for side panel menu, if shown.
-      browser()->window()->NotifyFeaturePromoFeatureUsed(
-          feature_engagement::kIPHPowerBookmarksSidePanelFeature,
-          FeaturePromoFeatureUsedAction::kIgnorePromoIfPresent);
+      BrowserUserEducationInterface::From(browser())
+          ->NotifyFeaturePromoFeatureUsed(
+              feature_engagement::kIPHPowerBookmarksSidePanelFeature,
+              FeaturePromoFeatureUsedAction::kIgnorePromoIfPresent);
       break;
     case IDC_SHOW_BOOKMARK_MANAGER:
       if (!uma_action_recorded_) {
@@ -1360,9 +1357,10 @@ void AppMenuModel::LogMenuMetrics(int command_id) {
       }
       LogMenuAction(MENU_ACTION_SHOW_READING_MODE_SIDE_PANEL);
       // Close IPH for side panel menu, if shown.
-      browser()->window()->NotifyFeaturePromoFeatureUsed(
-          feature_engagement::kIPHReadingModeSidePanelFeature,
-          FeaturePromoFeatureUsedAction::kIgnorePromoIfPresent);
+      BrowserUserEducationInterface::From(browser())
+          ->NotifyFeaturePromoFeatureUsed(
+              feature_engagement::kIPHReadingModeSidePanelFeature,
+              FeaturePromoFeatureUsedAction::kIgnorePromoIfPresent);
       break;
     case IDC_SHOW_CUSTOMIZE_CHROME_SIDE_PANEL:
       if (!uma_action_recorded_) {
@@ -1371,9 +1369,10 @@ void AppMenuModel::LogMenuMetrics(int command_id) {
       }
       LogMenuAction(MENU_ACTION_SHOW_CUSTOMIZE_CHROME_SIDE_PANEL);
       // Close IPH for side panel menu, if shown.
-      browser()->window()->NotifyFeaturePromoFeatureUsed(
-          feature_engagement::kIPHDesktopCustomizeChromeRefreshFeature,
-          FeaturePromoFeatureUsedAction::kIgnorePromoIfPresent);
+      BrowserUserEducationInterface::From(browser())
+          ->NotifyFeaturePromoFeatureUsed(
+              feature_engagement::kIPHDesktopCustomizeChromeRefreshFeature,
+              FeaturePromoFeatureUsedAction::kIgnorePromoIfPresent);
       break;
     // Zoom menu
     case IDC_ZOOM_MINUS:
@@ -1719,10 +1718,6 @@ bool AppMenuModel::IsCommandIdAlerted(int command_id) const {
   return false;
 }
 
-bool AppMenuModel::IsElementIdAlerted(ui::ElementIdentifier element_id) const {
-  return highlighted_menu_identifier_ == element_id;
-}
-
 bool AppMenuModel::GetAcceleratorForCommandId(
     int command_id,
     ui::Accelerator* accelerator) const {
@@ -1886,9 +1881,10 @@ void AppMenuModel::Build() {
                                      IDS_GLIC_THREE_DOT_MENU_ITEM,
                                      glic::GlicVectorIconManager::GetVectorIcon(
                                          IDR_GLIC_BUTTON_VECTOR_ICON));
-    SetIsNewFeatureAt(GetIndexOfCommandId(IDC_OPEN_GLIC).value(),
-                      browser()->window()->MaybeShowNewBadgeFor(
-                          features::kGlicAppMenuNewBadge));
+    SetIsNewFeatureAt(
+        GetIndexOfCommandId(IDC_OPEN_GLIC).value(),
+        BrowserUserEducationInterface::From(browser())->MaybeShowNewBadgeFor(
+            features::kGlicAppMenuNewBadge));
   }
 #endif
 
@@ -1902,14 +1898,16 @@ void AppMenuModel::Build() {
 #else
         vector_icons::kSearchChromeRefreshIcon;
 #endif
-    AddItemWithStringIdAndVectorIcon(this, IDC_CONTENT_CONTEXT_LENS_OVERLAY,
-                                     IDS_SHOW_LENS_OVERLAY, icon);
+    AddItemWithStringIdAndVectorIcon(
+        this, IDC_CONTENT_CONTEXT_LENS_OVERLAY,
+        lens::GetLensOverlayEntrypointLabelAltIds(IDS_SHOW_LENS_OVERLAY), icon);
     const int lens_command_index =
         GetIndexOfCommandId(IDC_CONTENT_CONTEXT_LENS_OVERLAY).value();
     SetElementIdentifierAt(lens_command_index, kShowLensOverlay);
-    SetIsNewFeatureAt(lens_command_index,
-                      browser()->window()->MaybeShowNewBadgeFor(
-                          lens::features::kLensOverlay));
+    SetIsNewFeatureAt(
+        lens_command_index,
+        BrowserUserEducationInterface::From(browser())->MaybeShowNewBadgeFor(
+            lens::features::kLensOverlay));
   }
 
   AddItemWithStringIdAndVectorIcon(this, IDC_SHOW_TRANSLATE, IDS_SHOW_TRANSLATE,
