@@ -23,6 +23,14 @@
 #include "base/cpu.h"
 #endif
 
+#if BUILDFLAG(IS_MAC)
+#include "base/mac/mac_util.h"
+#endif
+
+#if BUILDFLAG(IS_WIN)
+#include "base/win/windows_version.h"
+#endif
+
 namespace switches {
 
 // Allow users to specify a custom buffer size for debugging purpose.
@@ -280,11 +288,6 @@ const char kCastStreamingForceDisableHardwareVp9[] =
 const char kCastStreamingForceEnableHardwareVp9[] =
     "cast-streaming-force-enable-hardware-vp9";
 
-#if !BUILDFLAG(IS_ANDROID)
-const char kCastMirroringTargetPlayoutDelay[] =
-    "cast-mirroring-target-playout-delay";
-#endif  // !BUILDFLAG(IS_ANDROID)
-
 }  // namespace switches
 
 namespace media {
@@ -317,7 +320,7 @@ BASE_FEATURE(kPictureInPictureOcclusionTracking,
 // Enables the animation of the Picture-in-Picture window creation.
 BASE_FEATURE(kPictureInPictureShowWindowAnimation,
              "PictureInPictureShowWindowAnimation",
-             base::FEATURE_DISABLED_BY_DEFAULT);
+             base::FEATURE_ENABLED_BY_DEFAULT);
 #endif  // !BUILDFLAG(IS_ANDROID)
 
 // Enables user control over muting tab audio from the tab strip.
@@ -358,10 +361,16 @@ BASE_FEATURE(kResumeBackgroundVideo,
 );
 
 #if BUILDFLAG(IS_MAC)
-// Enables system audio sharing using ScreenCaptureKit when screen sharing on
-// macOS 13.0+.
-BASE_FEATURE(kMacLoopbackAudioForScreenShare,
-             "MacLoopbackAudioForScreenShare",
+// Enables system audio loopback capture using the macOS CoreAudio tap API for
+// Cast.
+BASE_FEATURE(kMacCatapLoopbackAudioForCast,
+             "MacCatapLoopbackAudioForCast",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+// Enables system audio loopback capture using the macOS CoreAudio tap API for
+// screen share.
+BASE_FEATURE(kMacCatapLoopbackAudioForScreenShare,
+             "MacCatapLoopbackAudioForScreenShare",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
 // Use the built-in MacOS screen-sharing picker (SCContentSharingPicker). This
@@ -471,13 +480,26 @@ BASE_FEATURE(kContextMenuSearchForVideoFrame,
 BASE_FEATURE(kChromeWideEchoCancellation,
              "ChromeWideEchoCancellation",
              base::FEATURE_ENABLED_BY_DEFAULT);
-#if BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC)
+#endif
+
+#if BUILDFLAG(SYSTEM_LOOPBACK_AS_AEC_REFERENCE)
+// If echo cancellation for a mic signal is requested, use system loopback
+// audio as reference signal to be able to cancel echo from all audio processes
+// and not only audio from Chrome.
 BASE_FEATURE(kSystemLoopbackAsAecReference,
              "SystemLoopbackAsAecReference",
              base::FEATURE_DISABLED_BY_DEFAULT);
-const base::FeatureParam<int> kAddedProcessingDelay{
-    &kSystemLoopbackAsAecReference, "added_delay_ms", 100};
-#endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC)
+const base::FeatureParam<bool> kSystemLoopbackAsAecReferenceForcedOn{
+    &kSystemLoopbackAsAecReference, "forced_on", false};
+// If we are using system loopback as AEC reference, we delay the capture
+// signal with `added_delay_ms` so that the reference signal arrives before
+// the capture signal.
+const base::FeatureParam<int> kAddedProcessingDelayMs{
+    &kSystemLoopbackAsAecReference, "added_delay_ms", 170};
+// Modifies the number of matched filters used in the AEC delay estimation when
+// loopback system AEC is enabled.
+const base::FeatureParam<int> kAecDelayNumFilters{
+    &kSystemLoopbackAsAecReference, "num_filters", 6};
 #endif
 
 #if (BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN))
@@ -574,13 +596,6 @@ BASE_FEATURE(kMemoryPressureBasedSourceBufferGC,
              "MemoryPressureBasedSourceBufferGC",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
-// Forces SuggestProviderState() to only suggest deferring when range requests
-// aren't supported and the underlying provider considers itself stale. The
-// stale state is set if the provider has been in a deferred state for > 1 sec.
-BASE_FEATURE(kMultiBufferNeverDefer,
-             "MultiBufferNeverDefer",
-             base::FEATURE_DISABLED_BY_DEFAULT);
-
 // Controls whether the Mirroring Service will fetch, analyze, and store
 // information on the quality of the session using RTCP logs.
 BASE_FEATURE(kEnableRtcpReporting,
@@ -606,6 +621,12 @@ BASE_FEATURE(kRevokeMediaSourceObjectURLOnAttach,
              "RevokeMediaSourceObjectURLOnAttach",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
+#if BUILDFLAG(ENABLE_SYMPHONIA)
+BASE_FEATURE(kSymphoniaAudioDecoding,
+             "SymphoniaAudioDecoding",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+#endif
+
 BASE_FEATURE(kD3D11VideoDecoderUseSharedHandle,
              "D3D11VideoDecoderUseSharedHandle",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -736,6 +757,12 @@ BASE_FEATURE(kSpecCompliantCanPlayThrough,
              "SpecCompliantCanPlayThrough",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
+// Suspends WebMediaPlayerImpl instances when the containing RenderFrame is
+// frozen. TODO(crbug.com/41161335): Remove in M143 after it goes stable.
+BASE_FEATURE(kSuspendMediaForFrozenFrames,
+             "SuspendMediaForFrozenFrames",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
 // Disables the real audio output stream after silent audio has been delivered
 // for too long. Should save quite a bit of power in the muted video case.
 BASE_FEATURE(kSuspendMutedAudio,
@@ -1034,6 +1061,20 @@ BASE_FEATURE(kHardwareSecureDecryptionAv1,
              "HardwareSecureDecryptionAv1",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
+#if BUILDFLAG(IS_WIN)
+// Enables showing permission indicator in the omnibox when a site is allowed or
+// denied to to use protected content IDs to play protected content.
+BASE_FEATURE(kProtectedMediaIdentifierIndicator,
+             "ProtectedMediaIdentifierIndicator",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
+// Requires that setServerCertificate() be called before generateRequest().
+// This feature only affects MediaFoundation OS CDMs.
+BASE_FEATURE(kHardwareSecureDecryptionRequireServerCert,
+             "HardwareSecureDecryptionRequireServerCert",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+#endif
+
 // Enables handling of hardware media keys for controlling media.
 BASE_FEATURE(kHardwareMediaKeyHandling,
              "HardwareMediaKeyHandling",
@@ -1076,6 +1117,13 @@ BASE_FEATURE(kAllowNonSecureOverlays,
              "AllowNonSecureOverlays",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
+// Enables automatic Picture-in-Picture on Android for supported websites.
+// This triggers for active video playback or camera/microphone usage on sites
+// that have registered an auto picture-in-picture action.
+BASE_FEATURE(kAutoPictureInPictureAndroid,
+             "AutoPictureInPictureAndroid",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
 // Enables block model (LinearBlock) on supported devices.
 BASE_FEATURE(kMediaCodecBlockModel,
              "MediaCodecBlockModel",
@@ -1183,8 +1231,6 @@ BASE_FEATURE(kBuiltInHlsPlayer,
 #endif
 );
 
-BASE_FEATURE(kBuiltInHlsMP4, "BuiltInHlsMP4", base::FEATURE_ENABLED_BY_DEFAULT);
-
 #endif  // BUILDFLAG(ENABLE_HLS_DEMUXER)
 
 // TODO(crbug.com/414430336): Consider restricting to IS_CHROMEOS.
@@ -1517,24 +1563,6 @@ BASE_FEATURE(kMediaEngagementHTTPSOnly,
              "MediaEngagementHTTPSOnly",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
-// Enables experimental local learning for media. Used in the context of media
-// capabilities only. Adds reporting only; does not change media behavior.
-BASE_FEATURE(kMediaLearningExperiment,
-             "MediaLearningExperiment",
-             base::FEATURE_DISABLED_BY_DEFAULT);
-
-// Enables the general purpose media machine learning framework. Adds reporting
-// only; does not change media behavior.
-BASE_FEATURE(kMediaLearningFramework,
-             "MediaLearningFramework",
-             base::FEATURE_DISABLED_BY_DEFAULT);
-
-// Enables the smoothness prediction experiment.  Requires
-// kMediaLearningFramework to be enabled also, else it does nothing.
-BASE_FEATURE(kMediaLearningSmoothnessExperiment,
-             "MediaLearningSmoothnessExperiment",
-             base::FEATURE_DISABLED_BY_DEFAULT);
-
 // Enable the prototype global optimization of tuneables via finch.  See
 // media/base/tuneable.h for how to create tuneable parameters.
 BASE_FEATURE(kMediaOptimizer,
@@ -1594,6 +1622,12 @@ BASE_FEATURE(kUseFakeDeviceForMediaStream,
              "use-fake-device-for-media-stream",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
+// Enables accurate dropped frame count for MediaStreamVideoSource.
+// TODO(crbug.com/432367602): Remove after M143.
+BASE_FEATURE(kMediaStreamAccurateDroppedFrameCount,
+             "MediaStreamAccurateDroppedFrameCount",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
 #if !BUILDFLAG(IS_ANDROID) && !BUILDFLAG(IS_CHROMEOS) && !BUILDFLAG(IS_FUCHSIA)
 // Enables effects for camera and mic streams.
 BASE_FEATURE(kCameraMicEffects,
@@ -1738,6 +1772,10 @@ BASE_FEATURE(kMediaFoundationAcceleratedEncodeOnArm64,
 #endif
 
 #if BUILDFLAG(IS_WIN)
+BASE_FEATURE(kD3D12SharedImageEncode,
+             "D3D12SharedImageEncode",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
 BASE_FEATURE(kMediaFoundationD3DVideoProcessing,
              "MediaFoundationD3DVideoProcessing",
              base::FEATURE_DISABLED_BY_DEFAULT);
@@ -1756,6 +1794,11 @@ BASE_FEATURE(kHeadlessLiveCaption,
              "HeadlessLiveCaption",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
+// Allows per-site special processing for media links.
+BASE_FEATURE(kMediaLinkHelpers,
+             "MediaLinkHelpers",
+             base::FEATURE_ENABLED_BY_DEFAULT);
+
 bool IsChromeWideEchoCancellationEnabled() {
 #if BUILDFLAG(CHROME_WIDE_ECHO_CANCELLATION)
   return base::FeatureList::IsEnabled(kChromeWideEchoCancellation) &&
@@ -1765,25 +1808,88 @@ bool IsChromeWideEchoCancellationEnabled() {
 #endif
 }
 
+#if BUILDFLAG(IS_MAC)
+namespace {
+// Enables system audio loopback capture using the macOS Screen Capture Kit
+// framework, regardless of the system version.
+BASE_FEATURE(kMacSckSystemAudioLoopbackOverride,
+             "MacSckSystemAudioLoopbackOverride",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+}  // namespace
+
+bool IsMacCatapSystemLoopbackCaptureSupported() {
+  return (base::mac::MacOSVersion() >= 14'02'00);
+}
+
+bool IsMacSckSystemLoopbackCaptureSupported() {
+  // Only supported on macOS 13.0+.
+  // Disabled on macOS 15.0 due to problems with permission prompt.
+  // The override feature is useful for testing on unsupported versions.
+  return (base::mac::MacOSVersion() >= 13'00'00 &&
+          base::mac::MacOSVersion() < 15'00'00) ||
+         base::FeatureList::IsEnabled(kMacSckSystemAudioLoopbackOverride);
+}
+#endif  // BUILDFLAG(IS_MAC)
+
+#if BUILDFLAG(IS_WIN)
+bool IsWindowsSystemLoopbackCaptureSupported() {
+  return (base::win::GetVersion() >= base::win::Version::WIN11);
+}
+#endif  // BUILDFLAG(IS_WIN)
+
+bool IsSystemLoopbackCaptureSupported() {
+#if BUILDFLAG(IS_WIN) || BUILDFLAG(USE_CRAS)
+  return true;
+#elif BUILDFLAG(IS_MAC)
+  return (IsMacSckSystemLoopbackCaptureSupported() ||
+          IsMacCatapSystemLoopbackCaptureSupported());
+#elif BUILDFLAG(IS_LINUX) && defined(USE_PULSEAUDIO)
+  return true;
+#else
+  return false;
+#endif  // BUILDFLAG(IS_WIN) || BUILDFLAG(USE_CRAS)
+}
+
 bool IsSystemLoopbackAsAecReferenceEnabled() {
-#if BUILDFLAG(CHROME_WIDE_ECHO_CANCELLATION) && \
-    (BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC))
+#if BUILDFLAG(SYSTEM_LOOPBACK_AS_AEC_REFERENCE)
+
+#if BUILDFLAG(IS_MAC)
+  if (!IsMacCatapSystemLoopbackCaptureSupported()) {
+    return false;
+  }
+#elif BUILDFLAG(IS_WIN)
+  if (!IsWindowsSystemLoopbackCaptureSupported()) {
+    return false;
+  }
+#endif
   return base::FeatureList::IsEnabled(kSystemLoopbackAsAecReference);
+
+#else  // BUILDFLAG(SYSTEM_LOOPBACK_AS_AEC_REFERENCE)
+  return false;
+#endif
+}
+
+bool IsSystemLoopbackAsAecReferenceForcedOn() {
+#if BUILDFLAG(SYSTEM_LOOPBACK_AS_AEC_REFERENCE)
+  return IsSystemLoopbackAsAecReferenceEnabled() &&
+         kSystemLoopbackAsAecReferenceForcedOn.Get();
 #else
   return false;
 #endif
 }
 
-std::optional<base::TimeDelta> GetAecAddedDelay() {
-#if BUILDFLAG(CHROME_WIDE_ECHO_CANCELLATION) && \
-    (BUILDFLAG(IS_WIN) || BUILDFLAG(IS_MAC))
-  if (IsSystemLoopbackAsAecReferenceEnabled()) {
-    return base::Milliseconds(kAddedProcessingDelay.Get());
-  }
-#endif
-  return std::nullopt;
+#if BUILDFLAG(SYSTEM_LOOPBACK_AS_AEC_REFERENCE)
+base::TimeDelta GetAecAddedDelay() {
+  CHECK(IsSystemLoopbackAsAecReferenceEnabled());
+  return base::Milliseconds(kAddedProcessingDelayMs.Get());
 }
 
+int GetAecDelayNumFilters() {
+  CHECK(IsSystemLoopbackAsAecReferenceEnabled());
+  return kAecDelayNumFilters.Get();
+}
+#endif  // BUILDFLAG(SYSTEM_LOOPBACK_AS_AEC_REFERENCE)
+
 bool IsSystemEchoCancellationEnforced() {
 #if (BUILDFLAG(IS_MAC) || BUILDFLAG(IS_WIN))
   return base::FeatureList::IsEnabled(kEnforceSystemEchoCancellation);
@@ -1851,6 +1957,17 @@ bool IsVideoCaptureAcceleratedJpegDecodingEnabled() {
 #endif
 }
 
+bool IsRestrictOwnAudioSupported() {
+#if BUILDFLAG(IS_MAC)
+  return IsMacCatapSystemLoopbackCaptureSupported() &&
+         base::FeatureList::IsEnabled(kMacCatapLoopbackAudioForScreenShare);
+#elif BUILDFLAG(IS_WIN)
+  return IsWindowsSystemLoopbackCaptureSupported();
+#else
+  return false;
+#endif
+}
+
 #if BUILDFLAG(IS_WIN)
 bool IsMediaFoundationD3D11VideoCaptureEnabled() {
   return base::FeatureList::IsEnabled(kMediaFoundationD3D11VideoCapture);
